<?php
function solatec_cms_features_list_opts($widget, $i, $condition = []){
    $widget->start_controls_section(
        'feature'.$i.'_section',
        [
            'label'    => 'Features '.$i,
            'tab'      => \Elementor\Controls_Manager::TAB_CONTENT
        ]
    );
        $widget->add_control(
            'heading'.$i.'_icon',
            [
                'label'            => esc_html__('Select Heading Icon', 'solatec'),
                'type'             => \Elementor\Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default'          => [
                    'value'     => '',
                    'library'   => '',
                ]
            ]
        );
        $widget->add_control(
            'heading'.$i.'_text',
            [
                'label'       => esc_html__( 'Heading', 'solatec' ),
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'default'     => '',
                'placeholder' => esc_html__( 'Enter your title', 'solatec' ),
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'heading'.$i.'_color',
            [
                'label'       => esc_html__( 'Heading Color', 'solatec' ),
                'type'        => \Elementor\Controls_Manager::SELECT,
                'options'     => solatec_elementor_theme_color_opts(),  
                'default'     => ''
            ]
        );
        $widget->add_control(
            'heading'.$i.'_custom_color',
            [
                'label'       => esc_html__( 'Custom Heading Color', 'solatec' ),
                'type'        => \Elementor\Controls_Manager::COLOR,
                'condition'   => [
                    'heading'.$i.'_color'      => 'custom'
                ]
            ]
        );
        $widget->add_control(
            'feature'.$i.'_icon',
            [
                'label'            => esc_html__( 'Feture Icon', 'solatec' ),
                'type'             => \Elementor\Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default'          => [
                    'value'     => '',
                    'library'   => '',
                ],
                'separator' => 'before'
            ]
        );
        $widget->add_control(
            'icon'.$i.'_color',
            [
                'label'       => esc_html__( 'Icon Color', 'solatec' ),
                'type'        => \Elementor\Controls_Manager::SELECT,
                'options'     => solatec_elementor_theme_color_opts(),  
                'default'     => '',
                'condition'   => [
                    'feature_icon[value]!' => ''
                ]
            ]
        );
        $widget->add_control(
            'icon'.$i.'_custom_color',
            [
                'label'       => esc_html__( 'Custom Icon Color', 'solatec' ),
                'type'        => \Elementor\Controls_Manager::COLOR,
                'condition'   => [
                    'icon'.$i.'_color'      => 'custom'
                ]
            ]
        );
        $widget->add_control(
            'feature'.$i.'_lists',
            [
                'label'   => '',
                'type'    => \Elementor\Controls_Manager::REPEATER,
                'default' => [],
                'controls' => array(
                    array(
                        'name'        => 'feature_text',
                        'type'        => \Elementor\Controls_Manager::TEXT,
                        'label_block' => true
                    )
                ),
                'title_field'   => '{{{ feature_text }}}',
                'separator'     => 'before',
                'prevent_empty' => false,
            ]
        );
        $widget->add_control(
            'feature'.$i.'_color',
            [
                'label'       => esc_html__( 'Text Color', 'solatec' ),
                'type'        => \Elementor\Controls_Manager::SELECT,
                'options'     => solatec_elementor_theme_color_opts(),  
                'default'     => '',
                'separator'   => 'before',
                'condition'   => [
                    'feature_lists!' => ''
                ]
            ]
        );
        $widget->add_control(
            'feature'.$i.'_custom_color',
            [
                'label'       => esc_html__( 'Custom Text Color', 'solatec' ),
                'type'        => \Elementor\Controls_Manager::COLOR,
                'condition'   => [
                    'feature'.$i.'_color'      => 'custom'
                ]
            ]
        );
    $widget->end_controls_section();
}
function solatec_cms_features_list_render($widget, $settings, $i , $args = []){
    $args = wp_parse_args($args, [
        'heading_text'         => '',
        'heading_color'        => '26365e',
        'heading_icon'         => [],
        'heading_custom_color' => '',
        'feature_lists'        => [],
        'feature_icon'         => [],
        'feature_icon_color'   => '',
        'feature_color'        => '',
        'bg'                   => '' 
    ]);
    if(empty($widget->get_setting('heading'.$i.'_text', $args['heading_text']))) return;
    // Heading
    $widget->add_render_attribute( 'heading', 'class', 'col-12 col-md-4 text-14 font-700');
    $widget->add_render_attribute( 'heading', 'class', 'text-'.$widget->get_setting('heading'.$i.'_color', $args['heading_color']));

    if($settings['heading'.$i.'_color'] === 'custom' && !empty($settings['heading'.$i.'_custom_color'])){
        $widget->add_render_attribute( 'heading', 'style', 'color:'.$settings['heading'.$i.'_custom_color']);
    }
    ?>
    <div class="cms-features-section bg-<?php echo esc_attr($args['bg']);?>">
        <div class="row">
            <div <?php etc_print_html($widget->get_render_attribute_string( 'heading' )); ?>><?php
                solatec_elementor_icon_render($settings,[
                    'id'           => 'heading'.$i.'_icon',
                    'tag'          => 'span',
                    'default_icon' => $args['heading_icon']
                ]);
                echo esc_html($widget->get_setting('heading'.$i.'_text', $args['heading_text']));
            ?></div>
            <?php
                $feature_lists = $widget->get_setting('feature'.$i.'_lists', $args['feature_lists']);
                if(!empty($feature_lists)){
                    echo '<div class="cms-features col-12 col-md-8 text-14 text-'.$settings['feature'.$i.'_color'].'">';
                    foreach ($feature_lists as $feature){
                        echo '<div class="cms-feature-item">';
                            solatec_elementor_icon_render($settings, [
                                'id'           => 'feature'.$i.'_icon', 
                                'tag'          => 'span', 
                                'wrap_class'   => 'text-10 text-'.$widget->get_setting('icon'.$i.'_color', $args['feature_icon_color']), 
                                'default_icon' => $args['feature_icon']
                            ]);
                            echo '<span class="cms-feature-title">'.$feature['feature_text'].'</span>';
                        echo '</div>';
                    }
                    echo '</div>';
                }
            ?>
        </div>
    </div>
    <?php
}
use Elementor\Controls_Manager;
if (!function_exists('solatec_widget_cms_features_register_controls')) {
    add_action('etc_widget_cms_features_register_controls', 'solatec_widget_cms_features_register_controls', 10, 1);
    function solatec_widget_cms_features_register_controls($widget)
    {
        // Layout Section Start
        $widget->start_controls_section('layout_section', [
            'label' => esc_html__('Layout', 'solatec'),
            'tab' => Controls_Manager::TAB_LAYOUT
        ]);
            $widget->add_control('layout', [
                'label'   => esc_html__('Templates', 'solatec'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'solatec' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_features/layout-images/1.png'
                    ]
                ],
                'prefix_class' => 'cms-features-layout-'
            ]);
        $widget->end_controls_section();
        // Content
        solatec_cms_features_list_opts($widget, 1, ['1','2','3','4','5','6','7','8','9','10']);
        solatec_cms_features_list_opts($widget, 2, ['2','3','4','5','6','7','8','9','10']);
        solatec_cms_features_list_opts($widget, 3, ['3','4','5','6','7','8','9','10']);
        solatec_cms_features_list_opts($widget, 4, ['4','5','6','7','8','9','10']);
        solatec_cms_features_list_opts($widget, 5, ['5','6','7','8','9','10']);
        solatec_cms_features_list_opts($widget, 6, ['6','7','8','9','10']);
        solatec_cms_features_list_opts($widget, 7, ['7','8','9','10']);
        solatec_cms_features_list_opts($widget, 8, ['8','9','10']);
        solatec_cms_features_list_opts($widget, 9, ['9','10']);
        solatec_cms_features_list_opts($widget, 10, ['10']);
        // Style
        $widget->start_controls_section(
            'background_section',
            [
                'label'    => esc_html__( 'Background Settings', 'solatec' ),
                'tab'      => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
            $widget->add_control(
                'odd_bg',
                [
                    'label'       => esc_html__( 'Odd Background', 'solatec' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'options'     => solatec_elementor_theme_color_opts(),  
                    'default'     => '',
                ]
            );
            $widget->add_control(
                'even_bg',
                [
                    'label'       => esc_html__( 'Even Background', 'solatec' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'options'     => solatec_elementor_theme_color_opts(),  
                    'default'     => '',
                ]
            );
        $widget->end_controls_section();
    }
}