<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;
if (!function_exists('solatec_widget_cms_headline_register_controls')) {
    add_action('etc_widget_cms_headline_register_controls', 'solatec_widget_cms_headline_register_controls', 10, 1);
    function solatec_widget_cms_headline_register_controls($widget)
    {
        // Layout Section Start
        $widget->start_controls_section('layout_section', [
            'label' => esc_html__('Layout', 'solatec'),
            'tab' => Controls_Manager::TAB_LAYOUT
        ]);
            solatec_elementor_text_align($widget, ['default' => '']);
            $widget->add_control('layout', [
                'label'   => esc_html__('Templates', 'solatec'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label'      => esc_html__( 'Layout 1', 'solatec' ),
                        'image'      => get_template_directory_uri() . '/elementor/templates/widgets/cms_headline/layout-images/layout1.png',
                    ],
                    
                ]
            ]);
        $widget->end_controls_section();
        // Slick Slider Settings
        solatec_elementor_slick_slider_settings($widget);
        // Content Settings
        $widget->start_controls_section(
            'heading_section',
            [
                'label'    => esc_html__( 'Heading Settings', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'heading_icon',
                [
                    'label'            => esc_html__( 'Heading Icon', 'solatec' ),
                    'type'             => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'default'          => [
                        'value'   => '',
                        'library' => '',
                    ]
                ]
            );
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'solatec' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Enter your title', 'solatec' ),
                    'label_block' => true,
                    'condition'   => []
                ]
            );
        $widget->end_controls_section();
        // Source Settings
        $widget->start_controls_section(
            'source_section',
            [
                'label'    => esc_html__( 'Source', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'source_type',
                [
                    'label'    => esc_html__( 'Source Type', 'solatec' ),
                    'type'     => Controls_Manager::SELECT,
                    'options'  => [
                        'buildin'    => esc_html__('Build In', 'solatec'),
                        'custom'     => esc_html__('Custom', 'solatec')
                    ],
                    'default'  => 'buildin'
                ]
            );
            $widget->add_control(
                'post_type',
                [
                    'label'    => esc_html__( 'Select Post Type', 'solatec' ),
                    'type'     => Controls_Manager::SELECT,
                    'multiple' => true,
                    'options'  => etc_get_post_type_options(),
                    'default'  => 'post',
                    'condition' => [
                        'source_type' => 'buildin'
                    ]
                ]
            );
            etc_get_grid_term_by_post_type_options($widget, [
                'custom_condition' => [
                    'source_type' => ['buildin']
                ]
            ]);
            $widget->add_control(
                'orderby',
                [
                    'label'   => esc_html__( 'Order By', 'solatec' ),
                    'type'    => Controls_Manager::SELECT,
                    'default' => 'date',
                    'options' => [
                        'date'   => esc_html__( 'Date', 'solatec' ),
                        'ID'     => esc_html__( 'ID', 'solatec' ),
                        'author' => esc_html__( 'Author', 'solatec' ),
                        'title'  => esc_html__( 'Title', 'solatec' ),
                        'rand'   => esc_html__( 'Random', 'solatec' ),
                    ],
                    'condition' => [
                        'source_type' => 'buildin'
                    ]
                ]
            );
            $widget->add_control(
                'order',
                [
                    'label'   => esc_html__( 'Sort Order', 'solatec' ),
                    'type'    => Controls_Manager::SELECT,
                    'default' => 'desc',
                    'options' => [
                        'desc' => esc_html__( 'Descending', 'solatec' ),
                        'asc'  => esc_html__( 'Ascending', 'solatec' ),
                    ],
                    'condition' => [
                        'source_type' => 'buildin'
                    ]
                ]
            );
            $widget->add_control(
                'limit',
                [
                    'label'   => esc_html__( 'Total items', 'solatec' ),
                    'type'    => Controls_Manager::NUMBER,
                    'default' => '6',
                    'condition' => [
                        'source_type' => 'buildin'
                    ]
                ]
            );
        $widget->end_controls_section();
        // Thumbnail Settings
        $widget->start_controls_section(
            'thumbnail_section',
            [
                'label'    => esc_html__( 'Thumbnail Options', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'source_type' => 'buildin'
                ]
            ]
        );
            $widget->add_control(
                'show_thumbnail',
                [
                    'label'   => esc_html__( 'Show Thumbnail', 'solatec' ),
                    'type'    => Controls_Manager::SELECT,
                    'options'      => [
                        'yes' => esc_html__('Yes', 'solatec'),
                        'no'  => esc_html__('No','solatec')
                    ],
                    'default' => 'no',
                ]
            );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'         => 'thumbnail',
                    'default'      => 'thumbnail',
                    'condition'    => [
                        'show_thumbnail' => ['yes']
                    ]
                ]
            );
        $widget->end_controls_section();
        // Custom Content
        $widget->start_controls_section(
            'content_list',
            [
                'label'    => esc_html__('Custom Content', 'solatec'),
                'tab'      => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'source_type' => 'custom'
                ]
            ]
        );
            $custom_content = new Repeater();
            $custom_content->add_control(
                'title',
                [
                    'label'       => esc_html__('Title', 'solatec'),
                    'type'        => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );
            solatec_elementor_hyperlink_settings($custom_content);
            $widget->add_control(
                'custom_content',
                [
                    'label'    => esc_html__('Add Item', 'solatec'),
                    'type'     => Controls_Manager::REPEATER,
                    'fields'   => $custom_content->get_controls(),
                    'default' => [
                        [
                            'title'       => esc_html__( 'We drive the transition to more sustainable, reliable & affordable energy systems #1,', 'solatec' )
                        ],
                        [
                            'title'       => esc_html__( 'We drive the transition to more sustainable, reliable & affordable energy systems #2', 'solatec' )
                        ]
                    ],
                    'title_field' => '{{{ title }}}',
                ]
            );
        $widget->end_controls_section();
    }
}