<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
// register element
if (!function_exists('solatec_widget_cms_image_gallery_register_controls')) {
    add_action('etc_widget_cms_image_gallery_register_controls', 'solatec_widget_cms_image_gallery_register_controls', 10, 1);
    function solatec_widget_cms_image_gallery_register_controls($widget)
    {
        // Layout Section Start
        $widget->start_controls_section('layout_section', [
            'label' => esc_html__('Layout', 'solatec'),
            'tab' => Controls_Manager::TAB_LAYOUT
        ]);
            solatec_elementor_text_align($widget, ['default' => '']);
            $widget->add_control(
                'hover_effect',
                [
                    'label'   => esc_html__( 'Hover Styles', 'solatec' ),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        '' => esc_html__('Default','solatec'),
                    ],
                    'default' => ''
                ]
            );
            $widget->add_control('layout', [
                'label'   => esc_html__('Templates', 'solatec'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__('Layout 1', 'solatec' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_image_gallery/layout-images/1.png'
                    ]
                ]
            ]);
        $widget->end_controls_section();
        // Grid
        $widget->start_controls_section(
            'grid_section',
            [
                'label'    => esc_html__('Image Gallery', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'wp_gallery',
                [
                    'label'      => esc_html__( 'Add Images', 'solatec' ),
                    'type'       => Controls_Manager::GALLERY,
                    'show_label' => false,
                    'dynamic'    => [
                        'active' => true,
                    ]
                ]
            );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'         => 'thumbnail',
                    'default'      => 'large',
                ]
            );
            $widget->add_control(
                'gallery_col',
                [
                    'label'        => esc_html__('Columns', 'solatec' ),
                    'type'         => Controls_Manager::SELECT,
                    'default'      => '3',
                    'control_type' => 'responsive',
                    'options'      => [
                        '1' => esc_html__('1', 'solatec' ),
                        '2' => esc_html__('2', 'solatec' ),
                        '3' => esc_html__('3', 'solatec' ),
                        '4' => esc_html__('4', 'solatec' ),
                        '6' => esc_html__('6', 'solatec' ),
                    ]
                ]
            );
            $widget->add_control(
                'gallery_rand',
                [
                    'label'   => esc_html__( 'Order By', 'solatec' ),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        ''     => esc_html__( 'Default', 'solatec' ),
                        'rand' => esc_html__( 'Random', 'solatec' ),
                    ],
                    'default' => ''
                ]
            );
        $widget->end_controls_section();
        // Style
        $widget->start_controls_section(
            'gallery_images_section',
            [
                'label'    => esc_html__('Images', 'solatec' ),
                'tab'      => Controls_Manager::TAB_STYLE
            ]
        );
            $widget->add_control(
                'gap',
                [
                    'label'        => esc_html__('Image Gap', 'solatec' ),
                    'type'         => Controls_Manager::NUMBER,
                    'control_type' => 'responsive',
                    'default'      => 30
                ]
            );
            $widget->add_control(
                'gallery_display_caption',
                [
                    'label'   => esc_html__( 'Display', 'solatec' ),
                    'type'    => Controls_Manager::SELECT,
                    'default' => 'none',
                    'options' => [
                        'none' => esc_html__( 'Hide', 'solatec' ),
                        ''     => esc_html__( 'Show', 'solatec' ),
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .image-caption' => 'display: {{VALUE}};',
                    ]
                ]
            );
            $widget->add_control(
                'caption_align',
                [
                    'label'   => __( 'Alignment', 'solatec' ),
                    'type'    => Controls_Manager::CHOOSE,
                    'options' => [
                        'left' => [
                            'title' => __( 'Left', 'solatec' ),
                            'icon' => 'eicon-text-align-left',
                        ],
                        'center' => [
                            'title' => __( 'Center', 'solatec' ),
                            'icon' => 'eicon-text-align-center',
                        ],
                        'right' => [
                            'title' => __( 'Right', 'solatec' ),
                            'icon' => 'eicon-text-align-right',
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .image-caption' => 'text-align: {{VALUE}};',
                    ],
                    'default'   => 'center',
                    'condition' => [
                        'gallery_display_caption' => '',
                    ]
                ]
            );
            $widget->add_control(
                'caption_color',
                [
                    'label'     => esc_html__( 'Text Color', 'solatec' ),
                    'type'      => Controls_Manager::COLOR,
                    'default'   => '',
                    'selectors' => [
                        '{{WRAPPER}} .image-caption' => 'color: {{VALUE}};',
                    ],
                    'condition' => [
                        'gallery_display_caption' => '',
                    ]
                ]
            );
            $widget->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'      => 'caption_typography',
                    'selector'  => '{{WRAPPER}} .image-caption',
                    'condition' => [
                        'gallery_display_caption' => '',
                    ]
                ]
            );
        $widget->end_controls_section();
    }
}