<?php
use Elementor\Controls_Manager;
use Elementor\Repeater;
if (!function_exists('solatec_widget_cms_locate_pointers_register_controls')) {
    add_action('etc_widget_cms_locate_pointers_register_controls', 'solatec_widget_cms_locate_pointers_register_controls', 10, 1);
    function solatec_widget_cms_locate_pointers_register_controls($widget)
    {
        // Layout Section Start
        $widget->start_controls_section('layout_section', [
            'label' => esc_html__('Layout', 'solatec'),
            'tab' => Controls_Manager::TAB_LAYOUT
        ]);
            $widget->add_control('layout', [
                'label'   => esc_html__('Templates', 'solatec'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__('Layout 1', 'solatec' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_locate_pointers/layout-images/layout1.png'
                    ]
                ],
                'prefix_class' => 'cms-locate-pointer-layout-'
            ]);
        $widget->end_controls_section();
        // Icons
        $widget->start_controls_section(
            'icon_section',
            [
                'label'    => esc_html__('Banner Box', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            solatec_elementor_text_align($widget, [
                'label' => esc_html__('Backround Image Alignment','solatec'),
                'label_block' => 'true'
            ]);
            $widget->add_control(
                'image_bg',
                [
                    'label'   => esc_html__('Backround Image', 'solatec' ),
                    'type'    => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => get_template_directory_uri().'/assets/images/world-map.png',
                    ]
                ]
            );
            $pointers = new Repeater();
            $pointers->add_control(
                'image',
                [
                    'label'       => esc_html__('Image Pointers', 'solatec'),
                    'type'        => Controls_Manager::MEDIA,
                    'label_block' => true,
                    'default'     => [ 
                        'url' => ''
                    ]
                ]
            );
            $pointers->add_control(
                'selected_icon',
                [
                    'label'            => esc_html__( 'Icon', 'solatec' ),
                    'type'             => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'default'          => [
                        'value'   => 'cmsi-solar-panel',
                        'library' => 'cmsi',
                    ]
                ]
            );
            $pointers->add_control(
                'number',
                [
                    'label'       => esc_html__('Add Number', 'solatec'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => ''
                ]
            );
            $pointers->add_control(
                'content',
                [
                    'label'       => esc_html__('Content', 'solatec'),
                    'type'        => Controls_Manager::TEXTAREA,
                    'label_block' => true
                ]
            );
            $pointers->add_control(
                'content_hover',
                [
                    'label'   => esc_html__('Holder Style', 'solatec' ),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'holder-right' => 'Holder Right',
                        'holder-left'  => 'Holder Left'
                    ],
                    'default' => 'holder-right'
                ]
            );
            $pointers->add_control(
                'item_postion',
                [
                    'label'              => esc_html__('Item Postion', 'solatec' ),
                    'type'               => Controls_Manager::DIMENSIONS,
                    'control_type'       => 'responsive',
                    'allowed_dimensions' => ['top', 'left'],
                    'size_units'         => [ 'px', '%' ],
                    'range' => [
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default' => [
                        'top' => '10',
                        'left' => '10'
                    ],
                    'selectors' => [
                        '{{WRAPPER}} {{CURRENT_ITEM}}.item-pointer' => 'top: {{TOP}}{{UNIT}};left: {{LEFT}}{{UNIT}};',
                        '.rtl {{WRAPPER}} {{CURRENT_ITEM}}.item-pointer' => 'left: auto; right: {{LEFT}}{{UNIT}};',
                    ]
                ]
            );
            $widget->add_control(
                'content_list',
                [
                    'label'    => esc_html__('Pointers List', 'solatec'),
                    'type'     => Controls_Manager::REPEATER,
                    'fields'   => $pointers->get_controls(),
                    'default'  => [
                        [
                            'image'         => [],
                            'selected_icon' => [
                                'value'     => 'cmsi-solar-panel',
                                'library'   => 'cmsi'        
                            ],
                            'number'        => '748',
                            'content'       => 'Awards Milestones Awarded To Us.',
                            'content_hover' => 'holder-right',
                            'item_postion'  => [
                                'unit' => '%',
                                'top'  => '26',
                                'left' => '19'
                            ]
                        ],
                        [
                            'image'         => [],
                            'selected_icon' => [
                                'value'     => 'cmsi-solar-panel',
                                'library'   => 'cmsi' 
                            ],
                            'number'        => '2307',
                            'content'       => 'Beverley Rd Brooklyn, New York 11226 U.S.',
                            'content_hover' => 'holder-right',
                            'item_postion'  => [
                                'unit' => '%',
                                'top'  => '44',
                                'left' => '46'
                            ]
                        ]
                    ],
                    'title_field' => '{{{ content }}}'
                ]
            );
        $widget->end_controls_section();
    }
}