<?php
use Elementor\Controls_Manager;
// Register
if (!function_exists('solatec_widget_cms_menu_register_controls')) {
    add_action('etc_widget_cms_menu_register_controls', 'solatec_widget_cms_menu_register_controls', 10, 1);
    function solatec_widget_cms_menu_register_controls($widget)
    {
        $menus = get_terms( 'nav_menu', array( 'hide_empty' => false ) );
        if ( is_array( $menus ) && ! empty( $menus ) ) {
            foreach ( $menus as $single_menu ) {
                if ( is_object( $single_menu ) && isset( $single_menu->name, $single_menu->term_id ) ) {
                    $custom_menus[ $single_menu->slug ] = $single_menu->name;
                }
            }
        } else {
            $custom_menus = '';
        }
        // Layout Section Start
        $widget->start_controls_section('layout_section', [
            'label' => esc_html__('Layout', 'solatec'),
            'tab' => Controls_Manager::TAB_LAYOUT
        ]);
            $widget->add_control('layout', [
                'label'   => esc_html__('Templates', 'solatec'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'solatec' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_menu/layout-images/1.png'
                    ],
                    '2' => [
                        'label' => esc_html__( 'Layout 2', 'solatec' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_menu/layout-images/2.png'
                    ],
                    '3' => [
                        'label' => esc_html__( 'Layout 3', 'solatec' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_menu/layout-images/3.png'
                    ],
                    '4' => [
                        'label' => esc_html__( 'Layout 4', 'solatec' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_menu/layout-images/4.png'
                    ],
                ],
                'prefix_class' => 'cms-menu-layout-'
            ]);
        $widget->end_controls_section();
        // Settings
        $widget->start_controls_section(
            'setting_section',
            [
                'label'    => esc_html__('Settings', 'solatec'),
                'tab'      => \Elementor\Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__('Heading', 'solatec'),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'label_block' => true
                ]
            );
            $widget->add_control(
                'heading_color',
                [
                    'label'       => esc_html__( 'Heading Color', 'solatec' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'options'     => solatec_elementor_theme_color_opts(),  
                    'default'     => '',
                    'condition'   => [
                        'heading_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'heading_custom_color',
                [
                    'label'       => esc_html__( 'Custom Heading Color', 'solatec' ),
                    'type'        => \Elementor\Controls_Manager::COLOR,
                    'condition'   => [
                        'heading_text!' => '',
                        'heading_color' => 'custom'
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .cms-heading' => 'color:{{VALUE}};'
                    ]
                ]
            );
            $widget->add_control(
                'menu',
                [
                    'label'     => esc_html__('Select Menu', 'solatec'),
                    'type'      => \Elementor\Controls_Manager::SELECT,
                    'options'   => $custom_menus,
                    'separator' => 'before'
                ]
            );
            $widget->add_control(
                'link_color',
                [
                    'label'       => esc_html__( 'Link Color', 'solatec' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'options'     => solatec_elementor_theme_color_opts(),  
                    'default'     => ''
                ]
            );
            $widget->add_control(
                'link_hover_color',
                [
                    'label'       => esc_html__( 'Link Hover Color', 'solatec' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'options'     => solatec_elementor_theme_color_opts(),  
                    'default'     => ''
                ]
            );
        $widget->end_controls_section();
    }
}