<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
if (!function_exists('solatec_widget_cms_post_carousel_register_controls')) {
    add_action('etc_widget_cms_post_carousel_register_controls', 'solatec_widget_cms_post_carousel_register_controls', 10, 1);
    function solatec_widget_cms_post_carousel_register_controls($widget)
    {
        // Layout Section Start
        $widget->start_controls_section('layout_section', [
            'label' => esc_html__('Layout', 'solatec'),
            'tab' => Controls_Manager::TAB_LAYOUT
        ]);
            $widget->add_control(
                'layout', [
                    'label'        => esc_html__('Templates', 'solatec'),
                    'type'         => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default'      => '1',
                    'options'      => solatec_elementor_post_layout(),
                    'prefix_class' => 'cms-post-layout-'
                ]
            );
        $widget->end_controls_section();
        // Slider settings
        solatec_elementor_slick_slider_settings($widget);
        // Source
        $widget->start_controls_section(
            'source_section',
            [
                'label'    => esc_html__( 'Source Options', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'post_type',
                [
                    'label'    => esc_html__( 'Select Post Type', 'solatec' ),
                    'type'     => Controls_Manager::SELECT,
                    'multiple' => true,
                    'options'  => etc_get_post_type_options(),
                    'default'  => 'post'
                ]
            );
            etc_get_grid_term_by_post_type_options($widget);
            $widget->add_control(
                'orderby',
                [
                    'label'   => esc_html__( 'Order By', 'solatec' ),
                    'type'    => Controls_Manager::SELECT,
                    'default' => 'date',
                    'options' => [
                        'date'   => esc_html__( 'Date', 'solatec' ),
                        'ID'     => esc_html__( 'ID', 'solatec' ),
                        'author' => esc_html__( 'Author', 'solatec' ),
                        'title'  => esc_html__( 'Title', 'solatec' ),
                        'rand'   => esc_html__( 'Random', 'solatec' ),
                    ]
                ]
            );
            $widget->add_control(
                'order',
                [
                    'label'   => esc_html__( 'Sort Order', 'solatec' ),
                    'type'    => Controls_Manager::SELECT,
                    'default' => 'desc',
                    'options' => [
                        'desc' => esc_html__( 'Descending', 'solatec' ),
                        'asc'  => esc_html__( 'Ascending', 'solatec' ),
                    ]
                ]
            );
            $widget->add_control(
                'limit',
                [
                    'label'   => esc_html__( 'Items to show', 'solatec' ),
                    'type'    => Controls_Manager::NUMBER,
                    'default' => '6'
                ]
            );
        $widget->end_controls_section();
        // Thumbnail
        $widget->start_controls_section(
            'thumbnail_section',
            [
                'label'    => esc_html__( 'Thumbnail Settings', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'         => 'thumbnail',
                    'default'      => 'large'
                ]
            );
        $widget->end_controls_section();
        // Excerpt
        $widget->start_controls_section(
            'excerpt_section',
            [
                'label'    => esc_html__( 'Excerpt Options', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'excerpt_lenght',
                [
                    'label'     => esc_html__( 'Excerpt lenght', 'solatec' ),
                    'type'      => Controls_Manager::NUMBER,
                    'default'   => 25,
                    'separator' => 'after'
                ]
            );
            $widget->add_control(
                'excerpt_more_text',
                [
                    'label'     => esc_html__( 'Excerpt more text', 'solatec' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => '...',
                    'separator' => 'after'
                ]
            );
        $widget->end_controls_section();
        // Readmore 
        $widget->start_controls_section(
            'readmore_section',
            [
                'label'    => esc_html__( 'Read More Options', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'readmore_text',
                [
                    'label'     => esc_html__( 'Read More Text', 'solatec' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__('Read More','solatec'),
                    'separator' => 'after'
                ]
            );
        $widget->end_controls_section();
        // Other Info
        $widget->start_controls_section(
            'other_section',
            [
                'label'    => esc_html__( 'Other Info', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'other_text',
                [
                    'label'     => esc_html__( 'Text', 'solatec' ),
                    'type'      => Controls_Manager::TEXTAREA,
                    'default'   => '',
                    'separator' => 'after'
                ]
            );
            $widget->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'         => 'other_text_typo',
                    'default'      => '',
                    'selector'     => '{{WRAPPER}} .other-text',
                    'condition' => [
                        'other_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'other_text_color',
                [
                    'label'       => esc_html__( 'Text Color', 'solatec' ),
                    'type'        => Controls_Manager::SELECT,
                    'options'     => solatec_elementor_theme_color_opts(['custom' => false]),  
                    'default'     => '',
                    'selector'     => '{{WRAPPER}} .other-text',
                    'condition'   => [
                        'other_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'other_link_text',
                [
                    'label'     => esc_html__( 'Link Text', 'solatec' ),
                    'type'      => Controls_Manager::TEXTAREA,
                    'default'   => '',
                    'separator' => 'after'
                ]
            );
            $widget->add_control(
                'other_link',
                [
                    'label'     => esc_html__( 'Your Link', 'solatec' ),
                    'type'      => Controls_Manager::URL,
                    'default'   => [
                        'is_external' => 'on'
                    ],
                    'separator' => 'after',
                    'condition' => [
                        'other_link_text!' => ''
                    ]
                ]
            );
            $widget->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'         => 'other_link_typo',
                    'default'      => '',
                    'selector'     => '{{WRAPPER}} a[data-other-link]',
                    'condition' => [
                        'other_link_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'other_link_color',
                [
                    'label'       => esc_html__( 'Text Color', 'solatec' ),
                    'type'        => Controls_Manager::SELECT,
                    'options'     => solatec_elementor_theme_color_opts(['custom' => false]),  
                    'default'     => '',
                    'selectors'     => [
                        '{{WRAPPER}} a[data-other-link]' => 'color: var(--color-{{VALUE}});',
                    ],
                    'condition'   => [
                        'other_link_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'other_link_color_hover',
                [
                    'label'       => esc_html__( 'Link Color Hover', 'solatec' ),
                    'type'        => Controls_Manager::SELECT,
                    'options'     => solatec_elementor_theme_color_opts(['custom' => false]),  
                    'default'     => '',
                    'selectors'     => [
                        '{{WRAPPER}} a[data-other-link]:hover' => 'color:var(--color-{{VALUE}})',
                    ],
                    'condition'   => [
                        'other_link_text!' => ''
                    ]
                ]
            );
        $widget->end_controls_section();
        solatec_doctor_infomation_opts($widget);
    }
}