<?php
use Elementor\Controls_Manager;
if (!function_exists('solatec_widget_cms_post_featured_register_controls')) {
    add_action('etc_widget_cms_post_featured_register_controls', 'solatec_widget_cms_post_featured_register_controls', 10, 1);
    function solatec_widget_cms_post_featured_register_controls($widget)
    {
        // Layout Section Start
        $widget->start_controls_section('layout_section', [
            'label' => esc_html__('Layout', 'solatec'),
            'tab' => Controls_Manager::TAB_LAYOUT
        ]);
            solatec_elementor_text_align($widget, ['default' => '']);
            $widget->add_control(
                'layout', [
                    'label'        => esc_html__('Templates', 'solatec'),
                    'type'         => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default'      => '1',
                    'options'      => [
                        '1' => [
                            'label'      => esc_html__( 'Layout 1', 'solatec' ),
                            'image'      => get_template_directory_uri() . '/elementor/templates/widgets/cms_post_featured/layout-images/1.png'
                        ],
                    ],
                    'prefix_class' => 'cms-post-featured-layout-'
                ]
            );
        $widget->end_controls_section();
        // Background
        $widget->start_controls_section(
            'background_section',
            [
                'label'    => esc_html__( 'Background', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'background',
                [
                    'label'       => esc_html__( 'Background Image', 'solatec' ),
                    'description' => esc_html__( 'Choose Background. Default is post featured image', 'solatec' ),
                    'type'        => Controls_Manager::MEDIA
                ]
            );
            $widget->add_control(
                'bg_overlay',
                [
                    'label'       => esc_html__( 'Background Overlay', 'solatec' ),
                    'type'        => Controls_Manager::SELECT,
                    'label_block' => true,
                    'options'     => [
                        ''       => esc_html__('Default', 'solatec'),
                        'none'   => esc_html__('None', 'solatec'),
                        'custom' => esc_html__('Custom', 'solatec'),
                    ],
                    'default' => ''
                ]
            );
            $widget->add_control(
                'bg_overlay_color',
                [
                    'label'       => esc_html__( 'Background Overlay Color', 'solatec' ),
                    'type'        => Controls_Manager::COLOR,
                    'options'     => '',  
                    'default'     => '',
                    'condition'   => [
                        'bg_overlay!' => 'none'
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .cms-post-featured-gradient' => 'background-color: {{VALUE}};'
                    ]
                ]
            );
            $widget->add_control(
                'bg_overlay_color_stop',
                [
                    'label'      => _x( 'Location', 'Background Control', 'solatec' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => [ '%' ],
                    'default'    => [
                        'unit' => '%',
                        'size' => 0,
                    ],
                    'render_type' => 'ui',
                    'of_type'     => 'gradient',
                    'condition'   => [
                        'bg_overlay' => ['custom']
                    ]
                ]
            );
            $widget->add_control(
                'bg_overlay_color_b',
                [
                    'label'       => _x( 'Second Color', 'Background Control', 'solatec' ),
                    'type'        => Controls_Manager::COLOR,
                    'default'     => '#f2295b',
                    'render_type' => 'ui',
                    'condition'   => [
                        'bg_overlay' => ['custom']
                    ],
                    'of_type' => 'gradient'
                ]
            );
            $widget->add_control(
                'bg_overlay_color_b_stop',
                [
                    'label'      => _x( 'Location', 'Background Control', 'solatec' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => [ '%' ],
                    'default'    => [
                        'unit' => '%',
                        'size' => 100,
                    ],
                    'render_type' => 'ui',
                    'condition'   => [
                        'bg_overlay'      => [ 'custom' ],
                    ],
                    'of_type' => 'gradient'
                ]
            );
            $widget->add_control(
                'bg_overlay_type',
                [
                    'label'   => _x( 'Type', 'Background Control', 'solatec' ),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'linear' => _x( 'Linear', 'Background Control', 'solatec' ),
                        'radial' => _x( 'Radial', 'Background Control', 'solatec' ),
                    ],
                    'default'     => 'linear',
                    'render_type' => 'ui',
                    'condition'   => [
                        'bg_overlay'      => [ 'custom' ],
                    ],
                    'of_type' => 'gradient'
                ]
            );
            $widget->add_control(
                'bg_overlay_angle',
                [
                    'label'      => _x( 'Angle', 'Background Control', 'solatec' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => [ 'deg' ],
                    'default'    => [
                        'unit' => 'deg',
                        'size' => 180,
                    ],
                    'range' => [
                        'deg' => [
                            'step' => 10,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .cms-post-featured-gradient' => 'background-color: transparent; background-image: linear-gradient({{SIZE}}{{UNIT}}, {{bg_overlay_color.VALUE}} {{bg_overlay_color_stop.SIZE}}{{bg_overlay_color_stop.UNIT}}, {{bg_overlay_color_b.VALUE}} {{bg_overlay_color_b_stop.SIZE}}{{bg_overlay_color_b_stop.UNIT}})',
                    ],
                    'condition' => [
                        'bg_overlay'      => [ 'custom' ],
                        'bg_overlay_type' => 'linear',
                    ],
                    'of_type' => 'gradient'
                ]
            );
            $widget->add_control(
                'bg_overlay_position',
                [
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'center center' => _x( 'Center Center', 'Background Control', 'solatec' ),
                        'center left'   => _x( 'Center Left', 'Background Control', 'solatec' ),
                        'center right'  => _x( 'Center Right', 'Background Control', 'solatec' ),
                        'top center'    => _x( 'Top Center', 'Background Control', 'solatec' ),
                        'top left'      => _x( 'Top Left', 'Background Control', 'solatec' ),
                        'top right'     => _x( 'Top Right', 'Background Control', 'solatec' ),
                        'bottom center' => _x( 'Bottom Center', 'Background Control', 'solatec' ),
                        'bottom left'   => _x( 'Bottom Left', 'Background Control', 'solatec' ),
                        'bottom right'  => _x( 'Bottom Right', 'Background Control', 'solatec' ),
                    ],
                    'default'   => 'center center',
                    'selectors' => [
                        '{{WRAPPER}} .cms-post-featured-gradient' => 'background-color: transparent; background-image: radial-gradient(at {{VALUE}}, {{bg_overlay_color.VALUE}} {{bg_overlay_color_stop.SIZE}}{{bg_overlay_color_stop.UNIT}}, {{bg_overlay_color_b.VALUE}} {{bg_overlay_color_b_stop.SIZE}}{{bg_overlay_color_b_stop.UNIT}})',
                    ],
                    'condition' => [
                        'bg_overlay'      => [ 'custom' ],
                        'bg_overlay_type' => 'radial',
                    ],
                    'of_type' => 'gradient'
                ]
            );
        $widget->end_controls_section();
        // Heading
        $widget->start_controls_section(
            'heading_section',
            [
                'label'    => esc_html__( 'Heading', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'selected_icon',
                [
                    'label'            => esc_html__( 'Icon', 'solatec' ),
                    'type'             => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'default'          => [
                        'value'     => 'cmsi-solar-panel',
                        'library'   => 'cmsi',
                    ]
                ]
            );
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'solatec' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Enter your title. Default is title of post', 'solatec' ),
                    'label_block' => true
                ]
            );
            $widget->add_control(
                'heading_color',
                [
                    'label'       => esc_html__( 'Heading Color', 'solatec' ),
                    'type'        => Controls_Manager::SELECT,
                    'options'     => solatec_elementor_theme_color_opts(),  
                    'default'     => '',
                    'label_block' => true
                ]
            );
            $widget->add_control(
                'heading_custom_color',
                [
                    'label'       => esc_html__( 'Custom Heading Color', 'solatec' ),
                    'type'        => Controls_Manager::COLOR,
                    'label_block' => true,
                    'condition'   => [
                        'heading_color'      => 'custom'
                    ]
                ]
            );
            $widget->add_control(
                'heading_animation',
                [
                    'label' => esc_html__( 'Motion Effect', 'solatec' ),
                    'type' => Controls_Manager::ANIMATION,
                    'condition'   => [
                        'heading_text!' => ''
                    ]
                ]
            );
        $widget->end_controls_section();
        // Sub Heading
        $widget->start_controls_section(
            'subheading_section',
            [
                'label'    => esc_html__( 'Sub Heading', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'subheading_text',
                [
                    'label'       => esc_html__( 'Sub Heading', 'solatec' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Enter your sub title', 'solatec' ),
                    'label_block' => true,
                    'condition'   => []
                ]
            );
            $widget->add_control(
                'subheading_color',
                [
                    'label'       => esc_html__( 'Sub Heading Color', 'solatec' ),
                    'type'        => Controls_Manager::SELECT,
                    'options'     => solatec_elementor_theme_color_opts(),  
                    'default'     => '',
                    'label_block' => true
                ]
            );
            $widget->add_control(
                'sheading_custom_color',
                [
                    'label'       => esc_html__( 'Custom Sub Heading Color', 'solatec' ),
                    'type'        => Controls_Manager::COLOR,
                    'label_block' => true,
                    'condition'   => [
                        'subheading_color'      => 'custom'
                    ]
                ]
            );
            $widget->add_control(
                'subheading_animation',
                [
                    'label' => esc_html__( 'Motion Effect', 'solatec' ),
                    'type' => Controls_Manager::ANIMATION,
                    'condition'   => [
                        'subheading_text!' => ''
                    ]
                ]
            );
        $widget->end_controls_section();
        // Description
        $widget->start_controls_section(
            'desc_section',
            [
                'label'    => esc_html__( 'Description', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'description_text',
                [
                    'label'       => esc_html__( 'Description', 'solatec' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Enter your description. Default is excerpt', 'solatec' ),
                    'rows'        => 10,
                    'show_label'  => false,
                    'condition'   => []
                ]
            );
            $widget->add_control(
                'description_color',
                [
                    'label'       => esc_html__( 'Description Color', 'solatec' ),
                    'type'        => Controls_Manager::SELECT,
                    'options'     => solatec_elementor_theme_color_opts(),  
                    'default'     => '',
                    'label_block' => true
                ]
            );
            $widget->add_control(
                'description_custom_color',
                [
                    'label'       => esc_html__( 'Custom Description Color', 'solatec' ),
                    'type'        => Controls_Manager::COLOR,
                    'label_block' => true,
                    'condition'   => [
                        'description_color'      => 'custom'
                    ]
                ]
            );
            $widget->add_control(
                'description_animation',
                [
                    'label' => esc_html__( 'Motion Effect', 'solatec' ),
                    'type' => Controls_Manager::ANIMATION,
                    'condition'   => [
                        'description_text!' => ''
                    ]
                ]
            );
        $widget->end_controls_section();
        // Button
        $widget->start_controls_section(
            'button_section',
            [
                'label'    => esc_html__( 'Buttons', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            solatec_elementor_button_settings($widget, [
                'btn_text'         => 'Schedule A Visit',
                'btn_type_default' => 'just-link',
            ]);
        $widget->end_controls_section();
        // Breadcrumb
        $widget->start_controls_section(
            'breadcrumb_section',
            [
                'label'    => esc_html__( 'Breadcrumb', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'show_breadcrumb',
                [
                    'label'       => esc_html__( 'Show Breadcrumb', 'solatec' ),
                    'type'        => Controls_Manager::SELECT,
                    'default'     => '1',
                    'options'      => [
                        '1' => esc_html__('Yes', 'solatec'),
                        '0' => esc_html__('No', 'solatec')
                    ]
                ]
            );
            $widget->add_control(
                'breadcrumb_link_color',
                [
                    'label'       => esc_html__( 'Breadcrumb Link Color', 'solatec' ),
                    'type'        => Controls_Manager::SELECT,
                    'options'     => solatec_elementor_theme_color_opts(),  
                    'default'     => '',
                    'label_block' => true,
                    'condition'   => [
                        'show_breadcrumb'      => '1'
                    ],
                    'separator'     => 'before'
                ]
            );
            $widget->add_control(
                'breadcrumb_link_custom_color',
                [
                    'label'       => esc_html__( 'Custom Breadcrumb Color', 'solatec' ),
                    'type'        => Controls_Manager::COLOR,
                    'condition'   => [
                        'breadcrumb_link_color'      => 'custom'
                    ]
                ]
            );
            $widget->add_control(
                'breadcrumb_color',
                [
                    'label'       => esc_html__( 'Breadcrumb Color', 'solatec' ),
                    'type'        => Controls_Manager::SELECT,
                    'options'     => solatec_elementor_theme_color_opts(),  
                    'default'     => '',
                    'label_block' => true,
                    'condition'   => [
                        'show_breadcrumb'      => '1'
                    ],
                    'separator'     => 'before'
                ]
            );
            $widget->add_control(
                'breadcrumb_custom_color',
                [
                    'label'       => esc_html__( 'Custom Breadcrumb Color', 'solatec' ),
                    'type'        => Controls_Manager::COLOR,
                    'condition'   => [
                        'breadcrumb_color'      => 'custom'
                    ]
                ]
            );
        $widget->end_controls_section();
    }
}