<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
if (!function_exists('solatec_widget_cms_post_grid_register_controls')) {
    add_action('etc_widget_cms_post_grid_register_controls', 'solatec_widget_cms_post_grid_register_controls', 10, 1);
    function solatec_widget_cms_post_grid_register_controls($widget)
    {
        // Layout Section Start
        $widget->start_controls_section('layout_section', [
            'label' => esc_html__('Layout', 'solatec'),
            'tab' => Controls_Manager::TAB_LAYOUT
        ]);
            $widget->add_control(
                'layout', [
                    'label'        => esc_html__('Templates', 'solatec'),
                    'type'         => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default'      => '1',
                    'options'      => solatec_elementor_post_layout(),
                    'prefix_class' => 'cms-post-layout-'
                ]
            );
        $widget->end_controls_section();
        // Source
        $widget->start_controls_section(
            'source_section',
            [
                'label'    => esc_html__( 'Source Options', 'solatec' ),
                'tab'      => \Elementor\Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'post_type',
                [
                    'label'    => esc_html__( 'Select Post Type', 'solatec' ),
                    'type'     => \Elementor\Controls_Manager::SELECT,
                    'multiple' => true,
                    'options'  => etc_get_post_type_options(),
                    'default'  => 'post'
                ]
            );
            etc_get_grid_term_by_post_type_options($widget);
            $widget->add_control(
                'orderby',
                [
                    'label'   => esc_html__( 'Order By', 'solatec' ),
                    'type'    => \Elementor\Controls_Manager::SELECT,
                    'default' => 'date',
                    'options' => [
                        'date'   => esc_html__( 'Date', 'solatec' ),
                        'ID'     => esc_html__( 'ID', 'solatec' ),
                        'author' => esc_html__( 'Author', 'solatec' ),
                        'title'  => esc_html__( 'Title', 'solatec' ),
                        'rand'   => esc_html__( 'Random', 'solatec' ),
                    ]
                ]
            );
            $widget->add_control(
                'order',
                [
                    'label'   => esc_html__( 'Sort Order', 'solatec' ),
                    'type'    => \Elementor\Controls_Manager::SELECT,
                    'default' => 'desc',
                    'options' => [
                        'desc' => esc_html__( 'Descending', 'solatec' ),
                        'asc'  => esc_html__( 'Ascending', 'solatec' ),
                    ]
                ]
            );
            $widget->add_control(
                'limit',
                [
                    'label'   => esc_html__( 'Items to show', 'solatec' ),
                    'type'    => \Elementor\Controls_Manager::NUMBER,
                    'default' => '6'
                ]
            );
        $widget->end_controls_section();
        solatec_elementor_masonry_settings($widget);
        solatec_elementor_masonry_filter_settings($widget);
        solatec_elementor_masonry_column_settings($widget);
        solatec_elementor_masonry_pagination_settings($widget);
        //
        $widget->start_controls_section(
            'thumbnail_section',
            [
                'label'    => esc_html__( 'Thumbnail Settings', 'solatec' ),
                'tab'      => \Elementor\Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'         => 'thumbnail',
                    'control_type' => 'group',
                    'default'      => 'full'
                ]
            );
        $widget->end_controls_section();
        //
        $widget->start_controls_section(
            'excerpt_section',
            [
                'label'    => esc_html__( 'Excerpt Options', 'solatec' ),
                'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout!' => ['4']
                ]
            ]
        );
            $widget->add_control(
                'excerpt_lenght',
                [
                    'label'     => esc_html__( 'Excerpt lenght', 'solatec' ),
                    'type'      => \Elementor\Controls_Manager::NUMBER,
                    'default'   => 25,
                    'separator' => 'after'
                ]
            );
            $widget->add_control(
                'excerpt_more_text',
                [
                    'label'     => esc_html__( 'Excerpt more text', 'solatec' ),
                    'type'      => \Elementor\Controls_Manager::TEXT,
                    'default'   => '...',
                    'separator' => 'after'
                ]
            );
        $widget->end_controls_section();
        //
        $widget->start_controls_section(
            'readmore_section',
            [
                'label'    => esc_html__( 'Read More Options', 'solatec' ),
                'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout!' => ['4']
                ]
            ]
        );
            $widget->add_control(
                'readmore_text',
                [
                    'label'     => esc_html__( 'Read More Text', 'solatec' ),
                    'type'      => \Elementor\Controls_Manager::TEXT,
                    'default'   => esc_html__('Read More','solatec'),
                    'separator' => 'after'
                ]
            );
        $widget->end_controls_section();
    }
}