<?php
use Elementor\Controls_Manager;
use Elementor\Repeater;
if (!function_exists('solatec_widget_cms_socials_register_controls')) {
    add_action('etc_widget_cms_socials_register_controls', 'solatec_widget_cms_socials_register_controls', 10, 1);
    function solatec_widget_cms_socials_register_controls($widget)
    {
        // Layout Section Start
        $widget->start_controls_section('layout_section', [
            'label' => esc_html__('Layout', 'solatec'),
            'tab' => Controls_Manager::TAB_LAYOUT
        ]);
        	solatec_elementor_row_align($widget);
            $widget->add_control('layout', [
                'label'   => esc_html__('Templates', 'solatec'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
	                '1' => [
	                    'label' => esc_html__( 'Layout 1', 'solatec' ),
	                    'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_socials/layout-images/1.png'
	                ],
	                '2' => [
	                    'label' => esc_html__( 'Layout 2', 'solatec' ),
	                    'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_socials/layout-images/2.png'
	                ],
	                '3' => [
	                    'label' => esc_html__( 'Layout 3', 'solatec' ),
	                    'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_socials/layout-images/3.png'
	                ],
	            ],
	            'prefix_class' => 'cms-socials-layout-'
            ]);
        $widget->end_controls_section();
        // Content
        $widget->start_controls_section(
        	'social_section',
			[
				'label'    => esc_html__( 'Socials Settings', 'solatec' ),
				'tab'      => Controls_Manager::TAB_CONTENT
			]
        );
        	$socials = new Repeater();
        	$socials->add_control(
        		'social_name',
				[
					'label'       => esc_html__( 'Name', 'solatec' ),
					'type'        => Controls_Manager::TEXT,
					'label_block' => true
				]
        	);
        	$socials->add_control(
        		'social_link',
				[
					'label'       => esc_html__( 'Link', 'solatec' ),
					'type'        => Controls_Manager::URL,
					'placeholder' => esc_html__('https://your-link.com', 'solatec' ),
					'label_block' => true
				]
        	);
        	$socials->add_control(
        		'social_icon',
				[
					'label'            => esc_html__( 'Icon', 'solatec' ),
					'type'             => Controls_Manager::ICONS,
					'fa4compatibility' => 'social',
					'default'          => []
				]
        	);
        	$widget->add_control(
        		'social_list',
				[
					'label'    => esc_html__( 'Social Lists', 'solatec' ),
					'type'     => Controls_Manager::REPEATER,
					'fields'   => $socials->get_controls(),
					'default' => [
                        [
							'social_name' => 'Facebook',
							'social_link' => [
								'url'         => 'https://facebook.com',
								'is_external' => 'on'
							],
							'social_icon' => [
								'value'   => 'cmsi-facebook-f',
								'library' => 'cmsi',
							]
                        ],
                        [
							'social_name' => 'Twitter',
							'social_link' => [
								'url'         => 'https://twitter.com',
								'is_external' => 'on'
							],
							'social_icon' => [
								'value'   => 'cmsi-twitter',
								'library' => 'cmsi',
							]
                        ],
                        [
							'social_name' => 'Linkedin',
							'social_link' => [
								'url'         => 'https://linkedin.com',
								'is_external' => 'on'
							],
							'social_icon' => [
								'value'   => 'cmsi-linkedin-in',
								'library' => 'cmsi',
							]
                        ]
                    ],
                    'title_field' => '{{{ elementor.helpers.renderIcon( this, social_icon, {}, "i", "panel" ) || \'<i class="{{ icon }}" aria-hidden="true"></i>\' }}} {{{ social_name }}}'
				]
        	);
        	$widget->add_control(
        		'social_shape',
				[
					'label'   => esc_html__( 'Shape', 'solatec' ),
					'type'    => Controls_Manager::SELECT,
					'default' => '',
					'options' => [
						''        => esc_html__('Default', 'solatec'),
						'rounded' => esc_html__( 'Rounded', 'solatec' ),
						'square'  => esc_html__( 'Square', 'solatec' ),
						'circle'  => esc_html__( 'Circle', 'solatec' ),
					],
					'prefix_class' => 'cms-shape-'
				]
        	);
        	$widget->add_control(
        		'social_shape_round',
				[
					'label'      => esc_html__( 'Icon Rounded', 'solatec' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%' ],
					'selectors'  => [
                        '{{WRAPPER}} a, {{WRAPPER}} .cms-icon-wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                    ],
                    'condition' => [
                        'social_shape'    => ['rounded']                            
                    ]
				]
        	);
        	$widget->add_control(
        		'social_size',
	            [
	            	'label' => esc_html__( 'Size', 'solatec' ),
	                'type'  => Controls_Manager::SLIDER,
	                'range' => [
	                    'px' => [
	                        'min' => 20,
	                        'max' => 200,
	                    ],
	                ],
	                'default' => [
						'size' => '20',
					],
	                'selectors' => [
	                    '{{WRAPPER}} .cms-icon-wrap' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};',
	                ]
	            ]
        	);
        	$widget->add_control(
        		'social_icon_size',
	            [
	            	'label' => esc_html__( 'Icon Size', 'solatec' ),
	                'type'  => Controls_Manager::SLIDER,
	                'range' => [
	                    'px' => [
	                        'min' => 10,
	                        'max' => 50,
	                    ],
	                ],
	                'default' => [
						'size' => '10',
					],
	                'selectors' => [
	                    '{{WRAPPER}} .cms-icon' => 'font-size: {{SIZE}}{{UNIT}};',
	                ]
	            ]
        	);
        	solatec_elementor_theme_colors($widget, [
				'name'            => 'social_icon_color',
				'label'           => esc_html__('Icon Color','solatec'),
				'custom_name'     => 'social_icon_color_custom',
				'custom_label'    => esc_html__('Custom Icon Color','solatec'),
				'custom_selector' => '.cms-icon'
			]);
			solatec_elementor_theme_colors($widget, [
				'name'            => 'social_icon_color_hover',
				'label'           => esc_html__('Hover Color','solatec'),
				'custom_name'     => 'social_icon_color_hover_custom',
				'custom_label'    => esc_html__('Custom Hover Color','solatec'),
				'custom_selector' => 'a:hover .cms-icon'
			]);
            solatec_elementor_theme_colors($widget, [
				'name'            => 'social_bg_color',
				'label'           => esc_html__('Background Color','solatec'),
				'custom_name'     => 'social_bg_color_custom',
				'custom_label'    => esc_html__('Custom Background Color','solatec'),
				'custom_selector' => '.cms-icon-wrap',
				'custom_selector_tag' => 'background-color'
			]);
			solatec_elementor_theme_colors($widget, [
				'name'                => 'social_bg_color_hover',
				'label'               => esc_html__('Background Hover Color','solatec'),
				'custom_name'         => 'social_bg_color_hover_custom',
				'custom_label'        => esc_html__('Custom Background Hover Color','solatec'),
				'custom_selector'     => 'a:hover .cms-icon-wrap',
				'custom_selector_tag' => 'background-color'
			]);
        $widget->end_controls_section();
    }
}