<?php
use Elementor\Controls_Manager;
use Elementor\Repeater;
if (!function_exists('solatec_widget_cms_teams_register_controls')) {
    add_action('etc_widget_cms_teams_register_controls', 'solatec_widget_cms_teams_register_controls', 10, 1);
    function solatec_widget_cms_teams_register_controls($widget)
    {
        // Layout Section Start
        $widget->start_controls_section('layout_section', [
            'label' => esc_html__('Layout', 'solatec'),
            'tab' => Controls_Manager::TAB_LAYOUT
        ]);
            solatec_elementor_row_align($widget);
            $widget->add_control('layout', [
                'label'   => esc_html__('Templates', 'solatec'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__('Layout 1', 'solatec' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_teams/layout-images/1.png'
                    ],
                    '2' => [
                        'label' => esc_html__('Layout 2', 'solatec' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_teams/layout-images/2.png'
                    ],
                ],
                'prefix_class' => 'cms-teams-layout-'
            ]);
        $widget->end_controls_section();
        // Slider Settings
        solatec_elementor_slick_slider_settings($widget, [
            'tab' => Controls_Manager::TAB_LAYOUT,
        ]);
        // Heading
        $widget->start_controls_section(
            'heading_section',
            [
                'label'    => esc_html__( 'Heading', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'solatec' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'placeholder' => esc_html__( 'Enter your title', 'solatec' ),
                    'label_block' => true
                ]
            );
            $widget->add_control(
                'heading_color',
                [
                    'label'       => esc_html__( 'Heading Color', 'solatec' ),
                    'type'        => Controls_Manager::SELECT,
                    'options'     => solatec_elementor_theme_color_opts(),  
                    'default'     => '',
                    'label_block' => false,
                    'condition'   => [
                        'heading_text!'      => ''
                    ]
                ]
            );
            $widget->add_control(
                'heading_custom_color',
                [
                    'label'       => esc_html__( 'Custom Heading Color', 'solatec' ),
                    'type'        => Controls_Manager::COLOR,
                    'label_block' => false,
                    'condition'   => [
                        'heading_color'      => 'custom'
                    ]
                ]
            );
            $widget->add_control(
                'heading_animation',
                [
                    'label'       => esc_html__( 'Motion Effect', 'solatec' ),
                    'type'        => Controls_Manager::ANIMATION,
                    'label_block' => false,
                    'condition'   => [
                        'heading_text!' => ''
                    ]
                ]
            );
        $widget->end_controls_section();
        // Sub Heading
        $widget->start_controls_section(
            'subheading_section',
            [
                'label'    => esc_html__( 'Sub Heading', 'solatec' ),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'subheading_text',
                [
                    'label'       => esc_html__( 'Sub Heading', 'solatec' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'placeholder' => esc_html__( 'Enter your sub title', 'solatec' ),
                    'label_block' => true,
                    'condition'   => []
                ]
            );
            $widget->add_control(
                'subheading_color',
                [
                    'label'       => esc_html__( 'Sub Heading Color', 'solatec' ),
                    'type'        => Controls_Manager::SELECT,
                    'options'     => solatec_elementor_theme_color_opts(),  
                    'default'     => '',
                    'label_block' => false,
                    'condition'   => [
                        'subheading_text!'      => ''
                    ]
                ]
            );
            $widget->add_control(
                'sheading_custom_color',
                [
                    'label'       => esc_html__( 'Custom Sub Heading Color', 'solatec' ),
                    'type'        => Controls_Manager::COLOR,
                    'label_block' => false,
                    'condition'   => [
                        'subheading_color'      => 'custom'
                    ]
                ]
            );
            $widget->add_control(
                'subheading_animation',
                [
                    'label'       => esc_html__( 'Motion Effect', 'solatec' ),
                    'type'        => Controls_Manager::ANIMATION,
                    'label_block' => false,
                    'condition'   => [
                        'subheading_text!' => ''
                    ]
                ]
            );
        $widget->end_controls_section();
        // Team Lists
        $widget->start_controls_section(
            'teams_list',
            [
                'label'    => esc_html__('Teams', 'solatec'),
                'tab'      => Controls_Manager::TAB_CONTENT
            ]
        );
            $teams = new Repeater();
            $teams->add_control(
                'image',
                [
                    'label'       => esc_html__('Image', 'solatec'),
                    'type'        => Controls_Manager::MEDIA,
                    'label_block' => true
                ]
            );
            $teams->add_control(
                'name',
                [
                    'label'       => esc_html__('Name', 'solatec'),
                    'type'        => Controls_Manager::TEXT,
                    'label_block' => true
                ]
            );
            $teams->add_control(
                'position',
                [
                    'label' => esc_html__('Position', 'solatec'),
                    'type'  => Controls_Manager::TEXT
                ]
            );
            $teams->add_control(
                'link',
                [
                    'label'       => esc_html__('Link', 'solatec' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'solatec' ),
                    'default'     => [
                        'url'         => '#',
                        'is_external' => 'on'
                    ]
                ]
            );
            $teams->add_control(
                'social',
                [
                    'label' => esc_html__( 'Social', 'solatec' ),
                    'type' => Elementor_Theme_Core::ICONS_CONTROL
                ]
            );
            $widget->add_control(
                'teams',
                [
                    'label'       => esc_html__('Add Item', 'solatec'),
                    'type'        => Controls_Manager::REPEATER,
                    'fields'      => $teams->get_controls(),  
                    'title_field' => '{{{ name }}}',
                    'default'     => [
                        [
                            'name'     => 'Mike Dooley',
                            'position' => 'Chief Executive',
                            'link'     => [
                                'url' => '#',
                                'is_extalnal' => 'true'
                            ],
                            'social'   => ''
                        ],
                        [
                            'name'     => 'Michael Brian',
                            'position' => 'Managing Director',
                            'social'   => ''
                        ],
                        [
                            'name'     => 'Chris Wensel',
                            'position' => 'Vice President',
                            'social'   => ''
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
    }
}