<?php
/**
 * Functions and definitions
 *
 * @package Solatec
 */
if(!function_exists('solatec_require_folder')){
    function solatec_require_folder($foldername,$path = '')
    {
        if($path === '') $path = get_template_directory();
        $dir = $path . DIRECTORY_SEPARATOR . $foldername;
        if (!is_dir($dir)) {
            return;
        }
        $files = array_diff(scandir($dir), array('..', '.'));
        foreach ($files as $file) {
            $patch = $dir . DIRECTORY_SEPARATOR . $file;
            if (file_exists($patch) && strpos($file, ".php") !== false) {
                require_once $patch;
            }
        }
    }
}
solatec_require_folder('inc');
solatec_require_folder('inc/theme-configs');
solatec_require_folder('inc/extends');
require_once get_template_directory().'/assets/fonts/cms-solatec/cms-font-solatec.php';

if ( ! function_exists( 'solatec_setup' ) ) {
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
    add_action( 'after_setup_theme', 'solatec_setup' );
	function solatec_setup() {
		// Make theme available for translation.
		load_theme_textdomain( 'solatec', get_template_directory() . '/languages' );
		// Custom Header
		add_theme_support( "custom-header" );
		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );
		// Let WordPress manage the document title.
		add_theme_support( 'title-tag' );
		/*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support( 'post-thumbnails' );
        // Set post thumbnail size.
        set_post_thumbnail_size( solatec_configs('thumbnail')['post_thumbnail_size_w'], solatec_configs('thumbnail')['post_thumbnail_size_h'] );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Solatec Primary', 'solatec' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
            'script',
            'style'
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'solatec_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Add support for core custom logo.
		add_theme_support( 'custom-logo', array(
			'height'      => solatec_configs('logo')['width'],
			'width'       => solatec_configs('logo')['height'],
			'flex-width'  => true,
			'flex-height' => true,
		) );
		add_theme_support( 'post-formats', array(
			'gallery',
			'video',
		) );
        // Add support for full and wide align images.
        //add_theme_support( 'align-wide' );
        // Enable support for WooCommerce.
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );
	}
}
/* Display Custom Image Sizes */
if(!function_exists('solatec_custom_sizes')){
    add_filter('image_size_names_choose','solatec_custom_sizes');
    function solatec_custom_sizes($sizes){
        return array_merge($sizes, array(
            'medium_large' => esc_html__('Medium Large', 'solatec')
        ));
    }
}
if(!function_exists('solatec_update')){
    add_action('after_switch_theme', 'solatec_update');
    function solatec_update(){
        /* Change default image thumbnail sizes in wordpress */
        $thumbnail_size = array(
            'large_size_w'        => solatec_configs('thumbnail')['large_size_w'],
            'large_size_h'        => solatec_configs('thumbnail')['large_size_h'],
            'large_crop'          => 1, 
            'medium_large_size_w' => solatec_configs('thumbnail')['medium_large_size_w'],
            'medium_large_size_h' => solatec_configs('thumbnail')['medium_large_size_h'],
            'medium_large_crop'   => 1, 
            'medium_size_w'       => solatec_configs('thumbnail')['medium_size_w'],
            'medium_size_h'       => solatec_configs('thumbnail')['medium_size_h'],
            'medium_crop'         => 1, 
            'thumbnail_size_w'    => solatec_configs('thumbnail')['thumbnail_size_w'],
            'thumbnail_size_h'    => solatec_configs('thumbnail')['thumbnail_size_h'],
            'thumbnail_crop'      => 1,
        );
        foreach ($thumbnail_size as $option => $value) {
            if (get_option($option, '') != $value)
                update_option($option, $value);
        }
    }
}
/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 */
// Set up the content width value based on the theme's design and stylesheet.
if(!function_exists('solatec_content_width')){
    add_action('after_setup_theme', 'solatec_content_width', 0);
    if (!isset($content_width))
        $content_width = apply_filters('solatec_content_width', solatec_configs('content_width'));
    function solatec_content_width()
    {
        $GLOBALS['content_width'] = apply_filters('solatec_content_width', solatec_configs('content_width'));
    }
}

// Add new menu Locations
add_action( 'cms_locations', function ( $cms_locations ) {
    //$cms_locations['cms-test'] ='Test Menu';
	return $cms_locations;
} );
/**
 * Register widget area.
 */
if(!function_exists('solatec_widgets_init')){
    add_action( 'widgets_init', 'solatec_widgets_init' );
    function solatec_widgets_init() {
    	if(class_exists('Elementor_Theme_Core')){
            $all_post_type = solatec_all_post_types();
            foreach ($all_post_type as $key => $value) {
                register_sidebar( array(
                    'name'          => sprintf( esc_html__( '%s Sidebar', 'solatec' ), $value ),
                    'id'            => 'sidebar-'.$key,
                    'description'   => sprintf(esc_html__( 'Add widgets here to show in %1$s archive page and single %2$s page', 'solatec' ), strtoupper(str_replace('-', ' ', $key)), $value),
                    'class'         => 'cms-post-type-widget',
                    'title_class'   => ''
                ) );
            }
            // Hidden sidebar
            register_sidebar( array(
                'name'          => esc_html__( 'Hidden Sidebar', 'solatec' ),
                'id'            => 'sidebar-hidden',
                'description'   => esc_html__( 'Add widgets here.', 'solatec' ),
                'class'         => 'cms-hidden-widget',
                'title_class'   => ''
            ) );
        } else {
            register_sidebar( array(
                'name'          => esc_html__( 'Blog Widgets', 'solatec' ),
                'id'            => 'sidebar-post',
                'description'   => esc_html__( 'Add widgets here to show on blog/archives/single post page', 'solatec' ),
                'class'         => 'cms-blog-widget',
                'title_class'   => ''
            ) );
            if(class_exists('WooCommerce')){
                register_sidebar( array(
                    'name'          => esc_html__( 'WooCommerce Widgets', 'solatec' ),
                    'id'            => 'sidebar-product',
                    'description'   => esc_html__( 'Add widgets here to show on woocommerce page', 'solatec' ),
                    'class'         => 'cms-blog-widget',
                    'title_class'   => ''
                ) );
            }
        }
    }
}
/**
 * Change default widget title structure
*/
if(!function_exists('solatec_widgets_title')){
    add_filter('widget_display_callback', 'solatec_widgets_structure');
    add_filter('register_sidebar_defaults', 'solatec_widgets_structure');
    function solatec_widgets_structure($args){
        $args = wp_parse_args($args, [
            'title_class' => ''
        ]);
        $widget_title_tag = 'div';
        $title_class = [
            'cms-widget-title',
            'cms-heading',
            isset($args['title_class']) ? $args['title_class'] : ''
        ];
        $args['before_widget'] = '<div id="%1$s" class="cms-widget %2$s"><div class="cms-widget-inner">';
        $args['after_widget']  = '</div></div>';
        $args['before_title']  = '<'.$widget_title_tag.' class="'.trim(implode(' ', $title_class)).'">';
        $args['after_title']   = '</'.$widget_title_tag.'>';
        return $args;
    }
}
/**
 * Enqueue scripts and styles.
 */
if(!function_exists('solatec_scripts')){
    add_action( 'wp_enqueue_scripts', 'solatec_scripts', 10);
    function solatec_scripts() {
    	$theme = wp_get_theme( get_template() );
        $dev_mode   = solatec_get_opt('dev_mode', false);
        if($dev_mode === '' || $dev_mode === '0' || $dev_mode === false){
            $min = '.min';
        } else {
            $min = '';
        }
        // google font
        //wp_enqueue_style( 'solatec-google-fonts', solatec_fonts_url() );
        // theme font icon
        wp_enqueue_style( 'solatec-icon', get_template_directory_uri() . '/assets/fonts/cms-solatec/styles.css', array(), $theme->get( 'Version' ) );
        // theme style
        wp_enqueue_style( 'solatec', get_template_directory_uri() . '/assets/css/theme'.$min.'.css', array(), $theme->get( 'Version' ) );
        wp_add_inline_style( 'solatec', solatec_inline_styles() );
        // WP Comment
        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
            wp_enqueue_script( 'comment-reply' );
        }
        // magnific-popup
        wp_register_script( 'magnific-popup', get_template_directory_uri() . '/assets/js/magnific-popup.min.js', array( 'jquery' ), '1.0.0', true );
        wp_register_style( 'magnific-popup', get_template_directory_uri() . '/assets/css/magnific-popup.css', array(), '1.0.0' );
        // smoothscroll
        $smoothscroll = solatec_get_opt( 'smoothscroll', false );
        if ( isset( $smoothscroll ) && $smoothscroll ) {
            wp_enqueue_script( 'smoothscroll', get_template_directory_uri() . '/assets/js/smoothscroll.min.js', array( 'jquery' ), 'all', true );
        }
        // sidebar fixed on scroll
        wp_register_script( 'solatec-sidebar-fixed', get_template_directory_uri() . '/assets/js/sidebar-scroll-fixed.js', array( 'jquery' ), '1.0.0', true );
        // Slick Slider 
        wp_register_script( 'jquery-slick', get_template_directory_uri() . '/assets/js/slick/slick.min.js', array( 'jquery' ), '1.8.1', true );
        wp_register_script('cms-jquery-slick', get_template_directory_uri() . '/elementor/js/cms-slick-slider.js', [ 'jquery-slick' ], $theme->get( 'Version' ), true);
        wp_enqueue_script( 'cms-jquery-slick');
        // Theme JS
    	wp_enqueue_script( 'solatec', get_template_directory_uri() . '/assets/js/main.js', array( 'jquery' ), $theme->get( 'Version' ), true );
    	wp_localize_script( 'solatec', 'main_data', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
        /*
         * Elementor Widget JS
         */
        // Accordion
        wp_register_script('cms-accordion', get_template_directory_uri() . '/elementor/js/cms-accordion.js', [ 'jquery' ], $theme->get( 'Version' ), true);
        // Counter
        wp_register_script('cms-counter', get_template_directory_uri() . '/elementor/js/cms-counter.js', [ 'jquery' ], $theme->get( 'Version' ), true);
        // Post Grid Widget
        wp_register_script('cms-post-grid', get_template_directory_uri() . '/elementor/js/cms-post-grid.js', [ 'isotope', 'jquery' ], $theme->get( 'Version' ), true);
        // Progress Bar Widget
        wp_register_script( 'cms-progressbar', get_template_directory_uri() . '/elementor/js/cms-progressbar.js', [ 'jquery' ], $theme->get( 'Version' ) );
        // Elementor Custom
        wp_enqueue_script('cms-elementor-custom-js', get_template_directory_uri() . '/elementor/js/elementor-custom.js', [ 'jquery' ], $theme->get( 'Version' ), true);
        /** 
         * @since 1.2.0
         * Swiper Slider
         * Animation
        */
        wp_register_script('cms-animation', get_template_directory_uri() . '/elementor/js/cms-animation.js', [ 'jquery' ], $theme->get( 'Version' ), true);
        wp_register_script('swiper', get_template_directory_uri() . '/elementor/js/swiper/swiper'.$min.'.js', [ 'jquery' ], $theme->get( 'Version' ), true);
        wp_register_script('cms-swiper', get_template_directory_uri() . '/elementor/js/cms-swiper.js', [ 'jquery','swiper' ], $theme->get( 'Version' ), true);
    }
}

/* add editor styles */
if(!function_exists('solatec_add_editor_styles')){
    add_action( 'admin_init', 'solatec_add_editor_styles' );
    function solatec_add_editor_styles() {
    	add_editor_style( 'editor-style.css' );
    }
}

/* add admin styles */
if(!function_exists('solatec_admin_style')){
    add_action( 'admin_enqueue_scripts', 'solatec_admin_style' );
    function solatec_admin_style() {
    	$theme = wp_get_theme( get_template() );
    	wp_enqueue_style( 'solatec-admin-style', get_template_directory_uri() . '/assets/css/admin.css' );
        wp_enqueue_script('solatec-main-admin', get_template_directory_uri() . '/assets/js/main-admin.js', array( 'jquery' ), $theme->get('Version'), true);

        wp_enqueue_style('solatec-get-started-css', get_template_directory_uri() . '/assets/css/get-started.css');
        wp_enqueue_script('solatec-get-started-js', get_template_directory_uri() . '/assets/js/get-started.js', ['jquery'], $theme->get('Version'), true);
        wp_localize_script('solatec-get-started-js', 'main_data', array('ajax_url' => admin_url('admin-ajax.php')));
        // icon
        wp_enqueue_style( 'solatec-icon', get_template_directory_uri() . '/assets/fonts/cms-solatec/styles.css', array(), $theme->get( 'Version' ) );
    }
}
add_action( 'elementor/editor/before_enqueue_scripts', function() {
    $theme = wp_get_theme( get_template() );
    wp_enqueue_style( 'solatec-icon', get_template_directory_uri() . '/assets/fonts/cms-solatec/styles.css', array(), $theme->get( 'Version' ) );
});
add_action('elementor/preview/enqueue_styles',  function() {
    $theme = wp_get_theme( get_template() );
    wp_enqueue_style( 'solatec-icon', get_template_directory_uri() . '/assets/fonts/cms-solatec/styles.css', array(), $theme->get( 'Version' ) );
});
/**
 * Register Google Fonts
 *
 * https://gist.github.com/kailoon/e2dc2a04a8bd5034682c
 * https://themeshaper.com/2014/08/13/how-to-add-google-fonts-to-wordpress-themes/
 *
*/
function solatec_fonts_url() {
    $font_url = add_query_arg( 
        'family', 
        urlencode(solatec_configs('google_fonts')), 
        "//fonts.googleapis.com/css"
    );
    return $font_url;
}

/**
 * Get custom post type slug
*/
if(!function_exists('solatec_custom_post_type_slug')){
    function solatec_custom_post_type_slug(){
        $post_types = get_post_types([
            'public'   => true,
            '_builtin' => true
        ], 'names');
        $DefaultExcludedPostTypes = [
            'page',
            'attachment',
            'revision',
            'nav_menu_item',
            'vc_grid_item',
            'custom_css',
            'customize_changeset',
            'oembed_cache',
            'cms-mega-menu',
            'elementor_library',
        ];
        $ExtraExcludedPostTypes = apply_filters('etc_get_post_types', []);
        $excludedPostTypes      = array_merge($DefaultExcludedPostTypes, $ExtraExcludedPostTypes );
        echo '<pre>';
            var_dump($post_types);
        echo   '</pre>'; //die();
        $result = [];
        if (!is_array($post_types))
            return $result;
        foreach ($post_types as $post_type) {
            if (!$post_type instanceof WP_Post_Type)
                continue;
            if (in_array($post_type->name, $excludedPostTypes))
                continue;
            $result[] = array(
                'id'       => $post_type->name.'-slug',
                'title'    => sprintf(esc_html__( 'Slug %s', 'solatec' ), $post_type->labels->singular_name),
                'subtitle' => esc_html__('Enter slug for custom post type archive','solatec'),
                'type'     => 'text'
            );
        }
  
        return $result;
    }
}

/**
 * Incudes file
 *
*/
solatec_require_folder('inc/classes');
solatec_require_folder('inc/theme-options');
solatec_require_folder('inc/cms-iconpicker');

/**
 * Additional widgets for the theme
 */
solatec_require_folder('widgets');
/**
 * Custom post type
*/
solatec_require_folder('inc/custom-post');
/**
 * Elementor
*/
solatec_require_folder('inc/elementor');
/**
 *  Woocommerce
 */
if(class_exists('Woocommerce')){
    solatec_require_folder('woocommerce');
}
/**
 * other extensions
*/
solatec_require_folder('inc/extensions');

if(!function_exists('elementor_frontend_custom_css')){
    //add_action('wp_enqueue_scripts','elementor_frontend_custom_css', 2);
    function elementor_frontend_custom_css(){
        wp_enqueue_style( 'elementor-frontend-legacy', get_template_directory_uri() . '/assets/css/elementor-frontend-legacy.css', array('solatec'), '1.0' );
    }
}

// remove comment cookies
remove_action( 'set_comment_cookies', 'wp_set_comment_cookies' );
// remove lazy load 
add_filter( 'wp_lazy_loading_enabled', '__return_false' );
/*
 * Get Started
 */
require_once get_template_directory() . '/inc/get-started.php';
/*
 * Get Started
 */

/**
 * Custom Elementor Editor
 * @since 2.0.6
 * */
add_action( 'elementor/editor/before_enqueue_scripts', function() {
    wp_enqueue_style( 'solatec-elementor-custom-panel', get_template_directory_uri() . '/assets/admin/elementor-panel.css', array(), '2.0.6' );
});
add_action('elementor/preview/enqueue_styles',  function() {
    wp_enqueue_style( 'solatec-elementor-custom-preview', get_template_directory_uri() . '/assets/admin/elementor-preview.css', array(), '2.0.6' );
});

/**
 * Remove Some CSS
 * @since 2.0.6
*/
if(!function_exists('etc_remove_scripts')){
    add_action( 'wp_enqueue_scripts', 'etc_remove_scripts', 999 );
    add_action( 'wp_footer', 'etc_remove_styles', 999 );
    add_action( 'wp_header', 'etc_remove_styles', 999 );
    function etc_remove_scripts() {
        $default = ['isotope' ];
        $scripts  = apply_filters( 'etc_remove_scripts', $default );
        foreach ( $scripts as $script ) {
            wp_dequeue_script( $script );
        }
    }
}
if(!function_exists('etc_remove_styles')){
    add_action( 'wp_enqueue_scripts', 'etc_remove_styles', 999 );
    add_action( 'wp_footer', 'etc_remove_styles', 999 );
    add_action( 'wp_header', 'etc_remove_styles', 999 );
    function etc_remove_styles() {
        $default = ['gglcptch', 'isotope' ];
        $styles  = apply_filters( 'etc_remove_styles', $default );
        foreach ( $styles as $style ) {
            wp_dequeue_style( $style );
        }
    }
}
if(!function_exists('solatec_remove_styles')){
    add_filter('etc_remove_styles', 'solatec_remove_styles');
    function solatec_remove_styles($styles){
        $_styles = [
            // newsletter
            'newsletter',
            // elementor
            'elementor-frontend-legacy',
            // woo
            'woocommerce-smallscreen',
            'woocommerce-general',
            'woocommerce-layout',
            'wc-blocks-vendors-style',
            'wc-blocks-style',
            // theme core
            'oc-css',
            'etc-main-css',
            'progressbar-lib-css',
            //'slick-css',
            'tco-main-css',
            // language switcher
            'trp-floater-language-switcher-style',
            'trp-language-switcher-style',
        ];
        $styles = array_merge($styles, $_styles);
        return $styles;
    }
}
if(!function_exists('solatec_default_fonts')){
    function solatec_default_fonts(){
        $body_font    = solatec_configs('body')['font-family'];
        $heading_font = solatec_configs('heading')['font-family'];
    ?>
        <link rel="preconnect" href="https://fonts.googleapis.com">
        <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
        <link href="https://fonts.googleapis.com/css2?family=<?php echo esc_attr($heading_font);?>:wght@400;500;600;700&family=<?php echo esc_attr($body_font); ?>:wght@400;700&display=swap" rel="stylesheet">
    <?php
    }
}
add_action('wp_footer','solatec_default_fonts');