<?php
/**
 * Get page title and description.
 *
 * @return array Contains 'title'
 */
function solatec_get_page_titles() {
	$title = '';
	// Default titles
	if ( ! is_archive() ) {
		// Posts page view
		if ( is_home() ) {
			// Only available if posts page is set.
			if ( ! is_front_page() && $page_for_posts = get_option( 'page_for_posts' ) ) {
				$title = get_post_meta( $page_for_posts, 'custom_title', true );
				if ( empty( $title ) ) {
					$title = get_the_title( $page_for_posts );
				}
			}
			if ( is_front_page() ) {
				$title = esc_html__( 'Welcome to', 'solatec' ).' '.get_bloginfo('name');
			}
		} // Single page view
        elseif ( is_page() ) {
			$title = get_post_meta( get_the_ID(), 'custom_title', true );
			if ( ! $title ) {
				$title = get_the_title();
			}
		} elseif ( is_404() ) {
			$title = esc_html__( '404', 'solatec' );
		} elseif ( is_search() ) {
			$title = esc_html__( 'Search results', 'solatec' );
		} else {
			$title = get_post_meta( get_the_ID(), 'custom_title', true );
			if(is_singular('post') && empty($title)) $title = esc_html__('Blog Post', 'solatec'); // get_the_title(); //
			if ( ! $title ) {
				$title = get_the_title();
			}
		}
	} elseif ( is_author() ) {
		$title = get_the_author();
	} else {
		//$title = get_the_archive_title();
		$title = single_term_title('', false);
		if( (class_exists( 'WooCommerce' ) && is_shop()) ) {
			$title = esc_html__( 'Our Products', 'solatec' );
		}
	}
	return array(
		'title' => $title,
	);
}

// Remove "Category:", "Tag:", "Author:" from the_archive_title
add_filter( 'get_the_archive_title', function ($title) {    
    if ( is_category() ) {    
            $title = single_cat_title( '', false );    
        } elseif ( is_tag() ) {    
            $title = single_tag_title( '', false );    
        } elseif ( is_author() ) {    
            $title = '<span class="vcard">' . get_the_author() . '</span>' ;    
        } elseif ( is_tax() ) { //for custom post types
            $title = sprintf( '%1$s' , single_term_title( '', false ) );
        } elseif (is_post_type_archive()) {
            $title = post_type_archive_title( '', false );
        }
    return $title;    
});