<?php
// Add custom field to section
if(!function_exists('solatec_custom_section_params')){
    add_filter('etc-custom-section/custom-params', 'solatec_custom_section_params'); 
    function solatec_custom_section_params(){
        return array(
            'sections' => array(
                array(
                    'name'     => 'cms_custom_layout',
                    'label'    => esc_html__( 'Custom Settings', 'solatec' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_LAYOUT,
                    'controls' => array(
                        // make section full content with a space on start / end
                        array(
                            'name'         => 'full_content_with_space',
                            'label'        => esc_html__( 'Full Content with space from?', 'solatec' ),
                            'type'         => \Elementor\Controls_Manager::SELECT,
                            'prefix_class' => 'cms-full-content-with-space-',
                            'options'      => array(
                                'none'    => esc_html__( 'None', 'solatec' ),
                                'start'   => esc_html__( 'Start', 'solatec' ),
                                'end'     => esc_html__( 'End', 'solatec' ),
                                'start-wide'   => esc_html__( 'Start (Container Wide)', 'solatec' ),
                                'end-wide'     => esc_html__( 'End (Container Wide)', 'solatec' ),
                            ),
                            'default'      => 'none',
                            'condition'    => [
                                'layout' => 'full_width'
                            ]
                        ),
                        // this field hasn't config prefix_class
                        // its value will be handled at solatec_custom_section_classes function
                        // screen shot - http://prntscr.com/tjco9g
                        array(
                            'name'    => 'column_hori_align',
                            'label'   => esc_html__( 'Horizontal Align', 'solatec' ),
                            'type'    => \Elementor\Controls_Manager::SELECT,
                            'options' => array(
                                ''        => esc_html__( 'Default', 'solatec' ),
                                'start'   => esc_html__( 'Start', 'solatec' ),
                                'center'  => esc_html__( 'Center', 'solatec' ),
                                'end'     => esc_html__( 'End', 'solatec' ),
                                'around'  => esc_html__( 'Space Around', 'solatec' ),
                                'between' => esc_html__( 'Space Between', 'solatec' ),
                                'center cms-justify-content-xxl-between' => esc_html__( 'Space Center - XXL Between', 'solatec' ),
                            ),
                            'prefix_class' => 'cms-justify-content-',
                            'default'      => '',
                        ),
                        array(
                            'name'         => 'cms_boxed_bg',
                            'label'        => esc_html__( 'Boxed Background', 'solatec' ),
                            'type'         => \Elementor\Controls_Manager::SWITCHER,
                            'prefix_class' => 'cms-boxed-bg-',
                            'default'      => 'false',
                            'condition'    => [
                                //'stretch_section' => ['section-stretched']
                            ] 
                        ),
                        array(
                            'name'         => 'cms_boxed_bg_background',
                            'type'         => \Elementor\Group_Control_Background::get_type(),
                            'control_type' => 'group',
                            'types'         => [ 'classic' ],
                            'fields_options' => [
                                'background' => [
                                    'frontend_available' => true,
                                ],
                            ],
                            'selector'  => '{{WRAPPER}} > .cms-section-boxed-bg',
                            'condition'    => [
                                'stretch_section' => ['section-stretched']
                            ]
                        )
                    ),
                ),
            ),
        );
    }
}

// add html to before row
if(!function_exists('solatec_boxed_bg')){
    add_filter('etc-custom-section/before-elementor-row', 'solatec_boxed_bg', 10 , 1);
    function solatec_boxed_bg($settings){
        return '<div class="cms-section-boxed-bg"></div>';
    }
}
// Custom Elementor Row Structure
if(!function_exists('solatec_custom_el_attributes')){
    //add_action( 'elementor/element/after_add_attributes', 'solatec_custom_el_attributes', 10, 1 );
    function solatec_custom_el_attributes($el){
        if( 'section' !== $el->get_name() ) {
            return;
        }
        $settings = $el->get_settings();
        if(!isset($settings['full_content_with_space'])) return;
        $pxl_container_width = (isset($settings['pxl_container_width']) && !empty($settings['pxl_container_width'])) ? $settings['pxl_container_width'].'px' : '1200px';
        $pxl_container_wide_width = (isset($settings['pxl_container_wide_width']) && !empty($settings['pxl_container_wide_width'])) ? $settings['pxl_container_wide_width'].'px' : '1320px';
        if ( $settings['full_content_with_space'] === 'start' ) {
            if(is_rtl()){
                $el->add_render_attribute( '_wrapper', 'style', 'padding-right: calc( (100% - '.$pxl_container_width.')/2);');
            } else {
                $el->add_render_attribute( '_wrapper', 'style', 'padding-left: calc( (100% - '.$pxl_container_width.')/2);');
            }
        } elseif($settings['full_content_with_space'] === 'end') {
            if(is_rtl()){
                $el->add_render_attribute( '_wrapper', 'style', 'padding-left: calc( (100% - '.$pxl_container_width.')/2);');
            } else {
                $el->add_render_attribute( '_wrapper', 'style', 'padding-right: calc( (100% - '.$pxl_container_width.')/2);');
            }
        } elseif ( $settings['full_content_with_space'] === 'start-wide' ) {
            if(is_rtl()){
                $el->add_render_attribute( '_wrapper', 'style', 'padding-right: calc( (100% - '.$pxl_container_wide_width.')/2);');
            } else {
                $el->add_render_attribute( '_wrapper', 'style', 'padding-left: calc( (100% - '.$pxl_container_wide_width.')/2);');
            }
        } elseif($settings['full_content_with_space'] === 'end-wide') {
            if(is_rtl()){
                $el->add_render_attribute( '_wrapper', 'style', 'padding-left: calc( (100% - '.$pxl_container_wide_width.')/2);');
            } else {
                $el->add_render_attribute( '_wrapper', 'style', 'padding-right: calc( (100% - '.$pxl_container_wide_width.')/2);');
            }
        }
    }
}
if(!function_exists('solatec_elementor_container_attrs')){
    //add_filter('etc-custom-section/etc-custom-section-container', 'solatec_elementor_container_attrs', 10, 1);
    function solatec_elementor_container_attrs($settings){
        if(!isset($settings['full_content_with_space'])) return;
        $pxl_container_width = (isset($settings['pxl_container_width']) && !empty($settings['pxl_container_width'])) ? $settings['pxl_container_width'].'px' : '1200px';
        $pxl_container_wide_width = (isset($settings['pxl_container_wide_width']) && !empty($settings['pxl_container_wide_width'])) ? $settings['pxl_container_wide_width'].'px' : '1320px';
        $attrs = [];
        if ( $settings['full_content_with_space'] === 'start' ) {
            if(is_rtl()){
                $attrs['style'] = 'padding-right: calc( (100% - '.$pxl_container_width.')/2);';
            } else {
                $attrs['style'] = 'padding-left: calc( (100% - '.$pxl_container_width.')/2);';
            }
        } elseif($settings['full_content_with_space'] === 'end') {
            if(is_rtl()){
                $attrs['style'] = 'padding-left: calc( (100% - '.$pxl_container_width.')/2);';
            } else {
                $attrs['style'] = 'padding-right: calc( (100% - '.$pxl_container_width.')/2);';
            }
        } elseif ( $settings['full_content_with_space'] === 'start-wide' ) {
            if(is_rtl()){
                $attrs['style'] = 'padding-right: calc( (100% - '.$pxl_container_wide_width.')/2);';
            } else {
                $attrs['style'] = 'padding-left: calc( (100% - '.$pxl_container_wide_width.')/2);';
            }
        } elseif($settings['full_content_with_space'] === 'end-wide') {
            if(is_rtl()){
                $attrs['style'] = 'padding-left: calc( (100% - '.$pxl_container_wide_width.')/2);';
            } else {
                $attrs['style'] = 'padding-right: calc( (100% - '.$pxl_container_wide_width.')/2);';
            }
        }
        return $attrs;
    }
}

if(!function_exists('solatec_custom_section_presets')){
    add_filter('etc-custom-section/custom-presets', 'solatec_custom_section_presets');
    function solatec_custom_section_presets(){
        return [
            1 => [
                [
                    'preset' => [42]
                ],
                [
                    'preset' => [50]
                ]
            ],
            2 => [
                [
                    'preset' => [31, 68]
                ],
                [
                    'preset' => [41, 41]
                ],
                [
                    'preset' => [41, 50]
                ],
                [
                    'preset' => [41, 58]
                ],
                [
                    'preset' => [41, 100]
                ],
                [
                    'preset' => [50, 100]
                ],
                [
                    'preset' => [58, 100]
                ],
                [
                    'preset' => [75, 25]
                ]
            ],
            3 => [
                [
                    'preset' => [ 41, 58, 100 ],
                ],
                [
                    'preset' => [ 50, 50, 100 ],
                ],
                [
                    'preset' => [ 100, 50, 50 ],
                ],
                [
                    'preset' => [ 50, 100, 100 ],
                ],
                [
                    'preset' => [ 20, 40, 40 ],
                ],
            ],
            4 => [
                [
                    'preset' => [ 41, 58, 100, 100 ],
                ],
                [
                    'preset' => [ 100, 33, 33, 33 ],
                ],
                [
                    'preset' => [ 50, 50, 50, 50 ],
                ],
                [
                    'preset' => [ 58, 20, 40, 40 ],
                ],
                [
                    'preset' => [ 100, 50, 50, 100 ],
                ],
            ],
            5 => [
                [
                    'preset' => [ 25,25,25,25,100 ],
                ],
                [
                    'preset' => [ 100,25,25,25,25 ],
                ],
                [
                    'preset' => [ 50, 50, 50, 50, 100 ],
                ],
                [
                    'preset' => [ 100, 50, 50, 50, 50 ],
                ],
                [
                    'preset' => [ 58,100, 20, 40, 40 ],
                ],
            ],
            6 => [
                [
                    'preset' => [33, 33, 33, 33, 33, 33],
                ],
                [
                    'preset' => [100, 20, 20, 20, 20, 20],
                ],
                [
                    'preset' => [20, 20, 20, 20, 20, 100],
                ]
            ],
            7 => [
                [
                    'preset' => [ 100, 33, 33, 33, 33, 33, 33 ],
                ],
                [
                    'preset' => [ 100, 20, 20, 20, 20, 20, 100 ],
                ]
            ],
            8 => [
                [
                    'preset' => [ 100, 100, 20, 20, 20, 20, 20, 100 ],
                ],
                [
                    'preset' => [ 100, 33, 33, 33, 33, 33, 33 ],
                ],
                [
                    'preset' => [ 100, 20, 20, 20, 20, 20, 100 ],
                ]
            ]
        ];
    }
}

// Add custom field to column
if(!function_exists('solatec_custom_column_params')){
    add_filter('etc-custom-column/custom-params', 'solatec_custom_column_params');
    function solatec_custom_column_params(){
        return array(
            'sections' => array(
                array(
                    'name'     => 'custom_section',
                    'label'    => esc_html__( 'Custom Settings', 'solatec' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_LAYOUT,
                    'controls' => array(
                        // this field hasn't config prefix_class
                        // its value will be handled at solatec_custom_column_classes function
                        // screen shot - http://prntscr.com/tjco9g
                        array(
                            'name'    => 'element_display',
                            'label'   => esc_html__( 'Element Display Settings', 'solatec' ),
                            'type'    => \Elementor\Controls_Manager::SELECT,
                            'options' => array(
                                ''           => esc_html__( 'Default', 'solatec' ),
                                'horizontal' => esc_html__( 'Horizontal', 'solatec' ),
                            ),
                            'default' => '',
                            'prefix_class' => 'cms-column-element-'
                        )
                    )
                )
            )
        );
    }
}

/**
 * Change html tag for Elementor image render
 * @Since 2.0.6
 * 
*/
if(!function_exists('solatec_elementor_image_size_get_attachment_image_html')){
    add_filter('elementor/image_size/get_attachment_image_html','solatec_elementor_image_size_get_attachment_image_html', 10, 4);
    function solatec_elementor_image_size_get_attachment_image_html($html, $settings, $image_size_key, $image_key){

        if ( ! $image_key ) {
            $image_key = $image_size_key;
        }
        $settings['size'] = isset($settings['size']) ? $settings['size'] : 'medium';
        $image = $settings[ $image_key ];

        // Old version of image settings.
        if ( ! isset( $settings[ $image_size_key . '_size' ] ) ) {
            $settings[ $image_size_key . '_size' ] = $settings['size'];
        }

        $size = $settings[ $image_size_key . '_size' ];

        $image_class = ['cms-lazy lazy-loading'];
        $image_class[] = isset($settings['img_class']) ?$settings['img_class'] : '';
        $image_class[] = ! empty( $settings['hover_animation'] ) ? 'elementor-animation-' . $settings['hover_animation'] : '';
        $image_class = implode(' ', array_filter($image_class));

        $html = '';

        // If is the new version - with image size.
        $image_sizes = get_intermediate_image_sizes();
        $image_sizes[] = 'full';

        if ( ! empty( $image['id'] ) && ! wp_attachment_is_image( $image['id'] ) ) {
            $image['id'] = '';
        }
        $is_static_render_mode = \Elementor\Plugin::$instance->frontend->is_static_render_mode();
        // On static mode don't use WP responsive images.
        if ( ! empty( $image['id'] ) && in_array( $size, $image_sizes ) && ! $is_static_render_mode ) {
            $image_class .= " attachment-$size size-$size wp-image-{$image['id']}";
            $image_attr = wp_get_attachment_image_src( $image['id'], $size);
            // if have max-height style
            if(isset($settings['cms_style']) && $settings['cms_style']){
                $image_attr['style'] = 'max-height:'.get_option($size.'_size_h').'px';
            }
            $alt  = trim( strip_tags( get_post_meta( $image['id'], '_wp_attachment_image_alt', true ) ) );
            $html = '<img class="'.$image_class.'" data-src="'.$image_attr[0].'" width="'.$image_attr[1].'" height="'.$image_attr[2].'" alt="'.$alt.'" style="'.$image_attr['style'].'" />';
        } else {
            $custom_dimension = isset($settings[ $image_key . '_custom_dimension' ]) ? $settings[ $image_key . '_custom_dimension' ] : ['width' => 'auto', 'height' => 'auto'];
            $settings[$image_key . '_custom_dimension'] = isset($settings[ $image_key . '_custom_dimension' ]) ? $settings[ $image_key . '_custom_dimension' ] : $custom_dimension;
            $image_src = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $image['id'], $image_size_key, $settings );
            if ( ! $image_src && isset( $image['url'] ) ) {
                $image_src = $image['url'];
            }

            if ( ! empty( $image_src ) ) {
                $image_class_html = ! empty( $image_class ) ? ' class="' . $image_class . '"' : '';

                // if have max-height style
                $image_style = '';
                if(isset($settings['cms_style']) && $settings['cms_style']){
                    $image_style = ' style="max-height:'.$settings[$image_key . '_custom_dimension']['height'].'px;"';
                }

                $html = sprintf( '<img width="%s" height="%s" data-src="%s" title="%s" alt="%s"%s%s />', 
                    $custom_dimension['width'],
                    $custom_dimension['height'],
                    esc_attr( $image_src ), 
                    \Elementor\Control_Media::get_image_title( $image ), 
                    \Elementor\Control_Media::get_image_alt( $image ), 
                    $image_class_html,
                    $image_style
                );
            }
        }

        return $html;
    }
}