<?php
/**
 * Ajax paginate links
*/
if(!function_exists('solatec_ajax_paginate_links')){
    function solatec_ajax_paginate_links($link){
        $parts = parse_url($link);
        parse_str($parts['query'], $query);
        if(isset($query['page']) && !empty($query['page'])){
            return '#' . $query['page'];
        }
        else{
            return '#1';
        }
    }
}
/**
 * AJAX HTML for pagination
*/
if(!function_exists('solatec_get_pagination_html')){
    add_action( 'wp_ajax_solatec_get_pagination_html', 'solatec_get_pagination_html' );
    add_action( 'wp_ajax_nopriv_solatec_get_pagination_html', 'solatec_get_pagination_html' );
    function solatec_get_pagination_html(){
        try{
            if(!isset($_POST['query_vars'])){
                throw new Exception(__('Something went wrong while requesting. Please try again!', 'solatec'));
            }
            $query = new WP_Query($_POST['query_vars']);
            ob_start();
            solatec_posts_pagination( $query,  true );
            $html = ob_get_clean();
            wp_send_json(
                array(
                    'status' => true,
                    'message' => esc_html__('Load Successfully!', 'solatec'),
                    'data' => array(
                        'html'       => $html,
                        'query_vars' => $_POST['query_vars'],
                        'post'       => $query->have_posts()
                    ),
                )
            );
        }
        catch (Exception $e){
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}
// Load More Post Layout
if(!function_exists('solatec_load_more_post_grid')){
    add_action( 'wp_ajax_solatec_load_more_post_grid', 'solatec_load_more_post_grid' );
    add_action( 'wp_ajax_nopriv_solatec_load_more_post_grid', 'solatec_load_more_post_grid' );
    function solatec_load_more_post_grid(){
        try{
            if(!isset($_POST['settings'])){
                throw new Exception(__('Something went wrong while requesting. Please try again!', 'solatec'));
            }
            $settings = $_POST['settings'];
            set_query_var('paged', $settings['paged']);
            extract(etc_get_posts_of_grid($settings['post_type'], [
                'source'   => isset($settings['source'])?$settings['source']:'',
                'orderby'  => isset($settings['orderby'])?$settings['orderby']:'date',
                'order'    => isset($settings['order'])?$settings['order']:'desc',
                'limit'    => isset($settings['limit'])?$settings['limit']:'6',
                'post_ids' => '',
            ]));
            ob_start();
                solatec_get_post_grid($posts, $settings);
            $html = ob_get_clean();
            wp_send_json(
                array(
                    'status' => true,
                    'message' => __('Load Successfully!', 'solatec'),
                    'data' => array(
                        'html'  => $html,
                        'paged' => $settings['paged'],
                        'posts' => $posts,
                        'max'   => $max,
                    ),
                )
            );
        }
        catch (Exception $e){
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}
// Post Layout 
if(!function_exists('solatec_get_post_grid')){
    function solatec_get_post_grid($posts = [], $settings = [], $args = []){
        if(empty($posts) || !is_array($posts) || empty($settings) || !is_array($settings)){
            return false;
        }
        extract($settings);
        if($thumbnail_size != 'custom'){
            $img_size = $thumbnail_size;
        }
        elseif(!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])){
            $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
        }
        else{
            $img_size = 'full';
        }
        $col_xl = isset($settings['col_xl']) ? 'col-xl-'.(12 / intval($settings['col_xl'])) : '';
        $col_lg = isset($settings['col_lg']) ? 'col-lg-'.(12 / intval($settings['col_lg'])) : '';
        $col_md = isset($settings['col_md']) ? 'col-md-'.(12 / intval($settings['col_md'])) : '';
        $col_sm = isset($settings['col_sm']) ? 'col-'.(12 / intval($settings['col_sm'])) : '';

        $args = wp_parse_args($args, [
            'item_class' => trim(implode(' ', ['cms-grid-item', $col_xl, $col_lg, $col_md, $col_sm]))
        ]);

        $item_class = $args['item_class'];
        $settings['gap_extra'] = empty($settings['gap_extra']) ? '0' : $settings['gap_extra'];
        // Start build post item 
        foreach ($posts as $post):
            $filter_class = etc_get_term_of_post_to_class($post->ID, array_unique($tax));
            ?>
            <div class="<?php echo esc_attr($item_class . ' ' . $filter_class); ?>" style="padding: <?php echo esc_attr($settings['gap']/2);?>px; margin-bottom: <?php echo esc_attr($settings['gap_extra']);?>px">
                <?php switch ($settings['layout']) {
                    case '8':
                ?>
                    <div class="cms-item-content bg-white cms-shadow-2 cms-transition cms-radius-tr-8 clearfix">
                        <div class="cms-item-content-inner p-20 p-tb-lg-50 p-lr-lg-40 text-center">
                            <?php 
                                $icon     = solatec_get_post_format_value($post->ID, 'cms_post_icon', '');
                                $icon_img = solatec_get_post_format_value($post->ID, 'cms_post_icon_img', []);
                                if(isset($icon_img['id']) && !empty($icon_img['id'])){
                                    $class = '';
                                } else {
                                    $class = 'text-64 text-primary icon';
                                }
                                solatec_post_icon([
                                    'id'    => $post->ID,
                                    'class' => 'circle text-center cms-transition '.$class
                                ]);
                            ?>
                            <div class="cms-item-content-title cms-heading text-23 lh-32 pt-32">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                            </div>
                            <div class="cms-item-content-excerpt pt-15 text-15 lh-25"><?php
                                if(!empty($post->post_excerpt)){
                                    echo wp_trim_words( $post->post_excerpt, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                }
                                else{
                                    $content = strip_shortcodes( $post->post_content );
                                    $content = apply_filters( 'the_content', $content );
                                    $content = str_replace(']]>', ']]&gt;', $content);
                                    echo wp_trim_words( $content, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                }
                            ?></div>
                            <?php if(!empty($settings['readmore_text'])){ ?>
                                <div class="cms-btn-wraps cms-post-item-readmore mt-24">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="btn btn-outline btn-primary btn-md btn-hover-accent">
                                        <span class="cms-btn-content">
                                            <span class="cms-btn-icon"><span class="zmdi zmdi-minus default-icon"></span><span class="zmdi zmdi-arrow-<?php echo is_rtl() ? 'left' : 'right';?> hover-icon"></span></span>
                                            <span class="cms-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                        </span>
                                    </a>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                <?php
                    break;
                    case '7':
                ?>
                    <div class="cms-item-content bg-white cms-shadow-1 cms-shadow-hover-2 cms-transition cms-radius-8 overflow-hidden clearfix relative h-100">
                        <?php 
                            solatec_post_media([
                            'id'             => $post->ID, 
                            'default_thumb'  => '1',
                            'thumbnail_size' => $img_size,
                            'wrap_class'     => 'overflow-hidden',
                            'img_class'      => '',
                            'media_content'  => false,
                            'media_after'    => solatec_doctor_infomation([
                                'id'         =>  $post->ID,
                                'show_fb'    =>  $settings['show_fb'],
                                'show_tw'    =>  $settings['show_tw'],
                                'show_insta' =>  $settings['show_insta'],
                                'show_email' =>  $settings['show_email'],
                                'show_phone' =>  $settings['show_phone'],
                                'before'     => '<div class="cms-doctor-social d-inline-block cms-transition"><div class="cms-social-layout-5">',
                                'after'      => '</div></div>', 
                                'echo'       => false   
                            ])
                        ]); ?>
                        <div class="cms-item-content-inner bg-white p-lr-20 p-lr-lg-40 pt-30 pb-33 cms-transition">
                            <div class="cms-item-content-inner2 cms-transition">
                                <div class="cms-heading cms-item-content-title cms-heading text-21 lh-32">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                                </div>
                                <?php 
                                    solatec_terms([
                                        'id'     => $post->ID,
                                        'taxo'   => solatec_get_custom_post_taxonomies($post->post_type, 'cat'),
                                        'before' => '<span class="cms-post-cat pb-20 text-14"><span class="text-accent">',
                                        'after'  => '</span></span>'
                                    ]);
                                ?>
                                <div class="cms-item-content-excerpt text-15 pt-15"><?php
                                    if(!empty($post->post_excerpt)){
                                        echo wp_trim_words( $post->post_excerpt, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                    }
                                    else{
                                        $content = strip_shortcodes( $post->post_content );
                                        $content = apply_filters( 'the_content', $content );
                                        $content = str_replace(']]>', ']]&gt;', $content);
                                        echo wp_trim_words( $content, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                    }
                                ?></div>
                                <?php if(!empty($settings['readmore_text'])){ 
                                    ?><div class="cms-btn-wraps cms-post-item-readmore mt-33 mb-7">
                                        <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="btn btn-outline btn-primary">
                                            <span class="cms-btn-content">
                                                <span class="cms-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                            </span>
                                        </a>
                                    </div><?php 
                                } ?>   
                            </div>
                        </div>
                    </div>
                <?php
                        break;
                    case '6':
                ?>
                    <div class="cms-item-content relative bg-white cms-shadow-1 cms-shadow-hover-2 cms-transition cms-radius-8 clearfix">
                        <?php 
                            solatec_post_media([
                            'id'             => $post->ID, 
                            'default_thumb'  => '1',
                            'thumbnail_size' => $img_size,
                            'wrap_class'     => '',
                            'img_class'      => 'cms-radius-t-8',
                            'media_content'  => false
                        ]); ?>
                        <div class="cms-item-content-inner p-40 mt-n8">
                            <div class="cms-item-content-title cms-heading text-23 lh-32">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                            </div>
                            <div class="cms-item-content-excerpt text-15 mt-15"><?php
                                if(!empty($post->post_excerpt)){
                                    echo wp_trim_words( $post->post_excerpt, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                }
                                else{
                                    $content = strip_shortcodes( $post->post_content );
                                    $content = apply_filters( 'the_content', $content );
                                    $content = str_replace(']]>', ']]&gt;', $content);
                                    echo wp_trim_words( $content, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                }
                            ?></div>
                            <?php 
                            if(!empty($settings['readmore_text'])){ ?>
                                <div class="cms-btn-wraps cms-post-item-readmore mt-25">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="btn btn-outline btn-primary btn-hover-accent btn-md">
                                        <span class="cms-btn-content">
                                            <span class="cms-btn-icon text-20 cmsi-arrow-circle-<?php echo is_rtl() ? 'left' : 'right';?>"></span>
                                            <span class="cms-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                        </span>
                                    </a>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                <?php break; 
                    case '5':
                ?>
                    <div class="cms-item-content bg-white cms-shadow-4 cms-shadow-hover-2 cms-transition cms-radius-8 overflow-hidden clearfix relative h-100">
                        <?php 
                            solatec_post_media([
                            'id'             => $post->ID, 
                            'default_thumb'  => '1',
                            'thumbnail_size' => $img_size,
                            'class'          => '',
                            'img_class'      => '',
                            'media_content'  => false
                        ]); ?>
                        <div class="cms-item-content-inner p-lr-20 p-tb-15 p-lr-lg-40 p-tb-lg-35">
                            <div class="cms-item-content-inner2">
                                <?php 
                                    solatec_terms([
                                        'id'     => $post->ID,
                                        'taxo'   => solatec_get_custom_post_taxonomies($post->post_type, 'cat'),
                                        'before' => '<div class="cms-post-cat text-14 text-accent pb-5">',
                                        'after'  => '</div>'
                                    ]);
                                ?>
                                <div class="cms-heading cms-item-content-title cms-heading text-20 lh-28">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                                </div>
                                <?php if(intval($settings['excerpt_lenght']) !== -1) : ?>  
                                <div class="cms-item-content-excerpt pt-15"><?php
                                    if(!empty($post->post_excerpt)){
                                        echo wp_trim_words( $post->post_excerpt, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                    }
                                    else{
                                        $content = strip_shortcodes( $post->post_content );
                                        $content = apply_filters( 'the_content', $content );
                                        $content = str_replace(']]>', ']]&gt;', $content);
                                        echo wp_trim_words( $content, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                    }
                                ?></div>
                                <?php endif; ?>
                                    <?php if(!empty($settings['readmore_text'])){ ?>
                                        <div class="cms-btn-wraps cms-post-item-readmore mt-18">
                                            <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="btn-readmore">
                                                <span class="cms-btn-content">
                                                    <span class="cms-btn-icon fas"></span>
                                                    <span class="cms-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                                </span>
                                            </a>
                                        </div>
                                    <?php } 
                                ?>  
                            </div>
                        </div>
                    </div>
                <?php
                        break;
                    case '4':
                ?>
                    <div class="cms-item-content relative">
                        <?php 
                            solatec_post_media([
                            'id'             => $post->ID, 
                            'default_thumb'  => '1',
                            'thumbnail_size' => $img_size,
                            'class'          => 'overflow-hidden cms-radius-8',
                            'img_class'      => 'cms-radius-8',
                            'media_content'  => false
                        ]); ?>
                        <div class="cms-item-content-inner cms-transition bg-white p-tb-35 pl-40 pr-15">
                            <div class="cms-item-content-inner2">
                                <?php 
                                    solatec_terms([
                                        'id'     => $post->ID,
                                        'taxo'   => solatec_get_custom_post_taxonomies($post->post_type, 'cat'),
                                        'before' => '<div class="cms-post-cat pb-15 text-14 text-accent">',
                                        'after'  => '</div>'
                                    ]);
                                ?>
                                <div class="cms-heading cms-item-content-title cms-heading text-20 lh-28">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php 
                                        //echo get_the_title($post->ID);
                                        echo wp_trim_words( get_the_title($post->ID), '7', '');
                                    ?></a>
                                </div> 
                            </div>
                        </div>
                    </div>
                <?php
                        break;
                    case '3':
                ?>
                    <div class="cms-item-content bg-white cms-radius-8 cms-shadow-4 cms-hover-img-scale overflow-hidden relative clearfix"><?php 
                        solatec_post_media([
                            'id'             => $post->ID, 
                            'default_thumb'  => '1',
                            'thumbnail_size' => $img_size,
                            'wrap_class'     => 'cms-radius-t-8 overflow-hidden',
                            'img_class'      => 'w-100',
                            'media_content'  => false  
                        ]); ?>
                        <div class="cms-item-content-inner cms-transition p-lr-15 p-lr-md-40 pt-40 pb-40">
                            <?php 
                                solatec_post_category([
                                    'post_id'       => $post->ID,
                                    'taxo'          => solatec_get_custom_post_taxonomies($post->post_type, 'cat'),
                                    'class'         => 'd-block pb-15 text-14 mt-n8',
                                    'show_icon'     => false  
                                ]);
                            ?>
                            <div class="cms-item-content-title cms-heading text-20 lh-28 mb-15">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php 
                                    echo get_the_title($post->ID); 
                                ?></a>
                            </div>
                            <div class="cms-item-content-excerpt mb-20"><?php
                                if(!empty($post->post_excerpt)){
                                    echo wp_trim_words( $post->post_excerpt, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                }
                                else{
                                    $content = strip_shortcodes( $post->post_content );
                                    $content = apply_filters( 'the_content', $content );
                                    $content = str_replace(']]>', ']]&gt;', $content);
                                    echo wp_trim_words( $content, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                }
                            ?></div>
                            <?php 
                            if(!empty($settings['readmore_text'])){ ?>
                                <div class="cms-btn-wraps cms-post-item-readmore">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="btn btn-fill btn-accent">
                                        <span class="cms-btn-content">
                                            <span class="cms-btn-icon text-20 cmsi-arrow-circle-<?php echo is_rtl() ? 'left' : 'right';?>"></span>
                                            <span class="cms-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                        </span>
                                    </a>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                <?php
                    break;
                    case '2':
                ?>
                    <div class="cms-item-content bg-white cms-shadow-1 cms-shadow-hover-2 cms-transition cms-radius-8 overflow-hidden cms-hover-img-scale cms-clip-path-wrap clearfix">
                        <?php solatec_post_media([
                            'id'             => $post->ID, 
                            'default_thumb'  => '1',
                            'thumbnail_size' => $img_size,
                            'wrap_class'     => 'overflow-hidden cms-clip-path cms-clip-path-bl cms-clip-path-40',
                            'img_class'      => 'w-100',
                            'media_content'  => false
                        ]); ?>
                        <div class="cms-item-content-inner p-lr-15 p-lr-md-30 pt-20 pb-30 mt-n8">
                            <div class="cms-item-content-title cms-heading text-21 lh-29 mb-15">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                            </div>
                            <div class="cms-item-content-excerpt mb-30"><?php
                                if(!empty($post->post_excerpt)){
                                    echo wp_trim_words( $post->post_excerpt, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                }
                                else{
                                    $content = strip_shortcodes( $post->post_content );
                                    $content = apply_filters( 'the_content', $content );
                                    $content = str_replace(']]>', ']]&gt;', $content);
                                    echo wp_trim_words( $content, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                }
                            ?></div>
                            <?php 
                            if(!empty($settings['readmore_text'])){ ?>
                                <div class="cms-btn-wraps cms-post-item-readmore">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="btn btn-outline btn-primary btn-hover-accent">
                                        <span class="cms-btn-content">
                                            <span class="cms-btn-icon text-20 cmsi-arrow-circle-<?php echo is_rtl() ? 'left' : 'right';?>"></span>
                                            <span class="cms-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                        </span>
                                    </a>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                <?php
                        break;
                    case '1': // remove this layout when approved
                ?>
                    <div class="cms-item-content cms-radius-8 cms-shadow-hover-4 cms-transition clearfix"><?php 
                        solatec_post_media([
                            'id'             => $post->ID, 
                            'default_thumb'  => '1',
                            'thumbnail_size' => $img_size,
                            'wrap_class'     => 'cms-radius-8',
                            'img_class'      => 'w-100 cms-radius-10',
                            'media_content'  => false,
                            'media_after'    => get_the_term_list($post->ID, solatec_get_custom_post_taxonomies($post->post_type, 'cat'), '<span class="cms-post-feature-cat">',', ', '</span>')
                        ]); 
                        ?>
                        <div class="cms-item-content-inner p-lr-15 p-lr-md-40 pt-40 pb-40 mt-n8">
                            <?php 
                                solatec_post_meta([
                                    'post_id'       => $post->ID,
                                    'taxo'          => solatec_get_custom_post_taxonomies($post->post_type, 'cat'),
                                    'class'         => 'pb-5 separator-divider',
                                    'show_icon'     => false,
                                    'show_cmt'      => false,
                                    'show_cat'     => false   
                                ]);
                            ?>
                            <div class="cms-item-content-title cms-heading text-20 lh-28 mb-25">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                            </div>
                            <div class="cms-item-content-excerpt mb-30"><?php
                                if(!empty($post->post_excerpt)){
                                    echo wp_trim_words( $post->post_excerpt, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                }
                                else{
                                    $content = strip_shortcodes( $post->post_content );
                                    $content = apply_filters( 'the_content', $content );
                                    $content = str_replace(']]>', ']]&gt;', $content);
                                    echo wp_trim_words( $content, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                }
                            ?></div>
                            <?php 
                            if(!empty($settings['readmore_text'])){ ?>
                                <div class="cms-btn-wraps cms-post-item-readmore">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="btn btn-outline btn-primary btn-hover-accent">
                                        <span class="cms-btn-content">
                                            <span class="cms-btn-icon text-20 cmsi-arrow-circle-<?php echo is_rtl() ? 'left' : 'right';?>"></span>
                                            <span class="cms-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                        </span>
                                    </a>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                <?php 
                        break; 
                    default:
                ?>
                    <div class="cms-item-content bg-white cms-radius-8 cms-hover-img-scale clearfix"><?php 
                        solatec_post_media([
                            'id'             => $post->ID, 
                            'default_thumb'  => '1',
                            'thumbnail_size' => $img_size,
                            'wrap_class'     => 'cms-radius-8 overflow-hidden',
                            'img_class'      => 'w-100 cms-radius-10'  
                        ]); ?>
                        <div class="cms-item-content-inner p-lr-15 p-lr-md-40 pt-40 pb-40 mt-n8">
                            <?php 
                                solatec_post_meta([
                                    'post_id'       => $post->ID,
                                    'taxo'          => solatec_get_custom_post_taxonomies($post->post_type, 'cat'),
                                    'class'         => 'pb-5',
                                    'show_icon'     => false,
                                    'show_cmt'      => false,
                                    'show_date'     => false   
                                ]);
                            ?>
                            <div class="cms-item-content-title cms-heading text-20 lh-28 mb-25">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                            </div>
                            <div class="cms-item-content-excerpt mb-30"><?php
                                if(!empty($post->post_excerpt)){
                                    echo wp_trim_words( $post->post_excerpt, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                }
                                else{
                                    $content = strip_shortcodes( $post->post_content );
                                    $content = apply_filters( 'the_content', $content );
                                    $content = str_replace(']]>', ']]&gt;', $content);
                                    echo wp_trim_words( $content, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                }
                            ?></div>
                            <?php 
                            if(!empty($settings['readmore_text'])){ ?>
                                <div class="cms-btn-wraps cms-post-item-readmore">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="btn btn-outline btn-primary btn-hover-accent">
                                        <span class="cms-btn-content">
                                            <span class="cms-btn-icon text-20 cmsi-arrow-circle-<?php echo is_rtl() ? 'left' : 'right';?>"></span>
                                            <span class="cms-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                        </span>
                                    </a>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                <?php break; 
                    } ?>
            </div>
        <?php
        endforeach;
    }
}