<?php
/**
 * Custom template tags for this theme.
 *
 * @package Solatec
 */

/**
 * Page loading
 **/
if(!function_exists('solatec_page_loading')){
    function solatec_page_loading()
    {
        $page_loading = solatec_get_opt( 'show_page_loading', false );

        if($page_loading) { ?>
            <div id="cms-loadding" class="cms-loader">
                <div class="loading-spinner">
                    <div class="loading-dot1"></div>
                    <div class="loading-dot2"></div>
                </div>
            </div>
        <?php }
    }
}
/*
 * Content area css class
*/
if(!function_exists('solatec_content_css_class')){
    function solatec_content_css_class($args = []){
        $args = wp_parse_args($args,[
            'content_col'  => 'archive_content_col',
            'sidebar_pos'  => 'archive_sidebar_pos',
            'class'        => ''
        ]);
        $classes = [
            'cms-content-area'
        ];
        $sidebar            = solatec_get_sidebar();
        $sidebar_position   = solatec_sidebar_position(['sidebar_pos' => $args['sidebar_pos']]);
        $content_grid_class = solatec_get_opts($args['content_col'], solatec_configs('blog')['archive_content_col']);

        if( $sidebar_position === 'bottom' || $sidebar_position === '0' ){
            $classes[] = 'col-12';
        } else {
            if($sidebar && ('none' !== $sidebar_position || 'center' == $sidebar_position)){
                $classes[] = 'col-lg-'.$content_grid_class;
                if($sidebar_position == 'left') $classes[] = 'order-lg-last';
                if($sidebar_position == 'center') $classes[] = 'offset-lg-2';
            } else {
                $classes[] = 'col-12';
            }
        }
        $classes[] = $args['class'];
        echo trim(implode(' ', $classes));
    }
}

// Post link pages
if(!function_exists('solatec_post_link_pages')){
    add_filter('wp_link_pages_args', 'solatec_wp_link_pages_args');
    function solatec_wp_link_pages_args($args){
        $args['before']      = '';
        $args['after']       = '';
        $args['link_before'] = '<span>';
        $args['link_after']  = '</span>';
        return $args;   
    }
    function solatec_post_link_pages($args = []){
        $args = wp_parse_args($args, [
            'class' => ''
        ]);
    ?>
    <div class="<?php echo trim(implode(' ', ['navigation cms-page-links clearfix', $args['class']])); ?>"><?php 
        wp_link_pages(); 
    ?></div>
    <?php
    }
}
// Post title
if ( ! function_exists( 'solatec_post_title' ) ) :
    /**
     * Print post title
     *
     * @param  integer $length
     */
    function solatec_post_title($args = []){
        $args = wp_parse_args($args, [
            'tag'         => 'div',
            'sticky_icon' => '<span class="cmsi-thumbtack"></span>',
            'show_link'   => true,
            'class'       => ''
        ]);
        ?>
        <<?php echo esc_attr($args['tag']); ?> class="<?php echo trim(implode(' ', ['cms-heading cms-post-title', $args['class']]));?>"><?php 
            if($args['show_link'] && !is_single() ) { ?>
                <a href="<?php echo esc_url( get_permalink()); ?>"><?php 
            }
                if(is_sticky()) { echo wp_kses_post($args['sticky_icon']).'&nbsp;&nbsp;'; }
                the_title();
            if($args['show_link']) { ?>
                </a><?php 
            } ?></<?php echo esc_attr($args['tag']); ?>>
    <?php
    }
endif;

if ( ! function_exists( 'solatec_post_excerpt' ) ) :
    /**
     * Print post excerpt based on length.
     *
     * @param  integer $length
     */
    function solatec_post_excerpt($args = []) {
        $args = wp_parse_args($args, [
            'class'  => '',
            'length' => 55,
            'more'   => ''
        ]);
    ?>
    <div class="<?php echo trim(implode(' ', ['cms-post-excerpt', $args['class']])) ?>">
        <?php 
            $cms_the_excerpt = get_the_excerpt();
            if(!empty(get_the_excerpt())) {
                echo wp_trim_words( $cms_the_excerpt, $args['length'], $args['more'] );
            } else {
                echo solatec_get_the_excerpt( $args['length'], $args['more']);
            }
        ?>
    </div>
    <?php
    }
endif;

if ( ! function_exists( 'solatec_post_readmore' ) ) :
    /**
     * Print post Readmore.
     *
     * @param 
     */
    function solatec_post_readmore($args = []){
        $args = wp_parse_args($args, [
            'wrap_class' => '',
            'class'      => '',
            'text'       => esc_html__('Read More', 'solatec'),
            'icon'       => 'cmsi-arrow-circle-right',
            'icon_rtl'   => 'cmsi-arrow-circle-left',
            'icon_pos'   => 'left'
        ]);
       ?>
       <div class="<?php echo trim(implode(' ', ['cms-post-readmore d-inline-block', $args['wrap_class']]));?>">
            <a href="<?php echo esc_url( get_permalink()); ?>" class="<?php echo trim(implode(' ', ['cms-readmore', $args['class']]));?>">
                <span class="cms-btn-content">
                    <span class="cms-btn-icon cms-align-icon-<?php echo esc_attr($args['icon_pos']);?>">
                        <i aria-hidden="true" class="<?php echo is_rtl() ? esc_attr($args['icon_rtl']) : esc_attr($args['icon']);?>"></i>
                    </span>
                    <span class="cms-btn-text"><?php echo esc_html($args['text']); ?></span>
                </span>        
            </a>
        </div>
       <?php 
    }
endif;

/**
 * Prints post edit link when applicable
 */
if(!function_exists('solatec_post_edit_link')){
    function solatec_post_edit_link()
    {
        edit_post_link(
            sprintf(
                wp_kses(
                /* translators: %s: Name of current post. Only visible to screen readers */
                    esc_html__( 'Edit', 'solatec' ),
                    array(
                        'span' => array(
                            'class' => array(),
                        ),
                    )
                ),
                get_the_title()
            ),
            '<div class="cms-post-edit-link"><span class="fa fa-edit"></span>',
            '</div>'
        );
    }
}


/**
 * Prints posts pagination based on query
 *
 * @param  WP_Query $query     Custom query, if left blank, this will use global query ( current query )
 * @return void
 */
function solatec_posts_pagination( $query = null, $ajax = false )
{
    if($ajax){
        add_filter('paginate_links', 'solatec_ajax_paginate_links');
    }

    $classes = array();

    if ( empty( $query ) )
    {
        $query = $GLOBALS['wp_query'];
    }

    if ( empty( $query->max_num_pages ) || ! is_numeric( $query->max_num_pages ) || $query->max_num_pages < 2 )
    {
        return;
    }

    $paged = $query->get( 'paged', '' );

    if ( ! $paged && is_front_page() && ! is_home() )
    {
        $paged = $query->get( 'page', '' );
    }

    $paged = $paged ? intval( $paged ) : 1;

    $pagenum_link = html_entity_decode( get_pagenum_link() );
    $query_args   = array();
    $url_parts    = explode( '?', $pagenum_link );

    if ( isset( $url_parts[1] ) )
    {
        wp_parse_str( $url_parts[1], $query_args );
    }

    $pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
    $pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

    $paginate_links_args = array(
        'base'     => $pagenum_link,
        'total'    => $query->max_num_pages,
        'current'  => $paged,
        'mid_size' => 1,
        'add_args' => array_map( 'urlencode', $query_args ),
        'prev_text' => solatec_pagination_prev_text(),
        'next_text' => solatec_pagination_next_text(),
    );
    if($ajax){
        $paginate_links_args['format'] = '?page=%#%';
    }
    $links = paginate_links( $paginate_links_args );
    if ( $links ):
    ?>
    <nav class="navigation posts-pagination <?php echo esc_attr($ajax?'ajax':''); ?>">
        <?php
            printf('%s',$links);
        ?>
    </nav>
    <?php
    endif;
}
if(!function_exists('solatec_pagination_prev_text')){
    function solatec_pagination_prev_text(){
        return '<span class="nav-prev-icon"></span>';
    }
}
if(!function_exists('solatec_pagination_next_text')){
    function solatec_pagination_next_text(){
        return '<span class="nav-next-icon"></span>';
    }
}

/**
 * List socials share for post.
 * <a class="pin-social pinterest hover-effect" title="Pinterest" target="_blank" href="http://pinterest.com/pin/create/button/?url=<?php echo urlencode(the_permalink()); ?>&media=<?php echo esc_attr($pinterestimage[0]); ?>&description=<?php the_title(); ?>"><i class="cmsi-pinterest"></i></a>
                <a class="it-social instagram hover-effect" title="Instagram" target="_blank" href="https://instagram.com/<?php echo solatec_get_opt('instagram_user');?>"><i class="cmsi-instagram"></i></a>
 */
if(!function_exists('solatec_socials_share_default')){
    function solatec_socials_share_default($args = []) {
        $args = wp_parse_args($args, [
            'show_share'   => '1',
            'class'        => '',
            'title'        => '<div class="cms-post-share-title h4">'.esc_html__('Share:','solatec').'</div>',
            'social_class' => '',
            'before'       => '',
            'after'        => ''  
        ]);
        if($args['show_share'] != '1') return;
        $pinterestimage = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full' );

        printf('%s', $args['before']);
    ?>
        <div class="<?php echo trim(implode(' ',['cms-post-share row align-items-center',  $args['class']]));?>">
            <?php if(!empty($args['title'])) printf('%s', $args['title']); ?>
            <div class="<?php echo trim(implode(' ',['col-auto cms-social',  $args['social_class']]));?>">
                <a class="fb-social facebook hover-effect" title="Facebook" target="_blank" href="https://www.facebook.com/sharer/sharer.php?u=<?php urlencode(the_permalink()); ?>"><i class="cmsi-facebook-f"></i></a>
                <a class="tw-social twitter hover-effect" title="Twitter" target="_blank" href="https://twitter.com/home?status=<?php the_permalink(); ?>"><i class="cmsi-twitter"></i></a>
                <a class="it-social linkedin hover-effect" title="Linkedin" target="_blank" href="https://linked.com/<?php echo solatec_get_opt('instagram_user');?>"><i class="cmsi-linkedin-in"></i></a>
            </div>
        </div>
        <?php
        printf('%s', $args['after']);
    }
}

/**
 * Post Author Info
****/
if(!function_exists('solatec_post_author_info')){
    function solatec_post_author_info($args = []){
        $args = wp_parse_args($args,[
            'class'       => '',
            'title_class' => '',
            'show_author' => solatec_get_opt('post_author_info_on','0'),
            'before'      => '',
            'after'       => ''  
        ]);
        if($args['show_author'] != '1') return;
        printf('%s', $args['before']);
    ?>
        <div class="<?php echo trim(implode(' ', ['entry-author-info', $args['class']]));?>">
            <div class="cms-post-author row text-center text-md-start">
                <div class="cms-post-author-avatar col-12 col-md-auto mb-20 mb-md-0">
                        <?php echo get_avatar( get_the_author_meta( 'ID' ), '70', '', esc_html__('Solatec', 'solatec'), ['class' => 'cms-radius-8'] ); ?>
                    </div>
                <div class="cms-post-author-description col text-primary"><?php 
                    echo '<div class="cms-post-author-title cms-heading '.$args['title_class'].'">'.get_the_author().'</div>';
                    echo '<div class="cms-post-author-description">'.get_the_author_meta( 'description' ).'</div>';
                    solatec_get_user_social([
                        'class' => 'cms-social-layout-1 pt-15 ml-n10 justify-content-center justify-content-md-start'
                    ]); 
                ?></div>
            </div>
        </div>
    <?php 
        printf('%s', $args['after']);
    }
}
/**
 * Single  Next/Prev Link
*/
if(!function_exists('solatec_posts_nav_link')) { 
    function solatec_posts_nav_link($args = []){
        $args = wp_parse_args($args, [
            'show_nav'       => '1',
            'show_thumbnail' => '1',
            'thumbnail_size' => '80',
            'show_title'     => '1',
            'prev_title'     =>  esc_html__('Previous', 'solatec'). ' ' .get_post_type(),
            'next_title'     =>  esc_html__('Next', 'solatec'). ' ' . get_post_type(),
            'prev_icon'      => 'fas fa-long-arrow-alt-left',
            'next_icon'      => 'fas fa-long-arrow-alt-right',
            'class'          => '',
            'img_class'      => '',
            'before'         => '',
            'after'          => ''
        ]);
        if($args['show_nav'] != '1' ) return;
        $next_post = get_next_post();
        $previous_post = get_previous_post();
        if(empty($previous_post) && empty($next_post)) return;
        printf('%s', $args['before']);
    ?>
        <div class="<?php echo trim(implode(' ', ['cms-single-next-prev-navigation row gutters-10 justify-content-between align-items-center', $args['class']])); ?>">
            <?php if(!empty($previous_post)) { ?>
            <div class="cms-single-next-prev cms-single-prev col-lg-6 relative text-start">
                <div class="cms-single-next-prev-inner cms-single-prev-inner cms-single-nav-inner">
                    <?php 
                        // overlay link
                        previous_post_link('%link',''); 
                    ?>
                    <div class="row align-items-center gutters-20">
                        <?php if('1' === $args['show_thumbnail']):
                            solatec_post_thumbnail([
                                'id'             => $previous_post->ID, 
                                'thumbnail_size' => $args['thumbnail_size'], 
                                'class'          => '', 
                                'img_class'      => $args['img_class'],
                                'before'         => '<div class="col-auto">',
                                'after'          => '</div>'
                            ]);
                        endif;
                            if('1' !== $args['show_thumbnail'] && !empty($args['prev_icon'])){
                                echo '<div class="col-auto"><span class="cms-nav-icon '.$args['prev_icon'].'"></span></div>';
                            }
                         ?>
                        <div class="col"><?php 
                            // label
                            if(!empty($args['prev_title'])) printf('<div class="cms-nav-label text-13">%s</div>', esc_html($args['prev_title']));
                            // title
                            if('1' === $args['show_title']) printf('<div class="cms-nav-title cms-heading text-16 lh-22">%s</div>', get_the_title($previous_post->ID ));
                        ?></div>
                    </div>
                </div>
            </div>
            <?php } else { echo '<div class="col-auto col-lg-6 relative text-start"></div>'; }
            if(!empty($next_post)) : ?>
            <div class="cms-single-next-prev cms-single-next col-lg-6 relative text-end">
                <div class="cms-single-next-prev-inner cms-single-next-inner cms-single-nav-inner">
                    <?php 
                        // overlay link
                        next_post_link('%link','');
                    ?>
                    <div class="row align-items-center gutters-20">
                        <div class="col"><?php
                            // label
                            if(!empty($args['prev_title'])) printf('<div class="cms-nav-label text-13">%s</div>', esc_html($args['next_title']));
                            // title
                            if('1' === $args['show_title']) printf('<div class="cms-nav-title cms-heading text-16 lh-22">%s</div>', get_the_title($next_post->ID ));
                        ?></div>
                        <?php if('1' === $args['show_thumbnail']):
                            solatec_post_thumbnail([
                                'id'             => $next_post->ID,
                                'thumbnail_size' => $args['thumbnail_size'], 
                                'class'          => '', 
                                'img_class'      => $args['img_class'],
                                'before'         => '<div class="col-auto">',
                                'after'          => '</div>'
                            ]); 
                        endif;
                            if('1' !== $args['show_thumbnail'] && !empty($args['next_icon'])){
                                echo '<div class="col-auto"><span class="cms-nav-icon '.$args['next_icon'].'"></span></div>';
                            }
                        ?>
                    </div>
                </div>
            </div>
            <?php endif; ?>
        </div>
    <?php 
        printf('%s', $args['after']);
    }
}

/**
 * Related Post
 */
if(!function_exists('solatec_related_post')){
    function solatec_related_post($args = [])
    {
        $args = wp_parse_args($args, [
            'class'          => '',
            'show_related'   => solatec_get_opt( 'post_related_on', '0' ),
            'title'          => esc_html__('Related Posts','solatec'),
            'posts_per_page' => '2',
            'post_type'      => 'post',
            'before'         => '',
            'after'          => ''
        ]);

        if($args['show_related'] != '1') return;
        
        global $post;
        $current_id = $post->ID;
        $posttags = get_the_category($post->ID);
        if (empty($posttags)) return;
        $tags = array();
        foreach ($posttags as $tag) {
            $tags[] = $tag->term_id;
        }
        $query_similar = new WP_Query(array(
            'posts_per_page' => $args['posts_per_page'], 
            'post_type'      => $args['post_type'], 
            'post_status'    => 'publish', 
            'category__in'   => $tags
        ));
        if (count($query_similar->posts) > 1) {
            printf('%s', $args['before']);
            ?>
            <div class="<?php echo trim(implode(' ', ['cms-related-post', $args['class']]));?>">
                <?php if(!empty($args['title'])) echo '<h3 class="cms-heading cms-related-heading mb-25">'.esc_html($args['title']).'</h3>'; ?>
                <div class="cms-related-post-inner row">
                    <?php foreach ($query_similar->posts as $post):
                        if ($post->ID !== $current_id) : ?>
                            <div class="grid-item col-lg-6 col-12">
                                <div class="grid-item-inner">
                                    <?php 
                                        solatec_post_media([
                                            'id'             => $post->ID,
                                            'thumbnail_size' => 'medium',
                                            'img_class'      => 'cms-radius-8'
                                        ]);
                                    ?>
                                    <h4 class="item-title mt-25">
                                        <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                    </h4>
                                </div>
                            </div>
                        <?php endif;
                    endforeach; ?>
                </div>
            </div>
        <?php 
            printf('%s', $args['after']);
        }
        wp_reset_postdata();
    }
}
/**
 * User custom fields.
 */
if(!function_exists('solatec_user_fields')){
    add_action( 'show_user_profile', 'solatec_user_fields' );
    add_action( 'edit_user_profile', 'solatec_user_fields' );
    function solatec_user_fields($user){

        $user_facebook = get_user_meta($user->ID, 'user_facebook', true);
        $user_twitter = get_user_meta($user->ID, 'user_twitter', true);
        $user_linkedin = get_user_meta($user->ID, 'user_linkedin', true);
        $user_skype = get_user_meta($user->ID, 'user_skype', true);
        $user_google = get_user_meta($user->ID, 'user_google', true);
        $user_youtube = get_user_meta($user->ID, 'user_youtube', true);
        $user_vimeo = get_user_meta($user->ID, 'user_vimeo', true);
        $user_tumblr = get_user_meta($user->ID, 'user_tumblr', true);
        $user_rss = get_user_meta($user->ID, 'user_rss', true);
        $user_pinterest = get_user_meta($user->ID, 'user_pinterest', true);
        $user_instagram = get_user_meta($user->ID, 'user_instagram', true);
        $user_yelp = get_user_meta($user->ID, 'user_yelp', true);

        ?>
        <h3><?php esc_html_e('Social', 'solatec'); ?></h3>
        <table class="form-table">
            <tr>
                <th><label for="user_facebook"><?php esc_html_e('Facebook', 'solatec'); ?></label></th>
                <td>
                    <input id="user_facebook" name="user_facebook" type="text" value="<?php echo esc_attr(isset($user_facebook) ? $user_facebook : ''); ?>" />
                </td>
            </tr>
            <tr>
                <th><label for="user_twitter"><?php esc_html_e('Twitter', 'solatec'); ?></label></th>
                <td>
                    <input id="user_twitter" name="user_twitter" type="text" value="<?php echo esc_attr(isset($user_twitter) ? $user_twitter : ''); ?>" />
                </td>
            </tr>
            <tr>
                <th><label for="user_linkedin"><?php esc_html_e('Linkedin', 'solatec'); ?></label></th>
                <td>
                    <input id="user_linkedin" name="user_linkedin" type="text" value="<?php echo esc_attr(isset($user_linkedin) ? $user_linkedin : ''); ?>" />
                </td>
            </tr>
            <tr>
                <th><label for="user_skype"><?php esc_html_e('Skype', 'solatec'); ?></label></th>
                <td>
                    <input id="user_skype" name="user_skype" type="text" value="<?php echo esc_attr(isset($user_skype) ? $user_skype : ''); ?>" />
                </td>
            </tr>
            <tr>
                <th><label for="user_google"><?php esc_html_e('Google', 'solatec'); ?></label></th>
                <td>
                    <input id="user_google" name="user_google" type="text" value="<?php echo esc_attr(isset($user_google) ? $user_google : ''); ?>" />
                </td>
            </tr>
            <tr>
                <th><label for="user_youtube"><?php esc_html_e('Youtube', 'solatec'); ?></label></th>
                <td>
                    <input id="user_youtube" name="user_youtube" type="text" value="<?php echo esc_attr(isset($user_youtube) ? $user_youtube : ''); ?>" />
                </td>
            </tr>
            <tr>
                <th><label for="user_vimeo"><?php esc_html_e('Vimeo', 'solatec'); ?></label></th>
                <td>
                    <input id="user_vimeo" name="user_vimeo" type="text" value="<?php echo esc_attr(isset($user_vimeo) ? $user_vimeo : ''); ?>" />
                </td>
            </tr>
            <tr>
                <th><label for="user_tumblr"><?php esc_html_e('Tumblr', 'solatec'); ?></label></th>
                <td>
                    <input id="user_tumblr" name="user_tumblr" type="text" value="<?php echo esc_attr(isset($user_tumblr) ? $user_tumblr : ''); ?>" />
                </td>
            </tr>
            <tr>
                <th><label for="user_rss"><?php esc_html_e('Rss', 'solatec'); ?></label></th>
                <td>
                    <input id="user_rss" name="user_rss" type="text" value="<?php echo esc_attr(isset($user_rss) ? $user_rss : ''); ?>" />
                </td>
            </tr>
            <tr>
                <th><label for="user_pinterest"><?php esc_html_e('Pinterest', 'solatec'); ?></label></th>
                <td>
                    <input id="user_pinterest" name="user_pinterest" type="text" value="<?php echo esc_attr(isset($user_pinterest) ? $user_pinterest : ''); ?>" />
                </td>
            </tr>
            <tr>
                <th><label for="user_instagram"><?php esc_html_e('Instagram', 'solatec'); ?></label></th>
                <td>
                    <input id="user_instagram" name="user_instagram" type="text" value="<?php echo esc_attr(isset($user_instagram) ? $user_instagram : ''); ?>" />
                </td>
            </tr>
            <tr>
                <th><label for="user_yelp"><?php esc_html_e('Yelp', 'solatec'); ?></label></th>
                <td>
                    <input id="user_yelp" name="user_yelp" type="text" value="<?php echo esc_attr(isset($user_yelp) ? $user_yelp : ''); ?>" />
                </td>
            </tr>
        </table>
        <?php
    }
}
/**
 * Save user custom fields.
 */
if(!function_exists('solatec_save_user_custom_fields')){
    add_action( 'personal_options_update', 'solatec_save_user_custom_fields' );
    add_action( 'edit_user_profile_update', 'solatec_save_user_custom_fields' );
    function solatec_save_user_custom_fields( $user_id )
    {
        if ( !current_user_can( 'edit_user', $user_id ) )
            return false;

        if(isset($_POST['user_facebook']))
            update_user_meta( $user_id, 'user_facebook', $_POST['user_facebook'] );
        if(isset($_POST['user_twitter']))
            update_user_meta( $user_id, 'user_twitter', $_POST['user_twitter'] );
        if(isset($_POST['user_linkedin']))
            update_user_meta( $user_id, 'user_linkedin', $_POST['user_linkedin'] );
        if(isset($_POST['user_skype']))
            update_user_meta( $user_id, 'user_skype', $_POST['user_skype'] );
        if(isset($_POST['user_google']))
            update_user_meta( $user_id, 'user_google', $_POST['user_google'] );
        if(isset($_POST['user_youtube']))
            update_user_meta( $user_id, 'user_youtube', $_POST['user_youtube'] );
        if(isset($_POST['user_vimeo']))
            update_user_meta( $user_id, 'user_vimeo', $_POST['user_vimeo'] );
        if(isset($_POST['user_tumblr']))
            update_user_meta( $user_id, 'user_tumblr', $_POST['user_tumblr'] );
        if(isset($_POST['user_rss']))
            update_user_meta( $user_id, 'user_rss', $_POST['user_rss'] );
        if(isset($_POST['user_pinterest']))
            update_user_meta( $user_id, 'user_pinterest', $_POST['user_pinterest'] );
        if(isset($_POST['user_instagram']))
            update_user_meta( $user_id, 'user_instagram', $_POST['user_instagram'] );
        if(isset($_POST['user_yelp']))
            update_user_meta( $user_id, 'user_yelp', $_POST['user_yelp'] );
    }
}

/* Author Social */
if(!function_exists('solatec_get_user_social')){
    function solatec_get_user_social($args = []) {
        $args = wp_parse_args($args,[
            'class' => ''
        ]);
        $user_facebook = get_user_meta(get_the_author_meta( 'ID' ), 'user_facebook', true);
        $user_twitter = get_user_meta(get_the_author_meta( 'ID' ), 'user_twitter', true);
        $user_linkedin = get_user_meta(get_the_author_meta( 'ID' ), 'user_linkedin', true);
        $user_skype = get_user_meta(get_the_author_meta( 'ID' ), 'user_skype', true);
        $user_google = get_user_meta(get_the_author_meta( 'ID' ), 'user_google', true);
        $user_youtube = get_user_meta(get_the_author_meta( 'ID' ), 'user_youtube', true);
        $user_vimeo = get_user_meta(get_the_author_meta( 'ID' ), 'user_vimeo', true);
        $user_tumblr = get_user_meta(get_the_author_meta( 'ID' ), 'user_tumblr', true);
        $user_rss = get_user_meta(get_the_author_meta( 'ID' ), 'user_rss', true);
        $user_pinterest = get_user_meta(get_the_author_meta( 'ID' ), 'user_pinterest', true);
        $user_instagram = get_user_meta(get_the_author_meta( 'ID' ), 'user_instagram', true);
        $user_yelp = get_user_meta(get_the_author_meta( 'ID' ), 'user_yelp', true);

        ?>
        <div class="<?php echo trim(implode(' ', ['user-social cms-socials', $args['class']]));?>">
            <?php if(!empty($user_facebook)) { ?>
                <a href="<?php echo esc_url($user_facebook); ?>"><i class="cmsi-facebook-f"></i></a>
            <?php } ?>
            <?php if(!empty($user_twitter)) { ?>
                <a href="<?php echo esc_url($user_twitter); ?>"><i class="cmsi-twitter"></i></a>
            <?php } ?>
            <?php if(!empty($user_linkedin)) { ?>
                <a href="<?php echo esc_url($user_linkedin); ?>"><i class="cmsi-linkedin"></i></a>
            <?php } ?>
            <?php if(!empty($user_rss)) { ?>
                <a href="<?php echo esc_url($user_rss); ?>"><i class="fa fa-rss"></i></a>
            <?php } ?>
            <?php if(!empty($user_instagram)) { ?>
                <a href="<?php echo esc_url($user_instagram); ?>"><i class="cmsi-instagram"></i></a>
            <?php } ?>
            <?php if(!empty($user_google)) { ?>
                <a href="<?php echo esc_url($user_google); ?>"><i class="cmsi-google-plus"></i></a>
            <?php } ?>
            <?php if(!empty($user_skype)) { ?>
                <a href="<?php echo esc_url($user_skype); ?>"><i class="cmsi-skype"></i></a>
            <?php } ?>
            <?php if(!empty($user_pinterest)) { ?>
                <a href="<?php echo esc_url($user_pinterest); ?>"><i class="cmsi-pinterest"></i></a>
            <?php } ?>
            <?php if(!empty($user_vimeo)) { ?>
                <a href="<?php echo esc_url($user_vimeo); ?>"><i class="cmsi-vimeo"></i></a>
            <?php } ?>
            <?php if(!empty($user_youtube)) { ?>
                <a href="<?php echo esc_url($user_youtube); ?>"><i class="cmsi-youtube"></i></a>
            <?php } ?>
            <?php if(!empty($user_yelp)) { ?>
                <a href="<?php echo esc_url($user_yelp); ?>"><i class="cmsi-yelp"></i></a>
            <?php } ?>
            <?php if(!empty($user_tumblr)) { ?>
                <a href="<?php echo esc_url($user_tumblr); ?>"><i class="cmsi-tumblr"></i></a>
            <?php } ?>

        </div> <?php
    }
}

function solatec_social_share_product() { ?>
    <a class="fb-social hover-effect" title="Facebook" target="_blank" href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>"><i class="zmdi zmdi-facebook"></i></a>
    <a class="tw-social hover-effect" title="Twitter" target="_blank" href="https://twitter.com/home?status=<?php the_permalink(); ?>"><i class="zmdi zmdi-twitter"></i></a>
    <a class="g-social hover-effect" title="Google Plus" target="_blank" href="https://plus.google.com/share?url=<?php the_permalink(); ?>"><i class="zmdi zmdi-google-plus"></i></a>
    <a class="pin-social hover-effect" title="Pinterest" target="_blank" href="https://pinterest.com/pin/create/button/?url=<?php echo esc_url(the_post_thumbnail_url( 'full' )); ?>&media=&description=<?php the_title(); ?>"><i class="zmdi zmdi-pinterest"></i></a>
    <?php
}

function solatec_product_nav() {
    global $post;
    $previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
    $next     = get_adjacent_post( false, '', false );

    if ( ! $next && ! $previous )
        return;
    ?>
    <?php
    $next_post = get_next_post();
    $previous_post = get_previous_post();
    if( !empty($next_post) || !empty($previous_post) ) { ?>
        <div class="product-previous-next">
            <?php if ( is_a( $previous_post , 'WP_Post' ) && get_the_title( $previous_post->ID ) != '') { ?>
                <a class="nav-link-prev" href="<?php echo esc_url(get_permalink( $previous_post->ID )); ?>"><i class="fa fa-long-arrow-left"></i></a>
            <?php } ?>
            <?php if ( is_a( $next_post , 'WP_Post' ) && get_the_title( $next_post->ID ) != '') { ?>
                <a class="nav-link-next" href="<?php echo esc_url(get_permalink( $next_post->ID )); ?>"><i class="fa fa-long-arrow-right"></i></a>
            <?php } ?>
        </div>
    <?php }
}
/**
 * WordPress Comments
 * All function for WP Comments
 * ============================
 * */
/**
 * Move comment field to bottom
 */
function solatec_comment_field_to_bottom( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
}
add_filter( 'comment_form_fields', 'solatec_comment_field_to_bottom' );

/**
 * Custom Comment List
 */
function solatec_comment_list( $comment, $args, $depth ) {
    if ( 'div' === $args['style'] ) {
        $tag       = 'div';
        $add_below = 'comment';
    } else {
        $tag       = 'li';
        $add_below = 'div-comment';
    }
    ?>
    <<?php echo ''.$tag ?> <?php comment_class( ['comment', empty( $args['has_children'] ) ? '' : 'parent' ]) ?> id="comment-<?php comment_ID() ?>">
    <?php if ( 'div' != $args['style'] ) : ?>
        <div id="div-comment-<?php comment_ID() ?>" class="comment-body">
        <?php endif; ?>
            <div class="comment-inner row gutters-15 gutters-lg-30 gutters-grid">
                <?php if ($args['avatar_size'] != 0) : ?>
                    <div class="comment-avatar col-auto empty-none"><?php
                        echo get_avatar($comment, solatec_configs('comment')['avatar-size']); 
                    ?></div>
                <?php endif; ?>
                <div class="comment-content col">
                    <div class="cms-heading comment-title"><?php printf( '%s', get_comment_author_link() ); ?></div>
                    <div class="comment-meta">
                        <div class="comment-rating empty-none"><?php
                            /**
                         * The woocommerce_review_before_comment_meta hook.
                         *
                         * @hooked woocommerce_review_display_rating - 10
                         */
                            if(is_singular('product')){
                                do_action( 'woocommerce_review_before_comment_meta', $comment );
                            }
                        ?></div>
                        <div class="empty-none"><?php
                            /**
                             * The woocommerce_review_meta hook.
                             *
                             * @hooked woocommerce_review_display_meta - 10
                             */
                            if(is_singular('product')){
                                do_action( 'woocommerce_review_meta', $comment );
                            }
                        ?></div>
                        <div class="comment-date empty-none"><?php echo get_comment_date().' - '.get_comment_time(); ?></div>
                    </div>
                    <div class="before-comment-text empty-none"><?php
                        if(is_singular('product')){ do_action( 'woocommerce_review_before_comment_text', $comment ); }
                    ?></div>
                    <div class="comment-text empty-none"><?php 
                        comment_text(); 
                        /**
                         * The woocommerce_review_comment_text hook
                         *
                         * @hooked woocommerce_review_display_comment_text - 10
                         */
                        if(is_singular('product')){
                            do_action( 'woocommerce_review_comment_text', $comment );
                        }
                    ?></div>
                    <div class="after-comment-text empty-none"><?php 
                        if(is_singular('product')){ do_action( 'woocommerce_review_after_comment_text', $comment ); }
                    ?></div>
                    <div class="comment-reply"><?php 
                        comment_reply_link( array_merge( $args, array(
                            'add_below' => $add_below,
                            'depth'     => $depth,
                            'max_depth' => $args['max_depth']
                        ) ) ); 
                    ?></div>
                </div>
            </div>
        <?php if ( 'div' != $args['style'] ) : ?>
        </div>
    <?php endif;
}

/**
 * Comment form fields
**/
if(!function_exists('solatec_comment_form_args')){
    function solatec_comment_form_args($args = []){
        $args = wp_parse_args($args, []);
        $commenter = [
            'comment_author' => '',
            'comment_author_email' => ''
        ];
        $icon = is_rtl() ? 'cmsi-arrow-circle-left' : 'cmsi-arrow-circle-right';
        $cms_comment_fields = array(
            'id_form'              => 'commentform',
            'title_reply'          => esc_attr__( 'Leave A Reply', 'solatec'),
            'title_reply_to'       => esc_attr__( 'Leave A Reply To ', 'solatec') . '%s',
            'cancel_reply_link'    => esc_attr__( 'Cancel Reply', 'solatec'),
            'id_submit'            => 'submit',
            'class_submit'         => 'btn-xl btn-accent',
            'label_submit'         => esc_attr__( 'Submit Comment', 'solatec'),
            'submit_button'        => '<button name="%1$s" type="submit" id="%2$s" class="%3$s" value="%4$s"><span class="cms-btn-content"><span class="cms-btn-icon"><span class="'.$icon.'"></span></span><span class="cms-btn-text">%4$s</span></span></button>',    
            'comment_notes_before' => '',
            'comment_field'        =>  '',
        );

        $cms_fields = [];
        //open
        $cms_fields['open'] = '<div class="cms-comment-form-fields-wrap row">';
        // author
        $cms_fields['author'] = '<div class="comment-form-field comment-form-author col-lg-4 col-md-4 col-sm-12">'.
                    '<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) .
                    '" size="30" placeholder="'.esc_attr__('Author', 'solatec').'"/></div>';
        // email 
        $cms_fields['email'] = '<div class="comment-form-field comment-form-email col-lg-4 col-md-4 col-sm-12">'.
                    '<input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) .
                    '" size="30" placeholder="'.esc_attr__('Email', 'solatec').'"/></div>';
        // website
        $cms_fields['website'] = '<div class="comment-form-field comment-form-website col-lg-4 col-md-4 col-sm-12">'.
                    '<input id="website" name="website" type="text" value="" size="30" placeholder="'.esc_attr__('Website', 'solatec').'"/></div>';
        //Close 
        $cms_fields['close'] = '</div>';

        $fields =  apply_filters( 'comment_form_default_fields', $cms_fields);
        $cms_comment_fields['fields'] = $fields;

        // Comment Field Message
        //$cms_comment_fields['comment_field'] = '';
        if(is_user_logged_in()){
            $cms_comment_fields['comment_field'] .= solatec_comment_rating_fields(false);
            $cms_comment_fields['comment_field'] .= solatec_woocommerce_comment_rating_fields(false);
        }

        $cms_comment_fields['comment_field'] .= '<div class="cms-comment-form-fields-wrap cms-comment-form-fields-message row"><div class="comment-form-field comment-form-comment col-12"><textarea id="comment-msg" name="comment" cols="45" rows="8" placeholder="'.esc_attr__('Comment', 'solatec').'" aria-required="true">' .'</textarea></div></div>';

        return $cms_comment_fields;
    }
}
/**
 * Header Top
 * ==========
**/
if(!function_exists('solatec_header_top_social')){
    function solatec_header_top_social($args=[]) {
        $args = wp_parse_args($args, [
            'tag'    => 'div',
            'class'  => '',
            'before' => '',
            'after'  => ''
        ]);
        $social_list = solatec_get_opts( 't_social_list' );
        if(!empty($args['before'])) echo wp_kses_post($args['before']);
            echo '<'.$args['tag'].' class="'.implode(' ', ['cms-social-list', $args['class']]).'">';
                if($social_list && isset($social_list['enabled'])){
                    foreach ($social_list['enabled'] as $social_key => $social_name){
                        $social_link = solatec_get_opt( 'social_' . $social_key . '_url' );
                        $social_link = !empty($social_link)?$social_link:'#';
                        if($social_key == 'facebook') $social_key = $social_key.'-f';
                        if($social_key !== 'placebo') echo '<a href="'. esc_url($social_link) .'" target="_blank"><span class="cms-icon fab fa-' . esc_attr($social_key) . '"></span></a>';
                    }
                }
            echo '</'.$args['tag'].'>';
        if(!empty($args['after'])) echo wp_kses_post($args['after']);
    }
}
if(!function_exists('solatec_header_top')){
    function solatec_header_top($args = []){
        if(is_singular('cms-header-top') || is_singular('cms-footer') ) return;
        $args = wp_parse_args($args, []);
        $header_top_layout = solatec_get_opts('header_top_layout', '');
        $cms_post = get_post($header_top_layout);
        if(in_array($header_top_layout, ['-1', '0', 'none', ''])) return;
        if (!is_wp_error($cms_post) && $cms_post->ID == $header_top_layout && class_exists('Elementor_Theme_Core')){
            $content = \Elementor\Plugin::$instance->frontend->get_builder_content( $header_top_layout );
            if(empty($content)){
                $content = $cms_post->post_content;
            }
        } else {
            $content = '';
        }
    ?>
    <div id="cms-header-top" class="cms-header-top empty-none container-full"><?php 
        printf('%s', $content); 
    ?></div>
    <?php
    }
}
/**
 * Header layout
 **/
if(!function_exists('solatec_header_layout')){
    function solatec_header_layout()
    {
        if(is_singular('cms-header-top') || is_singular('cms-footer')) return;
        $header_layout = solatec_get_opts( 'header_layout', '1' );
        get_template_part( 'template-parts/header/header-layout', $header_layout );
    }
}
/**
 * Header css class
*/
if(!function_exists('solatec_header_css_class')){
    function solatec_header_css_class($class=''){
        $classes = [
            'cms-header',
            'header-layout'.solatec_get_opts('header_layout','1')
        ];
        $header_sticky = solatec_get_opts('sticky_on','0');
        $header_ontop = solatec_get_opts('header_ontop','0');
        if($header_sticky == '1') $classes[] = 'is-sticky header-sticky';
        if($header_ontop == '1') $classes[] = 'is-ontop header-ontop';
        if(!empty($class)) $classes[] = $class;

        echo esc_attr(implode(' ', $classes));
    }
}

/**
 * Header Container CSS class
*/
if(!function_exists('solatec_header_container_css_class')){
    function solatec_header_container_css_class($class = ''){
        $classes = ['header-container container'];
        $classes[] = solatec_get_opts('header_layout_width', 'container');
        $classes[] = $class;
        echo esc_attr(trim(implode(' ', $classes)));
    }
}

/**
 * Header Logo
*/ 
if(!function_exists('solatec_logo')){
    function solatec_logo($args = []){
        $args = wp_parse_args($args, [
            'class' => '',
            'before' => '',
            'after' => ''
        ]);
    ?>
        <div class="<?php echo implode(' ', ['cms-header-logo', $args['class']]); ?>">
            <?php 
                printf('%s', $args['before']);
                do_action('solatec_before_logo');
                get_template_part( 'template-parts/header/header-branding' ); 
                do_action('solatec_after_logo');
                printf('%s', $args['after']);
            ?>
        </div>  
    <?php
    }
}


// Header Button 
if(!function_exists('solatec_header_button')){
    function solatec_header_button($args=[]){
        $args = wp_parse_args($args,[
            'class'     => '',
            'btn_class' => '',
            'show_icon'  => false,
            'icon_class' => '',
            'icon_pos'   => 'before'
        ]);
        $h_btn_on          = solatec_get_opts( 'h_btn_on', '0' );
        if($h_btn_on == '0') return;

        $h_btn_text        = solatec_get_opts( 'h_btn_text', 'Your Text' );
        $h_btn_link_type   = solatec_get_opts( 'h_btn_link_type', 'page' );
        $h_btn_link        = solatec_get_opts( 'h_btn_link' );
        $h_btn_link_custom = solatec_get_opts( 'h_btn_link_custom' );
        $h_btn_target      = solatec_get_opts( 'h_btn_target', '_self' );
        if($h_btn_link_type == 'page') {
            $h_btn_url = get_permalink($h_btn_link);
        } else {
            $h_btn_url = $h_btn_link_custom;
        }
        $btn_icon = '';
        if($args['show_icon'] === true){
            $btn_icon = '<span class="cms-btn-icon '.$args['icon_class'].'"></span>';
        }
        ?>
            <div class="<?php echo trim(implode(' ', ['cms-header-btn', $args['class']])); ?>">
                <a href="<?php echo esc_url( $h_btn_url ); ?>" target="<?php echo esc_attr($h_btn_target); ?>" class="<?php echo trim(implode(' ', ['h-btn', $args['btn_class']])); ?>">
                    <span class="cms-btn-content">
                        <?php if($args['icon_pos'] === 'before') printf('%s', $btn_icon); ?>
                        <span class="cms-btn-text"><?php  echo esc_html( $h_btn_text ); ?></span>
                        <?php if($args['icon_pos'] === 'after') printf('%s', $btn_icon); ?>
                    </span>
                </a>
            </div>
    <?php
    }
}
// Header Button 02
if(!function_exists('solatec_header_button2')){
    function solatec_header_button2($args=[]){
        $args = wp_parse_args($args,[
            'class'      => '',
            'btn_class'  => '',
            'show_icon'  => false,
            'icon_class' => '',
            'icon_pos'   => 'before'
        ]);
        $h_btn_on          = solatec_get_opts( 'h_btn_on2', '0' );
        if($h_btn_on == '0') return;
        
        $h_btn_text        = solatec_get_opts( 'h_btn_text2', 'Your Text' );
        $h_btn_link_type   = solatec_get_opts( 'h_btn_link_type2', 'page' );
        $h_btn_link        = solatec_get_opts( 'h_btn_link2' );
        $h_btn_link_custom = solatec_get_opts( 'h_btn_link_custom2' );
        $h_btn_target      = solatec_get_opts( 'h_btn_target2', '_self' );
        if($h_btn_link_type == 'page') {
            $h_btn_url = get_permalink($h_btn_link);
        } else {
            $h_btn_url = $h_btn_link_custom;
        }
        $btn_icon = '';
        if($args['show_icon'] === true){
            $btn_icon = '<span class="cms-btn-icon '.$args['icon_class'].'"></span>';
        }
        ?>
            <div class="<?php echo trim(implode(' ', ['cms-header-btn', $args['class']])); ?>">
                <a href="<?php echo esc_url( $h_btn_url ); ?>" target="<?php echo esc_attr($h_btn_target); ?>" class="<?php echo trim(implode(' ', ['h-btn', $args['btn_class']])); ?>">
                    <span class="cms-btn-content">
                        <?php if($args['icon_pos'] === 'before') printf('%s', $btn_icon); ?>
                        <span class="cms-btn-text"><?php echo esc_html( $h_btn_text ); ?></span>
                        <?php if($args['icon_pos'] === 'after') printf('%s', $btn_icon); ?>
                    </span>
                </a>
            </div>
    <?php
    }
}
// Header Hotline
if(!function_exists('solatec_header_hotline')){
    function solatec_header_hotline($args=[]){
        $args = wp_parse_args($args,[
            'class'      => '',
            'show_icon'  => true,
            'icon_class' => '',
            'icon_pos'   => 'before'
        ]);
        $h_btn_on          = solatec_get_opts( 'h_hotline_on', '0' );
        if($h_btn_on == '0') return;
        
        $h_btn_text        = solatec_get_opts( 'h_hotline_text', '01061245741' );
        $h_btn_url         = 'tel:'. $h_btn_text;
        $btn_icon = '';
        if($args['show_icon'] === true){
            $btn_icon = '<span class="cms-btn-icon '.$args['icon_class'].'"></span>';
        }
        ?>
            <div class="<?php echo trim(implode(' ', ['cms-header-btn', $args['class']])); ?>">
                <a href="<?php echo esc_url( $h_btn_url ); ?>">
                    <span class="cms-btn-content">
                        <?php if($args['icon_pos'] === 'before') printf('%s', $btn_icon); ?>
                        <span class="cms-btn-text"><?php echo esc_html( $h_btn_text ); ?></span>
                        <?php if($args['icon_pos'] === 'after') printf('%s', $btn_icon); ?>
                    </span>
                </a>
            </div>
    <?php
    }
}
// Header Search
if(!function_exists('solatec_header_search')){
    function solatec_header_search($args=[]){
        $args = wp_parse_args($args, [
            'class' => '',
            'icon'  => 'fa fa-search',
            'before' => '',
            'after'  => ''
        ]);
        $search_on = solatec_get_opts('search_on', '0');
        $css_class = ['cms-header-search header-icon', $args['class']];
        if($search_on == '0') return;
        wp_enqueue_script('magnific-popup');
        wp_enqueue_style('magnific-popup');
        printf('%s', $args['before']);
    ?>
        <div class="<?php echo implode(' ', $css_class);?>">
            <a href="#cms-search-popup" class="h-btn-search menu-color cms-transition"><span class="<?php echo esc_attr($args['icon']);?>"></span></a>
        </div>
    <?php
        printf('%s', $args['after']);
    }
}
/**
 * Search Popup
 */
if(!function_exists('solatec_search_popup')){
    add_action('wp_footer', 'solatec_search_popup', 1);
    function solatec_search_popup(){
        $search_on = solatec_get_opts( 'search_on', '0' );
        $search_text = solatec_get_opts( 'search_text', 'Type Words Then Enter' );
        ?>
        <div class="d-none">
            <div id="cms-search-popup" class="cms-search-popup">
                <div class="container">
                    <form role="search" method="get" class="cms-search-form cms-search-form-popup" action="<?php echo esc_url( home_url( '/' ) ); ?>">
                        <input type="search" class="cms-search-field" placeholder="<?php echo esc_attr( $search_text); ?>" value="<?php echo get_search_query(); ?>" name="s" />
                        <button type="submit" class="cms-search-submit" value="<?php echo esc_attr_x( 'Search', 'submit button', 'solatec' ); ?>"></button>
                    </form>
                </div>
            </div>
        </div>
        <?php
    }
}
// Header Cart
if(!function_exists('solatec_header_cart')){
    function solatec_header_cart($args=[]){
        $cart_on = solatec_get_opts( 'cart_on', '0' );
        if(!class_exists('Woocommerce') || $cart_on == '0') return;
        $args = wp_parse_args($args,[
            'class'  => '',
            'style'  => '1',
            'icon'   => 'fa fa-shopping-cart',
            'before' => '',
            'after'  => ''
        ]);
        $css_class = ['cms-header-cart header-icon relative', $args['class']];

        printf('%s', $args['before']);
    ?>
        <div class="<?php echo implode(' ', $css_class); ?>">
            <span class="h-btn-cart menu-color cms-transition">
                <span class="<?php echo esc_attr($args['icon']);?>"></span>
                <span class="header-count cart-count cart_total style-<?php echo esc_attr($args['style']);?>"><?php solatec_woocommerce_cart_counter(['style' => $args['style']]); ?></span>
            </span>
            <div class="widget_shopping_cart cms-shadow-1">
                <div class="widget_shopping_cart_content">
                    <?php woocommerce_mini_cart(); ?>
                </div>
            </div>
        </div>
    <?php
        printf('%s', $args['after']);
    }
}
if(!function_exists('solatec_woocommerce_add_to_cart_fragments')){
    add_filter('woocommerce_add_to_cart_fragments', 'solatec_woocommerce_add_to_cart_fragments', 10, 1 );
    function solatec_woocommerce_add_to_cart_fragments( $fragments ) {
        if(!class_exists('WooCommerce')) return;
        ob_start();
        $header_layout = solatec_get_opts('header_layout','1');
        switch ($header_layout) {
            case '5':
                $cart_style = '2';
                break;
            
            default:
                $cart_style = '1';
                break;
        }
        ?>
        <span class="header-count cart-count cart_total style-<?php echo esc_attr($cart_style);?>"><?php solatec_woocommerce_cart_counter(['style' => $cart_style]); ?></span>
        <?php
        $fragments['.cart_total'] = ob_get_clean();
        return $fragments;
    }
}

if(!function_exists('solatec_woocommerce_cart_counter')){
    function solatec_woocommerce_cart_counter($args=[]){
        if(!class_exists('WooCommerce')) return;
        $args = wp_parse_args($args, [
            'style' => '1'
        ]);
        switch ($args['style']) {
            case '2':
                $count = WC()->cart->cart_contents_count;
                break;
            
            default:
                $count = WC()->cart->cart_contents_count;
                break;
        }
        echo solatec_html($count);
    }
}

// Mobile menu icon
if(!function_exists('solatec_mobile_menu_icon')){
    function solatec_mobile_menu_icon($args=[]){
        $args = wp_parse_args($args,[
            'class' => ''
        ]);
        $css_class = ['main-menu-mobile', $args['class']];
        ?>
            <div id="main-menu-mobile" class="<?php echo implode(' ', $css_class);?>">
                <span class="btn-nav-mobile open-menu">
                    <span></span>
                </span>
            </div>
        <?php
    }
}
// Menu Right Class
if(!function_exists('solatec_site_menu_right_class')){
    function solatec_site_menu_right_class($class=''){
        $css_class         = ['cms-navigation-attrs'];
        $cart_on           = solatec_get_opts('cart_on','0');
        $search_on         = solatec_get_opts('search_on','0');
        $social_list       = solatec_get_opts( 'social_list', ['enabled' => []]);
        $social_on         = (count($social_list['enabled']) > 1) ? '1' : '0';
        $hidden_sidebar_on = solatec_get_opts('hidden_sidebar_on', '0');
        $show_secondary_menu = solatec_get_opts('show_secondary_menu', '0');
        $header_switch_language = solatec_get_opts('header_switch_language', '0');
        $h_btn_on1          = solatec_get_opts( 'h_btn_on', '0' );
        $h_btn_on2          = solatec_get_opts( 'h_btn_on2', '0' );
        $h_btn_on3         = solatec_get_opts( 'h_hotline_on', '0' );

        if($cart_on == '1' || $search_on == '1' || $social_on == '1' || $hidden_sidebar_on == '1' || $header_switch_language == '1' || $h_btn_on1 == '1' || $h_btn_on2 == '1' || $h_btn_on3 == '1') $css_class[] = 'has-atts';
        $css_class[] =  $class;
        echo implode(' ', $css_class);
    }
}

/**
 * Social Icon
*/
function solatec_header_social($args=[]) {
    $args = wp_parse_args($args,[
        'icon_class' => '',
        'before' => '',
        'after'  => ''
    ]);
    $social_list = solatec_get_opts( 'social_list' );
    if(isset($social_list['enabled']) && count($social_list['enabled']) === 1) return;
    if($social_list && isset($social_list['enabled'])){
        printf('%s', $args['before']);
        foreach ($social_list['enabled'] as $social_key => $social_name){
            $social_link = solatec_get_opt( 'social_' . $social_key . '_url' );
            $social_icon = !empty(solatec_get_opt( 'social_' . $social_key . '_icon')) ? solatec_get_opt( 'social_' . $social_key . '_icon') : 'fab fa-'.$social_key;
            $social_link = !empty($social_link)?$social_link:'#';
            if($social_key !== 'placebo') echo '<a href="'. esc_url($social_link) .'" target="_blank" class="'.esc_attr($args['icon_class']).'"><span class="'.esc_attr($social_icon).'"></span></a>';
        }
        printf('%s', $args['after']);
    }
}

/**
 * Secondary Menu
**/
if(!function_exists('solatec_secondary_menu')){
    function solatec_secondary_menu($args = []){
        $args = wp_parse_args($args, [
            'before'     => '',
            'after'      => '',
            'class'      => '',
            'menu_class' => '',
            'walker'     => ''
        ]);
        if(solatec_get_opts('show_secondary_menu') !== '1' || empty(solatec_get_opts('secondary_menu', ''))) return;
        printf('%s', $args['before']);
        ?>
        <div class="cms-secondary-menu-wrap">
            <div class="cms-secondary-menu-title"><?php echo esc_html(solatec_get_opts('secondary_menu_title', 'Your Menu')); ?></div>
            <?php
                wp_nav_menu( array(
                    'theme_location'  => '',
                    'menu'            => solatec_get_opts('secondary_menu', ''), 
                    'container'       => '',
                    'container_class' => $args['class'],
                    'menu_id'         => 'cms-secondary-menu',
                    'menu_class'      => trim('cms-secondary-menu unstyled clearfix '.$args['menu_class']),
                    'walker'          => $args['walker'],
                ) );
            ?>
        </div>
        <?php
        printf('%s', $args['after']);
    }
}
/**
 * Language Switcher
*/
if(!function_exists('solatec_header_language_switcher')){
    function solatec_header_language_switcher($args = []){
        if(!class_exists('TRP_Translate_Press') || solatec_get_opts('header_switch_language', '0') == '0') return;
        $args = wp_parse_args($args, [
            'class'  => '',
            'before' => '',
            'after'  => '',
            'full_names' => true
        ]);
        $classes = ['empty-none cms-language-switcher', 'cms-language-switcher-on-'.solatec_get_opts('header_switch_language', '0'), $args['class']];
        printf('%s', $args['before']);
        ?>
        <div class="<?php echo trim(implode(' ', $classes));?>"><?php 
            echo do_shortcode('[language-switcher full_names = "'.$args['full_names'].'"]'); 
        ?></div>
        <?php
        printf('%s', $args['after']);
    }
}
/**
 * Page title layout
 * =================
 **/
if(!function_exists('solatec_page_title_layout')){
    function solatec_page_title_layout($args = []) {
        if(is_singular('cms-header-top') || is_singular('cms-footer') || is_404()) return;
        $show_pagetitle  = solatec_get_opts( 'pagetitle', '1' );
        
        if(is_singular('post') || is_singular('product')){
            $ptitle_layout = '10';
        } else {
           $ptitle_layout   = solatec_get_opts( 'ptitle_layout', solatec_configs('ptitle')['layout'] );
        }
        $show_title      = solatec_get_opts( 'ptitle_title_on', '1');
        $show_breadcrumb = solatec_get_opts( 'ptitle_breadcrumb_on', '1' );
        if($show_pagetitle !== '1' || ($show_title !== '1' && $show_breadcrumb !== '1') ) return;

        $args = wp_parse_args($args, [
            'class' => ''
        ]);
        ?>
        <div id="cms-pagetitle" class="cms-pagetitle cms-page-title-layout<?php echo esc_attr($ptitle_layout); ?> relative">
            <div class="cms-page-title-overlay"></div>
            <div class="container relative">
                <div class="cms-page-title-inner">
                    <?php get_template_part( 'template-parts/page-title/layout', $ptitle_layout ); ?>
                </div>
            </div>
            <?php if(!in_array($ptitle_layout , ['10'])): ?>
                <a href="#cms-main" class="cms-scroll cms-ripple cms-ripple-accent cms-vibrate"><span class="cmsi-long-arrow-down"></span></a>
            <?php endif; ?>
        </div>
        <?php
    }
}

/**
 * Page Title 
*/
if(!function_exists('solatec_page_title')){
    function solatec_page_title($args = []){
        $show_title = solatec_get_opts('ptitle_title_on', '1');
        if($show_title !== '1') return;
        $args = wp_parse_args($args, [
            'class'     => '',
            'sub_class' => '',
            'before'    => '',
            'after'     => ''
        ]);
        $titles        = solatec_get_page_titles();
        $sub_title     = solatec_get_opts( 'sub_title','');

        printf('%s', $args['before']);
            if ( $titles['title'] ){
                printf( '<div class="cms-page-title cms-heading text-25 text-lg-40 font-500 %1$s">%2$s</div>',$args['class'], $titles['title'] );
            }
            if(!empty($sub_title)) { 
                printf( '<div class="cms-page-sub-title cms-heading text-lg-20 font-500 %1$s">%2$s</div>',$args['sub_class'], $sub_title);
            }
        printf('%s', $args['after']);
    }
}

/**
 * Prints HTML for breadcrumbs.
 */
if(!function_exists('solatec_breadcrumb')){
    function solatec_breadcrumb($args = []){
        $args = wp_parse_args($args, [
            'show_breadcrumb' => solatec_get_opts( 'ptitle_breadcrumb_on', '1' )
        ]);
        if ( ! class_exists( 'CMS_Breadcrumb' ) || $args['show_breadcrumb'] !== '1' )
        {
            return;
        }

        $breadcrumb = new CMS_Breadcrumb();
        $entries = $breadcrumb->get_entries();

        if ( empty( $entries ) )
        {
            return;
        }
        $args = wp_parse_args($args, [
            'before'     => '',
            'after'      => '',
            'divider'    => '',
            'class'      => '',
            'link_class' => '',
            'text_class' => ''
        ]);
        ob_start();
        foreach ( $entries as $entry )
        {
            $entry = wp_parse_args( $entry, array(
                'label' => '',
                'url'   => ''
            ) );

            if ( empty( $entry['label'] ) )
            {
                continue;
            }

            echo '<div class="breadcrumb-item">';

            if ( ! empty( $entry['url'] ) )
            {
                printf(
                    '<a class="breadcrumb-link '.$args['link_class'].'" href="%1$s">%2$s</a>%3$s',
                    esc_url( $entry['url'] ),
                    esc_attr( $entry['label'] ),
                    $args['divider']
                );
            }
            else
            {
                printf( '<span class="breadcrumb-text '.$args['text_class'].'" >%s</span>%2$s', $entry['label'], $args['divider'] );
            }

            echo '</div>';
        }

        $output = ob_get_clean();

        if ( $output )
        {
            printf('%s', $args['before']);
            printf( '<div class="cms-breadcrumb %s">%s</div>', $args['class'], $output);
            printf('%s', $args['after']);
        }
    }
}
/**
 * All function for footer
 * =======================
*/
/**
 * Footer 
 **/
if(!function_exists('solatec_footer')){
    function solatec_footer()
    {
        if(is_singular('cms-header-top') || is_singular('cms-footer')) return;
        $footer_layout = solatec_get_opts( 'footer_layout', '1' );
        get_template_part( 'template-parts/footer/footer-layout', $footer_layout );
    }
}
/*
 * Footer css class
*/
if(!function_exists('solatec_footer_css_class')){
    function solatec_footer_css_class($args = []){
        $args = wp_parse_args($args, [
            'class' => ''
        ]);
        $footer_fixed = solatec_get_opts('footer_fixed', '0');
        $css_classes = [
            'cms-footer',
            'relative'
        ];
        if($footer_fixed == '1') $css_classes[] = 'cms-footer-fixed';
        echo trim(implode(' ', $css_classes));
    }
}

/**
 * Footer Copyright
**/
if(!function_exists('solatec_footer_copyright')){
    function solatec_footer_copyright($args = []){
        $args = wp_parse_args($args, [
            'class' => ''
        ]);
        $classes = ['cms-footer-copyright', $args['class']];

        $default_copyright_text = sprintf( esc_html__('&copy; %s %s by %s. All Rights Reserved.','solatec'), date('Y') , get_bloginfo('name'), '<a href="'.esc_url('https://themeforest.net/user/cmssuperheroes').'" rel="nofollow" target="_blank">'.esc_html__('CMSSuperHeroes','solatec').'</a>');
    ?>
    <div class="<?php echo trim(implode(' ', $classes));?>">
        <?php echo solatec_get_opts('footer_copyright', $default_copyright_text); ?>
    </div>
    <?php
    }
}

// Footer Bottom
if(!function_exists('solatec_footer_bottom')){
    function solatec_footer_bottom(){
    ?>
        <div class="cms-footer-bottom">
            <div class="container">
                <div class="row gutters-30 gutters-grid justify-content-between align-items-center">
                    <div class="col-12 col-md-auto text-center text-md-start">
                        <?php solatec_footer_copyright(); ?>
                    </div>
                    <div class="cms-12 col-md-auto text-center text-md-end empty-none"><?php 
                        solatec_render_socials_list([
                            'name'   => 'f_social_list',
                            'before' => '<div class="cms-footer-social cms-socials cms-social-layout-4 justify-content-center">',
                            'after'  => '</div>'
                        ]);
                        dynamic_sidebar('sidebar-footer-bottom');
                    ?></div>
                </div>
            </div>
        </div>
    <?php
    }
}
// Foter elementor builder
if(!function_exists('solatec_footer_elementor_builder')){
    function solatec_footer_elementor_builder(){
        $footer_layout = solatec_get_opts('footer_layout', '1');
        if(in_array($footer_layout, ['-1', '0', '1', 'none'])) return;
        $cms_post = get_post($footer_layout);
        if (!is_wp_error($cms_post) && $cms_post->ID == $footer_layout && class_exists('Elementor_Theme_Core')){
            $content = \Elementor\Plugin::$instance->frontend->get_builder_content( $footer_layout );
            if(!empty($content)){
                etc_print_html($content);
            } else {
                etc_print_html($cms_post->post_content);
            }
        }
    }
}

/***
 * Back to top
*/
if(!function_exists('solatec_backtotop')){
    add_action('wp_footer', 'solatec_backtotop',2);
    function solatec_backtotop($args = []){
    $back_totop_on = solatec_get_opt('back_totop_on', '1');
    $backtotop_icon = solatec_get_opt('backtotop_icon', 'cmsi-long-arrow-up');
    if ('1' !== $back_totop_on) return;
    ?>
        <a href="#" class="cms-scroll cms-scroll-top"><span class="cms-scroll-top-arrow cms-scroll-top-icon"><span class="<?php echo esc_attr($backtotop_icon);?>"></span></span></a>
    <?php 
    } 
}

/**
 * Social Icon
*/
function solatec_render_socials_list($args=[]) {
    $args = wp_parse_args($args,[
        'name'       => '',
        'icon_class' => '',
        'before'     => '',
        'after'      => ''
    ]);
    if(empty($args['name'])) return;
    $social_list = solatec_get_opts($args['name']);
    
    if(isset($social_list['enabled']) && count($social_list['enabled']) === 1) return;
    if($social_list && isset($social_list['enabled'])){
        printf('%s', $args['before']);
        foreach ($social_list['enabled'] as $social_key => $social_name){
            $social_link = solatec_get_opt( 'social_' . $social_key . '_url' );
            $social_icon = !empty(solatec_get_opt( 'social_' . $social_key . '_icon')) ? solatec_get_opt( 'social_' . $social_key . '_icon') : 'cmsi-'.$social_key;
            $social_link = !empty($social_link)?$social_link:'#';
            if($social_key !== 'placebo') echo '<a href="'. esc_url($social_link) .'" target="_blank" class="'.esc_attr($args['icon_class']).'"><span class="'.esc_attr($social_icon).'"></span></a>';
        }
        printf('%s', $args['after']);
    }
}
if(!function_exists('solatec_get_sidebar')){
    function solatec_get_sidebar($check = true){
        global $wp_query;
        if ( isset($_GET['post_type'])) {
            $sidebar = 'sidebar-'.$_GET['post_type'];
        } elseif (isset($wp_query->post->post_type) && !is_search()){
            $sidebar = 'sidebar-'.$wp_query->post->post_type;
        } elseif ( is_search() ) {
            $sidebar = 'sidebar-post';
        } else {
            $sidebar = 'sidebar-post';
        }

        if($check)
            return is_active_sidebar($sidebar);
        else 
            return $sidebar;
    }
}
if(!function_exists('solatec_sidebar_position')){
    function solatec_sidebar_position($args = []){ 
        global $wp_query;
        $args = wp_parse_args($args, [
            'sidebar_pos' => 'archive_sidebar_pos'
        ]);
        $sidebar_pos = solatec_get_opts($args['sidebar_pos'], solatec_configs('blog')['archive_sidebar_pos']);
        return $sidebar_pos;
    }
}
/*
 * Sidebar area css class
*/
function solatec_sidebar_css_class($args=[]){
    $args = wp_parse_args($args, [
        'content_col' => 'archive_content_col',
        'sidebar_pos' => 'archive_sidebar_pos',
        'class'       => ''
    ]);
    $classes = [
        'cms-sidebar-area',
        'cms-sidebar-area-'.solatec_sidebar_position(['sidebar_pos' => $args['sidebar_pos']])
    ];
    $sidebar_position   = solatec_sidebar_position(['sidebar_pos' => $args['sidebar_pos']]);
    if( in_array($sidebar_position, ['0', 'none', 'bottom']) ){
        $classes[] = 'col-12';
    } else {
        $content_grid_class = (int) solatec_get_opts($args['content_col'], solatec_configs('blog')['archive_content_col']);
        $sidebar_grid_class = 12 - $content_grid_class;
        $classes[] = 'col-lg-'.$sidebar_grid_class; 
    }
    $classes[] = $args['class'];
    echo trim(implode(' ', $classes));
}
/**
 * Show Sidebar
*/
function solatec_sidebar($args = []){
    $args = wp_parse_args($args, [
        'content_col' => 'archive_content_col',
        'sidebar_pos' => 'archive_sidebar_pos',
        'class'       => ''
    ]);
    $sidebar            = solatec_get_sidebar(false);
    $sidebar_position   = solatec_sidebar_position([
        'sidebar_pos' => $args['sidebar_pos']
    ]);
    if( in_array($sidebar_position, ['0','none']) ) return;
    ?>
    <div id="cms-sidebar-area" class="<?php solatec_sidebar_css_class(['content_col' => $args['content_col'], 'sidebar_pos' => $args['sidebar_pos'],'class' => $args['class']]); ?>">
        <div class="cms-sidebar-area-inner"><?php
            get_sidebar(); 
        ?></div>
    </div>
    <?php
}
/**
 * Sidebar Hidden
 */
if(!function_exists('solatec_sidebar_hidden')){
    add_action('wp_footer', 'solatec_sidebar_hidden');
    function solatec_sidebar_hidden()
    {
        $hidden_sidebar_on = solatec_get_opts( 'hidden_sidebar_on', '0' );
        if($hidden_sidebar_on == '0' || !is_active_sidebar('sidebar-hidden')) return; 
        ?>
            <div class="cms-hidden-sidebar">
                <div class="cms-hidden-close fas fa-times"></div>
                <div class="cms-hidden-sidebar-inner cms-mousewheel p-30">
                    <div class="cms-hidden-sidebar-inner2 cms-mousewheel-inner">
                        <div class="cms-sidebar-area">
                            <div class="cms-sidebar-area-inner">
                                <?php dynamic_sidebar( 'sidebar-hidden' ); ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php
    }
}
if(!function_exists('solatec_hidden_sidebar_icon')){
    function solatec_hidden_sidebar_icon($args = []){
        if(solatec_get_opts( 'hidden_sidebar_on', '0' ) != '1' || !is_active_sidebar('sidebar-hidden')) return;
        $args = wp_parse_args($args, [
            'class' => '',
            'icon'  => 'fas fa-sign-out-alt'
        ]);
    ?>
        <div class="<?php echo trim(implode(' ', ['cms-header-hidden-sidebar header-icon cms-transition', $args['class']]));?>">
            <span class="<?php echo trim(implode(' ', [$args['icon']]));?>"></span>
        </div>
    <?php
    }
}

/**
 * Post Thumbnail
*/
if(!function_exists('solatec_post_thumbnail')){
    function solatec_post_thumbnail($args=[]){
        $args = wp_parse_args($args,[
            'id'              => null,
            'thumbnail_size'  => is_single() ? 'large' : 'medium',
            'echo'            => true,
            'default_thumb'   => solatec_configs('default_post_thumbnail'),
            'thumbnail_is_bg' => solatec_configs('thumbnail_is_bg'),
            'class'           => '',
            'img_class'       => '',
            'show_image'      => true,
            'before'          => '',
            'after'           => ''   
        ]);
        extract($args);
        if(!has_post_thumbnail($args['id']) && !$default_thumb) return;

        $thumbnail_atts = [];
        // class
        $thumbnail_atts_class = ['post-image','cms-post-image', $args['class']];
        if($thumbnail_is_bg) $thumbnail_atts_class[] = 'thumbnai-is-bg';
        $thumbnail_atts[] = 'class="'.implode(' ', $thumbnail_atts_class).'"';
        // style
        $thumbnail_atts_style = [];
        if($thumbnail_is_bg) $thumbnail_atts_style[] = 'background-image: url('.solatec_get_image_url_by_size(['id'=>$id,'size'=> 'full', 'default_thumb' => $default_thumb]).')';
        if(!empty($thumbnail_atts_style)) $thumbnail_atts[] = 'style="'.implode(';',$thumbnail_atts_style).'"';
        if($echo) {
            printf('%s', $args['before']);
        ?>
            <div <?php echo implode(' ', $thumbnail_atts);?>>
                <a href="<?php the_permalink($id);?>"><?php solatec_image_by_size([
                    'id'         => get_post_thumbnail_id($id),
                    'size'       => $thumbnail_size, 
                    'class'      => $args['img_class'], 
                    'show_image' => $show_image]);
                ?></a>
            </div>
            <?php do_action('solatec_post_thumbnail_content');
            printf('%s', $args['after']);
        } else {
            return $args['before'].'<div '.implode(' ', $thumbnail_atts).'><a href="'.get_the_permalink($id).'"><img width="100" height="100" data-src="'.solatec_get_image_url_by_size(['id'=>$id,'size'=> 'full', 'default_thumb' => $default_thumb]).'" alt="'.get_the_title().'" class="cms-lazy lazy-loading '.$args['img_class'].'" /></a></div>'.do_action('solatec_post_thumbnail_content').$args['after'];
        }
    }
}

/**
 * Post Gallery 
*/
if(!function_exists('solatec_post_gallery')){
    function solatec_post_gallery($args=[]){
        $args = wp_parse_args($args, array(
            'id'             => null,
            'show_media'     => '1',
            'thumbnail_size' => 'large',
            'show_author'    => is_singular() ? solatec_get_opts('archive_author_on','1') : solatec_get_opts('post_author_on','1'),
            'echo'           => true,
            'default_thumb'  => solatec_configs('default_post_thumbnail'),
            'light_box'      => solatec_get_post_format_value('post-gallery-lightbox', '0'),
            'source'         => 'post-gallery-images',
        ));
        if('0' === $args['show_media']) return;
        // Get gallery from option
        $gallery_list = explode(',', solatec_get_post_format_value($args['id'], $args['source'], ''));
        // Get first gallery in content 
        $gallery_in_content = get_post_gallery( get_the_ID(), false );
        if($gallery_in_content && empty($gallery_list[0]) && !is_singular()){
            $gallery_list = isset($gallery_in_content['ids']) ? explode(',', $gallery_in_content['ids']) : [];
        }
        $light_box = $args['light_box'];
        global $post;
        wp_enqueue_script('jquery-slick');
        if('1' === $light_box ) {
            $gallery_classes = ['cms-gallery cms-gallery-lightbox'];
            wp_enqueue_script( 'magnific-popup' );
            wp_enqueue_style( 'magnific-popup' );
        }
        else {
            $gallery_classes = ['cms-gallery-carousel'];
        }
        
       
        if( !empty($gallery_list[0]) || has_post_thumbnail() ){
            if(!empty($gallery_list[0])){
            ?>
                <div class="cms-post-gallery-slide cms-slick-slide <?php if($light_box) {echo 'images-light-box';} ?>" >
                    <?php
                    foreach ($gallery_list as $img_id):
                        ?>
                        <div class="carousel-item slick-slide-item">
                            <a class="light-box" href="<?php echo esc_url(wp_get_attachment_image_url($img_id, 'full'));?>"><img class="lazy lazy-loading" data-src="<?php echo solatec_get_image_url_by_size(['id' => $img_id, 'size' => $args['thumbnail_size']]);?>" alt="<?php echo esc_attr(get_post_meta( $img_id, '_wp_attachment_image_alt', true )) ?>"></a>
                        </div>
                        <?php
                    endforeach;
                    ?>
                </div>
            <?php 
            } elseif(has_post_thumbnail()) {
                solatec_post_thumbnail($args);
            }
        }
    }
}
/**
 * Post Video
*/
if(!function_exists('solatec_post_video')){
    function solatec_post_video($args=[]){
        global $wp_embed;
        $args = wp_parse_args($args, [
            'video_url'      => 'post-video-url',
            'video_file'     => 'post-video-file',
            'video_html'     => 'post-video-html',
            'id'             => null,
            'thumbnail_size' => is_single() ? 'large' : 'medium',
            'echo'           => true,
            'default_thumb'  => solatec_configs('default_post_thumbnail')
        ]);
        $video_url = solatec_get_post_format_value($args['id'], $args['video_url'], '');
        $video_file = solatec_get_post_format_value($args['id'], $args['video_file'], []);
            $video_file_id  = isset($video_file['id']) ? $video_file['id'] : '';
        $video_html = solatec_get_post_format_value($args['id'], $args['video_html'], '');

        // Only get video from the content if a playlist isn't present.
        $_video_in_content = apply_filters( 'the_content', get_the_content('','',$args['id']) );
        if ( false === strpos( $_video_in_content, 'wp-playlist-script' ) ) {
            $video_in_content = get_media_embedded_in_content( $_video_in_content, array( 'video', 'object', 'embed', 'iframe' ) );
        }
        $video = '';
        ob_start();
        if (!empty($video_url)) {
            $video = do_shortcode($wp_embed->autoembed($video_url));
        } elseif (!empty($video_file_id)) {
            /* Get default video poster */
            $poster = !empty(get_the_post_thumbnail_url($video_file_id)) ? get_the_post_thumbnail_url($video_file_id,'full') : get_the_post_thumbnail_url(get_the_ID(),'full');
            //attachment meta data 
            $att_data = wp_get_attachment_metadata($video_file_id);
            $mime_type = explode('/', $att_data['mime_type']);
            /* Build video */            
            $video_atts = array(
                'src'    => esc_url($video_file['url']),
                'poster' => esc_url($poster),
                'width'  => esc_attr($video_file['width']),
                'height' => esc_attr($video_file['height'])
            );
            switch ($mime_type[0]) {
                case 'audio':
                    $video = do_shortcode($wp_embed->autoembed($video_file['url']));
                    break;
                
                default:
                    if(!empty($poster))
                        $video = wp_video_shortcode($video_atts);
                    else 
                        $video = do_shortcode($wp_embed->autoembed($video_file['url']));
                    break;
            }            
        } elseif ('' != $video_html) {
            $_video_html = explode(',', $video_html);
            foreach ($_video_html as $value) {
                $video .= '<div class="video-item">'.do_shortcode($wp_embed->autoembed($value)).'</div>';
            }
        } elseif(! empty( $video_in_content ) && !is_singular()){
            // If not a single post, highlight the video file.
            foreach ( $video_in_content as $video_in_content_html ) {
                $video .= $video_in_content_html;
            }
        } else {
            $video = solatec_post_thumbnail($args);
        }
        $video .= ob_get_clean();
        // Show video 
        if($args['echo'])
            echo '<div class="entry-video">'.apply_filters('solatec_post_video', $video).'</div>';
        else 
            return '<div class="entry-video">'.$video.'</div>';
    }
}

/**
 * Post Audio
*/
if(!function_exists('solatec_post_audio')){
    function solatec_post_audio($args = []){
        $args = wp_parse_args($args, [
            'audio_url'      => 'post-audio-url',
            'audio_file'     => 'post-audio-file',
            'id'             => null,
            'thumbnail_size' => is_single() ? 'large' : 'medium',
            'echo'           => true,
            'default_thumb'  => solatec_configs('default_post_thumbnail')
        ]);
        global $wp_embed;
        $audio_url = solatec_get_post_format_value($args['id'], $args['audio_url'], '');
        $audio_file = solatec_get_post_format_value($args['id'], $args['audio_file'], ['id'=>'']);
        if(!empty($audio_file['id'])){
            /* Get default video poster */
            $poster = (is_array($audio_file) && !empty(get_the_post_thumbnail_url($audio_file['id']))) ? get_the_post_thumbnail_url($audio_file['id'],'full') : get_the_post_thumbnail_url(get_the_ID(),'full');
            //attachment meta data 
            $att_data = wp_get_attachment_metadata($audio_file['id']);
            $mime_type = explode('/', $att_data['mime_type']);
            /* Build audio */            
            $audio_atts = array(
                'src'    => esc_url($audio_file['url']),
                'poster' => esc_url($poster),
                'width'  => esc_attr($audio_file['width']),
                'height' => esc_attr($audio_file['height'])
            );
        }
        // get audion in content 
        $_audio_in_content = apply_filters( 'the_content', get_the_content() );
        // Only get audio from the content if a playlist isn't present.
        if ( false === strpos( $_audio_in_content, 'wp-playlist-script' ) ) {
            $audio_in_content = get_media_embedded_in_content( $_audio_in_content, array( 'audio' ) );
        }        
        $audio = '';
        ob_start();
        if(!empty($audio_url)){
            $audio =  do_shortcode($wp_embed->autoembed($audio_url));
        } elseif (!empty($audio_file['id'])) {
            switch ($mime_type[0]) {
                case 'audio':
                    $audio = do_shortcode($wp_embed->autoembed($audio_file['url']));
                    break;
                case 'application':
                    $audio = do_shortcode($wp_embed->autoembed($audio_file['url']));
                    break;
                
                default:
                    if(!empty($poster)){
                        $audio = wp_video_shortcode($audio_atts);
                    } else {
                        $audio = do_shortcode($wp_embed->autoembed($audio_file['url']));
                    }
                    break;
            }            
        } elseif(! empty( $audio_in_content ) && !is_singular()){
            // If not a single post, highlight the audio file.
            foreach ( $audio_in_content as $audio_in_content_html ) {
                $audio .= $audio_in_content_html;
            }
        } elseif ( has_post_thumbnail() ){
            $audio = solatec_post_thumbnail($args);
        }
        $audio .= ob_get_clean();
        // Show video 
        if($args['echo'])
            echo apply_filters('solatec_post_audio', $audio);
        else 
            return $audio;
    }
}
/**
 * Post Quote
*/
if(!function_exists('solatec_post_quote')){
    function solatec_post_quote($args = []){
        $args = wp_parse_args($args, [
            'id'             => null,
            'thumbnail_size' => is_single() ? 'large' : 'medium',
            'echo'           => true,
            'default_thumb'  => solatec_configs('default_post_thumbnail')
        ]);
        $text = solatec_get_post_format_value($args['id'], 'post-quote-text', '');
        $cite = solatec_get_post_format_value($args['id'], 'post-quote-cite', '');
        $quote = '';
        $quote_attrs = $quote_style = [];
        $quote_css_class = ['quote-wrap'];
        
        // Inline Style
        $bg_img = solatec_get_image_url_by_size([
            'id'   => $args['id'],
            'size' => 'post-thumbnail'
        ]);
        if(!empty($bg_img)) {
            $quote_style[] = 'background-image:url('.$bg_img.')';
            $quote_css_class[] = 'has-bg';
        }
        $quote_attrs[] = 'class="'.trim(implode(' ', $quote_css_class)).'"';
        if(!empty($quote_style)) $quote_attrs[] = 'style="'.trim(implode(';', $quote_style)).'"'; 

        if(!empty($text) || !empty($cite)){
            $quote = '<div '.trim(implode(' ', $quote_attrs)).'><blockquote><div class="quote-text">'.$text.'</div><cite>'.$cite.'</cite></blockquote></div>';
        } else {
            $quote = solatec_post_thumbnail($args);
        }

        if($args['echo'])
            echo apply_filters('solatec_post_quote', $quote);
        else 
            return $quote;
    }
}
/**
 * Post Link
*/
if(!function_exists('solatec_post_link')){
    function solatec_post_link($args = []){
        $args = wp_parse_args($args, [
            'id'             => null,
            'thumbnail_size' => is_single() ? 'large' : 'medium',
            'echo'           => true,
            'default_thumb'  => solatec_configs('default_post_thumbnail')
        ]);

        $title = solatec_get_post_format_value($args['id'], 'post-link-title', esc_html__('View Our Portfolio','solatec'));
        //https://themeforest.net/user/zookastudio/portfolio
        $link = solatec_get_post_format_value($args['id'], 'post-link-url', '');
        if(empty($link)) return;
        // Get first link in content 
        $link_in_content =  solatec_get_content_link(['echo' => false]);
        // Link attribute
        $link_attrs = $link_style = [];
        $link_css_class = ['link-wrap'];
        
        // Inline Style
        $bg_img = solatec_get_image_url_by_size([
            'id'            => $args['id'],
            'size'          => 'post-thumbnail', 
            'default_thumb' => true
        ]);
        if(!empty($bg_img)) {
            $link_style[] = 'background-image:url('.$bg_img.')';
            $link_css_class[] = 'has-bg';
        }
        $link_attrs[] = 'class="'.trim(implode(' ', $link_css_class)).'"';
        if(!empty($link_style)) $link_attrs[] = 'style="'.trim(implode(';', $link_style)).'"'; 

        if(!empty($link)) {
            // link
            $link = '<div '.trim(implode(' ', $link_attrs)).'><a href="'.esc_url($link).'" class="cms-btn cms-btn-df fill accent" target="_blank"><span>'.esc_html($title).'</span></a></div>';
        } elseif($link_in_content){
            // link 
            $link = '<div '.trim(implode(' ', $link_attrs)).'>' . solatec_get_content_link(['echo' => false]) . '</div>';
        } else {
            $link = solatec_post_thumbnail($args);
        }

        if($args['echo'])
            echo apply_filters('solatec_post_link', $link);
        else 
            return $link;
    }
}

/**
 * Post Image
 * @since 1.0.1
*/
if(!function_exists('solatec_post_image')){
    function solatec_post_image($args = []){
        $args = wp_parse_args($args, [
            'id'             => null,
            'thumbnail_size' => is_single() ? 'large' : 'medium',
            'echo'           => true,
            'default_thumb'  => solatec_configs('default_post_thumbnail')
        ]);
        $image = $image_in_content = '';
        // Get first link in content 
        $image_in_content =  solatec_get_content_image(['echo' => false]);
        
        if(has_post_thumbnail($args['id'])){
           $image =  solatec_post_thumbnail($args);
        } elseif(!empty($image_in_content) && !is_single()){
            // images
            $image =  solatec_get_content_image(['echo' => false]);
        }
        if($args['echo'])
            echo apply_filters('solatec_post_image', $image);
        else 
            return $image;
    }
}
/**
 * Post Media
 * @since 1.0.1
*/
if(!function_exists('solatec_post_media')){
    function solatec_post_media($args = []){
        $args = wp_parse_args($args, [
            'id'             => null,
            'thumbnail_size' => is_single() ? 'large' : 'medium',
            'echo'           => true,
            'default_thumb'  => solatec_configs('default_post_thumbnail'),
            'wrap_class'     => '',
            'before'         => '',
            'after'          => '',
            'class'          => '',
            'img_class'      => '',
            'media_content'  => true,
            'media_before'   => '',
            'media_after'    => '',
        ]);
        do_action('solatec_before_post_media');
        $post_format = !empty(get_post_format($args['id'])) ? get_post_format($args['id']) : 'standard';

        $classes = [
            'cms-featured',
            'cms-post-'.$post_format,
        ];
        $classes[] = solatec_is_loop() ? 'loop' : '';
        if(!empty($args['wrap_class'])) $classes[] = $args['wrap_class'];
        if($args['default_thumb'] !== '1' && !has_post_thumbnail($args['id'])) return;
    ?>
    <div class="<?php echo trim(implode(' ', $classes));?>"><div class="cms-featured-inner relative"><?php
        printf('%s', $args['media_before']);
            switch (get_post_format($args['id'])) {
                case 'gallery':
                    solatec_post_gallery($args);
                    break;
                case 'video':
                    solatec_post_video($args);
                    break;
                case 'audio':
                    solatec_post_audio($args);
                    break;
                case 'quote':
                    solatec_post_quote($args);
                    break;
                case 'link':
                    solatec_post_link($args);
                    break;
                 case 'image':
                    solatec_post_image($args);
                    break;
                default:
                    solatec_post_thumbnail($args);
                    break;
            }
        printf('%s', $args['media_after']);
        if($args['media_content']) do_action('solatec_post_media_content', $args);
    ?></div></div>
    <?php
        do_action('solatec_after_post_media');
    }
}

/**
 * Post Date on Media
 * action hook: solatec_post_media_content
 * @since 1.0.0
 * add_action('solatec_post_media_content', 'solatec_post_date_on_media', 10);
*/
if(!function_exists('solatec_post_date_on_media')){
    add_action('solatec_post_media_content', 'solatec_post_date_on_media', 10);
    function solatec_post_date_on_media($args =[]){
        $args = wp_parse_args($args, [
            'show_date' => is_singular() ? solatec_get_opts('post_date_on', '1' ) : solatec_get_opts('archive_date_on', '1' ),
        ]);
        extract($args);
        ob_start();
            echo '<div class="cms-post-date-on-media bg-white cms-radius-tl-br-8 text-616161 text-center text-small">'
            //.'<div class="date text-26 lh-26 font-700">'.get_the_date( 'd', $args['id']).'</div>'
            //.'<div class="month text-13 lh-13">'.get_the_date( 'M', $args['id']).'</div>'
            //.'<div class="year text-13 lh-13">'.get_the_date( 'Y', $args['id']).'</div>'
            .get_the_date( 'M d, Y', $args['id'])
            .'</div>';
        if($args['echo'])
            echo ob_get_clean();
        else 
            return ob_get_clean();
    }
}
/**
 * Post Author's on Media 
 * action hook : solatec_post_thumbnail_content
 * @since 1.0.0
*/
if(!function_exists('solatec_post_author_on_media')){
    function solatec_post_author_on_media($args = []){
        $args = wp_parse_args($args, [
            'echo'        => true,
            'show_author' => is_singular() ? solatec_get_opts('post_author_on','1') : solatec_get_opts('archive_author_on','1')
        ]);
        extract($args);

        if('1' !== $show_author) return;

        ob_start();
            echo '<div class="post-author">'
            .get_avatar(get_the_author_meta('ID'), 30,  '' , get_the_author(), array('class' => 'circle')).'&nbsp;&nbsp;'
            .esc_html__('By','solatec').':&nbsp;'
            .get_the_author_posts_link()
            .'</div>';
        if($args['echo'])
            echo ob_get_clean();
        else 
            return ob_get_clean();
    }
}

/**
 * Post Category on Media
 * action hook: solatec_post_thumbnail_content
 * @since 1.0.0
 * add_action('solatec_post_thumbnail_content', 'solatec_post_category_on_media', 10);
*/
if(!function_exists('solatec_post_category_on_media')){
    function solatec_post_category_on_media($args =[]){
        $args = wp_parse_args($args, [
            'echo'     => true,
            'show_cat' => is_singular() ? solatec_get_opts('post_categories_on','1') : solatec_get_opts('archive_categories_on','1'),
            'taxonomy' => 'category',
            'before'   => '<span class="icon-pencil icon"></span>',
            'sep'      => ' / ',
            'after'    => ''
        ]);
        extract($args);
        if('1' !== $show_cat) return;

        ob_start();
            echo '<div class="post-category badge-info">'
            .get_the_term_list( get_the_ID(), $taxonomy, $before, $sep, $after )
            .'</div>';
        if($args['echo'])
            echo ob_get_clean();
        else 
            return ob_get_clean();
    }
}

/**
 * Read more on media 
 *
*/
if(!function_exists('solatec_post_readmore_on_media')){
    function solatec_post_readmore_on_media($args=[]){
        $args = wp_parse_args($args, [
            'icon' => 'fa fa-plus',

        ]);
        ob_start();
    ?>
        <a class="overlay gradient-btt" href="<?php the_permalink();?>">
            <span class="icon-readmore <?php echo esc_attr($args['icon']);?>"></span>
        </a>
    <?php
        echo ob_get_clean();
    }
}
/* Meta Post Author */
if(!function_exists('solatec_post_author')){
    function solatec_post_author($args = []){
        $args = wp_parse_args($args,[
            'post_id'     => get_the_ID(),
            'show_author' => true,
            'class'       => '',
            'text'        => '',
            'show_icon'   => true,
            'icon'        => 'fa fa-user',
            'icon_class'  => 'text-accent'
        ]);

        if(!$args['show_author']) return;
    ?>
        <span class="<?php echo trim(implode(' ', ['cms-post-author', $args['class']]));?>">
            <?php 
                if($args['show_icon']){
                    // author icon
                    $icon_class = implode(' ', ['meta-icon', $args['icon'], $args['icon_class']]);
                    if(!empty($args['icon'])) echo '<span class="'.esc_attr($icon_class).'">&nbsp;</span>';
                }
                // Author text
                if(!empty($args['text'])):  echo '<span>'.esc_html($args['text']).'&nbsp;</span>'; endif; 
                // Author name
                $my_post = get_post( $args['post_id'] );
                $user_id = $my_post->post_author;
            ?>
            <a href="<?php echo get_author_posts_url($user_id); ?>" title="<?php the_author_meta('display_name', $user_id); ?>"><?php the_author_meta('display_name', $user_id); ?></a>
        </span>
    <?php
    }
}
/* Meta Post Category */
if(!function_exists('solatec_post_category')){
    function solatec_post_category($args = []){
        $args = wp_parse_args($args,[
            'show_cat'   => true,
            'class'      => '',
            'text'       => '',
            'show_icon'  => true,
            'icon'       => 'fa fa-folder-open',
            'icon_class' => 'text-accent',
            'taxo'       => 'category',
            'separator'  => ', ',
            'post_id'    => get_the_ID()
        ]);

        if(!$args['show_cat']) return;
    ?>
        <span class="<?php echo trim(implode(' ', ['cms-post-cat', $args['class']]));?>">
            <?php 
                if($args['show_icon']){
                    // cat icon
                    $icon_class = implode(' ', ['meta-icon',$args['icon'], $args['icon_class']]);
                    if(!empty($args['icon'])) echo '<span class="'.esc_attr($icon_class).'">&nbsp;</span>';
                }
                // cat text
                if(!empty($args['text'])):  echo '<span>'.esc_html($args['text']).'&nbsp;</span>'; endif; 
                // cat list
                the_terms( $args['post_id'], $args['taxo'], '<span class="text-accent">', $args['separator'], '</span>' );
            ?>
        </span>
    <?php
    }
}
/* Meta Post Comment */
if(!function_exists('solatec_post_comment')){
    function solatec_post_comment($args = []){
        $args = wp_parse_args($args,[
            'post_id'       => get_the_ID(),
            'show_cmt'      => true,
            'text'          => esc_html__('Comments','solatec'),
            'class'         => '',
            'show_icon'     => true,
            'icon'          => 'cmsi-comments',
            'icon_class'    => 'text-accent',
            'cmt_with_text' => true
        ]);

        if(!$args['show_cmt']) return;
    ?>
        <span class="<?php echo trim(implode(' ', ['cms-post-cmt', $args['class']]));?>">
            <?php 
                if($args['show_icon']){
                    // cat icon
                    $icon_class = implode(' ', ['meta-icon', $args['icon'], $args['icon_class']]);
                    if(!empty($args['icon'])) echo '<span class="'.esc_attr($icon_class).'"></span>';
                }
                // cat text
                if(!empty($args['text'])):  echo '<span>'.esc_html($args['text']).'&nbsp;</span>'; endif; 
                // cat list
            ?>
            <a class="cms-scroll" href="<?php the_permalink();?>#comments"><?php
                if($args['cmt_with_text']) 
                    echo comments_number(
                        esc_html__('Comments: ', 'solatec').'<span class="text-accent">0</span>',
                        esc_html__('Comment: ', 'solatec').'<span class="text-accent">1</span>',
                        esc_html__('Comments: ', 'solatec').'<span class="text-accent">%</span>',
                        $args['post_id']
                    ); 
                else 
                    echo comments_number(
                        '0',
                        '1',
                        '%',
                        $args['post_id']
                    );
            ?></a>
        </span>
    <?php
    }
}
/* Meta post author */
if(!function_exists('solatec_post_date')){
    function solatec_post_date($args = []){
        $args = wp_parse_args($args, [
            'post_id'     => get_the_ID(),
            'show_date'   => true,
            'date_format' => get_option('date_format'),
            'class'       => '',
            'show_icon'   => true,
            'icon'        => 'fa fa-clock',
            'icon_class'  => 'text-accent',
        ]);
        if(!$args['show_date']) return;
        ?>
        <span class="<?php echo trim(implode(' ', ['cms-post-date', $args['class']]));?>">
            <?php 
                if($args['show_icon']){
                    // date icon
                    $icon_class = implode(' ', ['meta-icon', $args['icon'], $args['icon_class']]);
                    if(!empty($args['icon'])) echo '<span class="'.esc_attr($icon_class).'"></span>';
                }
            ?>
            <span><?php echo get_the_date($args['date_format'], $args['post_id'] ); ?></span>
        </span>
        <?php
    }
}

/**
 * Prints post meta
 */
if ( ! function_exists( 'solatec_post_meta' ) ) :
    function solatec_post_meta($args=[]) {
        $args = wp_parse_args($args,[
            'show_author' => solatec_get_opt( 'archive_author_on', true ),
            'show_cat'    => solatec_get_opt( 'archive_categories_on', true ),
            'show_cmt'    => solatec_get_opt( 'archive_comments_on', true ),
            'show_date'   => solatec_get_opt( 'archive_date_on', true ),
            'show_icon'   => true, 
            'class'       => '',
            'inner_class' => '',
            'item_class'  => '',
            'post_id'     => get_the_ID(),
            'date_format' => get_option('date_format'),
            'gutters'     => '25',
            'taxo'        => solatec_get_custom_post_taxonomies(get_post_type(), 'cat'), 
        ]);
        $inner_class = ['cms-post-meta-inner', 'row', 'gutters-'.$args['gutters'], $args['inner_class']];
        if($args['show_author'] || $args['show_cat'] || $args['show_cmt'] || $args['show_date']) : ?>
            <div class="<?php echo implode(' ', ['cms-post-meta', $args['class']]); ?>">
                <div class="<?php echo trim(implode(' ', $inner_class));?>">
                    <?php 
                        solatec_post_category([
                            'show_icon' => $args['show_icon'],
                            'show_cat'  => $args['show_cat'],
                            'class'     => 'col-auto empty-none '.$args['item_class'],
                            'post_id'   => $args['post_id'],
                            'text'      =>  '',
                            'taxo'      => $args['taxo']
                        ]);
                        solatec_post_date([
                            'post_id'     => $args['post_id'],
                            'show_date'   => $args['show_date'],
                            'show_icon'   => $args['show_icon'],
                            'date_format' => $args['date_format'],
                            'class'       => 'col-auto '.$args['item_class']
                        ]);
                        solatec_post_author([
                            'post_id'     => $args['post_id'],
                            'show_author' => $args['show_author'], 
                            'show_icon'   => $args['show_icon'],
                            'show_author' => $args['show_author'],
                            'class'       => 'col-auto '.$args['item_class']
                        ]);
                        solatec_post_comment([
                            'post_id'   => $args['post_id'],
                            'show_icon' => $args['show_icon'],
                            'show_cmt'  => $args['show_cmt'],
                            'class'     => 'col-auto '.$args['item_class'],  
                            'text'      => ''
                        ]);
                    ?>
                </div>
            </div>
        <?php endif; }
endif;

/**
 * Prints tag list
 */
if ( ! function_exists( 'solatec_post_tagged_in' ) ) :
    /**
     * Prints HTML with meta information for the current post-date/time.
     */
    function solatec_post_tagged_in($args = [])
    {
        $args = wp_parse_args($args, [
            'title'    => '',
            'class'    => '',
            'style'    => 'tagcloud',     
            'show_tag' => '1',
            'post_id'  => get_the_ID(),
            'separator' => '',
        ]);
        if($args['show_tag'] !== '1') return;
        $tags_list = get_the_tag_list( '<div class="'.$args['style'].'">', $args['separator'], '</div>', $args['post_id']);
        if ( $tags_list )
        {
            echo '<div class="'.trim(implode(' ', ['cms-post-tags', $args['class']])).'"><div class="row gutters-10 gutters-grid align-items-center">';
                if($args['title'] != '') printf('<div class="col-auto cms-post-tags-title">%s</div>', $args['title']);
                printf('<div class="col">%2$s</div>', '', $tags_list);
            echo '</div></div>';
        }
    }
endif;

// Post Icon
if(!function_exists('solatec_post_icon')){
    function solatec_post_icon($args = []){
        $args = wp_parse_args($args, [
            'id'          => get_the_ID(),
            'class'       => '',     
            'before'      => '',
            'after'       => '',
            'wrap_before' => '',
            'wrap_after'  => '',
            'icon_class'  => '',
            'icon_color'  => 'primary',
            'size'        => '64',
            'echo'        => true    
        ]);
        $icon = solatec_get_post_format_value($args['id'], 'icon', '');
        
        if(empty($icon)) return;
        
        $_icon = '<i class="'.implode(' ',array_filter([$icon,'cms-post--icon','cms-transition','d-block', $args['icon_class'], 'text-'.$args['icon_color'],'text-'.$args['size']])).'"></i>';

        ob_start();
        printf('%s', $args['wrap_before']);
        ?>
            <div class="<?php echo implode(' ',array_filter(['cms-post-icon', $args['class']]));?>"><?php 
                printf('%1$s %2$s %3$s', $args['before'], $_icon, $args['after'] ); 
            ?></div>
        <?php
        printf('%s', $args['wrap_after']);
        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}