<?php 
/**
 * Get Page List 
 * @return array
*/
if(!function_exists('solatec_list_page')){
    function solatec_list_page($default = []){
        $page_list = array();
        if(!empty($default))
            $page_list[$default['value']] = $default['label'];
        $pages = get_pages(array('hierarchical' => 0, 'posts_per_page' => '-1'));
        foreach($pages as $page){
            $page_list[$page->ID] = $page->post_title;
        }
        return $page_list;
    }
}

/**
 * Get Post List
 * @return array
*/
if(!function_exists('solatec_list_post')){
    function solatec_list_post($post_type = 'post', $default = false){
        $post_list = array();
        if($default){
            $post_list['none'] = esc_html__('None','solatec');
            $post_list['-1']   = esc_html__('Default','solatec');
        }
        $posts = get_posts(array('post_type' => $post_type,'posts_per_page' => '-1'));
        foreach($posts as $post){
            $post_list[$post->ID] = $post->post_title;
        }
        return $post_list;
    }
}

/**
 * Get custom post type slug
*/
if(!function_exists('solatect_custom_post_type_slug')){
    function solatect_custom_post_type_slug(){
        $post_types = get_post_types([
            'public'   => true,
            '_builtin' => false
        ], 'objects');
        $DefaultExcludedPostTypes = [
            'page',
            'attachment',
            'revision',
            'nav_menu_item',
            'vc_grid_item',
            'custom_css',
            'customize_changeset',
            'oembed_cache',
            'cms-mega-menu',
            'elementor_library',
        ];
        $ExtraExcludedPostTypes = apply_filters('etc_get_post_types', []);
        $excludedPostTypes      = array_merge($DefaultExcludedPostTypes, $ExtraExcludedPostTypes );
        var_dump($post_types); die();
        $result = [];
        if (!is_array($post_types))
            return $result;
        foreach ($post_types as $post_type) {
            if (!$post_type instanceof WP_Post_Type)
                continue;
            if (in_array($post_type->name, $excludedPostTypes))
                continue;
            $result[] = array(
                'id'       => $post_type->name.'-slug',
                'title'    => sprintf(esc_html__( 'Slug %s', 'solatec' ), $post_type->labels->singular_name),
                'subtitle' => esc_html__('Enter slug for custom post type archive','solatec'),
                'type'     => 'text'
            );
        }
  
        return $result;
    }
}

/**
 * Get post thumbnail as image options
 * @return array
 *
*/
function solatec_list_post_thumbnail($post_type = 'post', $default = false, $args = []){
    $layouts = [
        'none' => get_template_directory_uri() . '/assets/images/default-opt/none.jpg'
    ];
    if($default){
        $layouts['-1'] = get_template_directory_uri() . '/assets/images/default-opt/default.jpg';
        //$layouts['none'] = get_template_directory_uri() . '/assets/images/default-opt/none.jpg';
    }
    $layouts = $layouts + $args;
    $posts = get_posts(array('post_type' => $post_type,'posts_per_page' => '-1'));
    
    foreach($posts as $post){
        $layouts[$post->ID] = [
            'alt' => get_the_title($post->ID),
            'img' => solatec_get_image_url_by_size([
                'id'            => get_post_thumbnail_id($post->ID),
                'size'          => 'full',
                'default_thumb' => true
            ])
        ];
    }
    return $layouts;
}

/**
 * get list menu.
 * @return array
 */
if(!function_exists('solatec_get_nav_menu')){
    function solatec_get_nav_menu($args = []){
        $args = wp_parse_args($args, [
            'default' => false, 
            'none'    => false
        ]);
        $menus = array(
            '0' => esc_html__('Primary Menu','solatec')
        );
        $obj_menus = wp_get_nav_menus();
        if($args['default']) $menus['-1'] = esc_html__('Default','solatec');
        if($args['none']) $menus['none'] = esc_html__('None','solatec');

        foreach ($obj_menus as $obj_menu){
            $menus[$obj_menu->slug] = $obj_menu->name;
        }
        return $menus;
    }
}
/**
 * Get list of user by user role for post options
 * 
 * @param $user_role
*/
function solatec_list_user_by_role_for_opts($args = []){
    $args = wp_parse_args($args, [
        'role'    => 'subcrible',
        'orderby' => 'user_nicename',
        'order'   => 'ASC'
    ]);
    $users = get_users( $args );
    $options = [];
    foreach ( $users as $user ) {
        $options[$user->user_email] = $user->display_name;
    }
    return $options;
}
/**
 * Get RevSlider List 
 * @return array
*/
if(!function_exists('solatec_get_list_rev_slider')){
    function solatec_get_list_rev_slider() {
        if (class_exists('RevSlider')) {
            $slider = new RevSlider();
            $arrSliders = $slider->getArrSliders();
            $revsliders = array();
            if ($arrSliders) {
                foreach ($arrSliders as $slider) {
                    /* @var $slider RevSlider */
                    $revsliders[$slider->getAlias()] = $slider->getTitle();
                }
            }
            return $revsliders;
        }
    }
}

/**
 * Get Contact Form 7 List
 * @return array
*/
if(!function_exists('solatec_get_list_cf7')){
    function solatec_get_list_cf7($defaule = false) {
        if(!class_exists('WPCF7')) return;
        $cf7 = get_posts( 'post_type="wpcf7_contact_form"&numberposts=-1' );
        $contact_forms = array();
        if($defaule){
            $contact_forms['-1'] = esc_html__('Default From Theme Option','solatec');
        }

        foreach ( $cf7 as $cform ) {
            $contact_forms[ $cform->post_title ] = $cform->post_title;
        }
        
        return $contact_forms;
    }
}