<?php
/**
 * Header Top
*/
if(!function_exists('solatec_header_top_opts')){
	function solatec_header_top_opts($args=[]){
		$args = wp_parse_args($args, [
			'default'       => false,
			'default_value' => '0',
			'subsection'    => false
		]);
		if($args['default']){
			$options = [
				'-1' => esc_html__('Default','solatec'),
                '1'  => esc_html__('Yes','solatec'),
                '0'  => esc_html__('No','solatec'),
			];
			$header_top_layout_default = '-1';
		} else {
			$options = [
				'1'  => esc_html__('Yes','solatec'),
                '0'  => esc_html__('No','solatec'),
			];
			$header_top_layout_default = '';
		}
		$opts = [
			'title'      => esc_html__('Header Top', 'solatec'),
		    'icon'       => 'el el-website',
		    'subsection' => $args['subsection'],
		    'fields'     => array(
		        array(
                    'id'          => 'header_top_layout',
                    'type'        => 'image_select',
                    'title'       => esc_html__('Layout', 'solatec'),
                    'subtitle'    => esc_html__('Select a layout for upper header top area.', 'solatec'),
                    'desc'        => sprintf(esc_html__('%sClick Here%s to add your custom Header Top layout first.','solatec'),'<a href="' . esc_url( admin_url( 'edit.php?post_type=cms-header-top' ) ) . '" target="_blank">','</a>'),
                    'placeholder' => esc_html__('Default','solatec'),
                    'options'     => solatec_list_post_thumbnail('cms-header-top', $args['default']),
                    'default'     => $header_top_layout_default,
                )
		    )
		];
		return $opts;
	}
}

/**
 * Header 
**/
if(!function_exists('solatec_header_opts')){
	function solatec_header_opts($args=[]){
		$args = wp_parse_args($args,[
			'default'         => false,
			'default_value'   => '1',
			'container_width' => 'container'
		]);
		$opt_default = [
			'-1' => get_template_directory_uri() . '/assets/images/default-opt/default.jpg',
			'0'    => get_template_directory_uri() . '/assets/images/default-opt/none.jpg',
		];
		$opt_list = [
			'3' => get_template_directory_uri() . '/assets/images/header-layout/h3.jpg',
			'4' => get_template_directory_uri() . '/assets/images/header-layout/h4.jpg',
			'5' => get_template_directory_uri() . '/assets/images/header-layout/h5.png',
		];
		$header_container_width_default = [
			'-1'    => esc_html__('Theme Default', 'solatec')
		];
		$header_container_width_list = [
			'container'      => esc_html__('Default', 'solatec'),
			'container-wide' => esc_html__('Wide', 'solatec'),
			'container-full' => esc_html__('Full', 'solatec'),
		];
		if($args['default']){
			$opt_lists = $opt_default +  $opt_list;
			$header_container_width_opts = $header_container_width_default + $header_container_width_list;
		} else {
			$opt_lists = $opt_list;
			$header_container_width_opts = $header_container_width_list;
		}

		$opts = array(
		    'title'  => esc_html__('Header', 'solatec'),
		    'icon'   => 'el-icon-website',
		    'fields' => array(
		        array(
		            'id'       => 'header_layout',
		            'type'     => 'image_select',
		            'title'    => esc_html__('Layout', 'solatec'),
		            'subtitle' => esc_html__('Select a layout for header.', 'solatec'),
		            'options'  => $opt_lists,
		            'default'  => $args['default_value']
		        ),
		        array(
		            'id'       => 'header_layout_width',
		            'type'     => 'button_set',
		            'title'    => esc_html__('Header Container Width', 'solatec'),
		            'subtitle' => esc_html__('Choose your header container width', 'solatec'),
		            'options'  => $header_container_width_opts,
		            'default'  => $args['container_width']
		        ),
		        array(
		            'id'       => 'header_height',
		            'type'     => 'dimensions',
		            'title'    => esc_html__('Header Height', 'solatec'),
		            'subtitle' => esc_html__('Enter Height for header. Leave blank to use default', 'solatec'),
		            'width'    => false,
		            'unit'     => 'px'
		        ),
		    )
		);
		return $opts;
	}
}
if(!function_exists('solatec_header_logo_opts')){
	function solatec_header_logo_opts($args = []){
		$args = wp_parse_args($args, [
			'subsection'    => true
		]);
		return array(
		    'title'      => esc_html__('Logo', 'solatec'),
		    'icon'       => 'el el-picture',
		    'subsection' => $args['subsection'],
		    'fields'     => array(
		        array(
		            'id'       => 'logo',
		            'type'     => 'media',
		            'title'    => esc_html__('Main Logo', 'solatec'),
		            'default' => array()
		        ),
		        array(
		            'id'       => 'logo_ontop',
		            'type'     => 'media',
		            'title'    => esc_html__('Ontop Logo', 'solatec'),
		             'default' => array()
		        ),
		        array(
		            'id'       => 'logo_sticky',
		            'type'     => 'media',
		            'title'    => esc_html__('Stick Logo', 'solatec'),
		             'default' => array()
		        ),
		        array(
		            'id'       => 'logo_mobile',
		            'type'     => 'media',
		            'title'    => esc_html__('Tablet & Mobile Logo', 'solatec'),
		             'default' => array()
		        ),
		        array(
		            'id'       => 'logo_size',
		            'type'     => 'dimensions',
		            'title'    => esc_html__('Logo Size', 'solatec'),
		            'subtitle' => esc_html__('Enter demensions for your logo, just in case the logo is too large. Leave blank to use default size from theme', 'solatec'),
		            'unit'     => 'px'
		        ),
		        array(
		            'id'       => 'logo_size_sm',
		            'type'     => 'dimensions',
		            'title'    => esc_html__('Enter demensions for your logo on Tablet & Mobile', 'solatec'),
		            'unit'     => 'px'
		        ),
		    )
		);
	}
}
/**
 * Header OnTop (Transparent)
**/
if(!function_exists('solatec_header_ontop_opts')){
	function solatec_header_ontop_opts($args = []){
		$args = wp_parse_args($args, [
			'default'       => false,
			'default_value' => '1',
			'subsection'    => true
		]);
		if($args['default']){
			$options = [
				'-1' => esc_html__('Default','solatec'),
                '1'  => esc_html__('Yes','solatec'),
                '0'  => esc_html__('No','solatec'),
			];
			$default_value = '-1';
		} else {
			$options = [
				'1'  => esc_html__('Yes','solatec'),
                '0'  => esc_html__('No','solatec'),
			];
			$default_value = '0';
		}
		return array(
		    'title'      => esc_html__('Header OnTop (Transparent)', 'solatec'),
		    'icon'       => 'el-icon-website',
		    'subsection' => $args['subsection'],
		    'fields'     => array(
		        array(
		            'id'       => 'header_ontop',
		            'title'    => esc_html__('OnTop Header', 'solatec'),
		            'subtitle' => esc_html__('Header will be overlay on next content when applicable.', 'solatec'),
		            'type'     => 'button_set',
                    'options'  => $options,
                    'default'  => $default_value,
		        )
		    )
		);
	}
}
/**
 * Header Sticky
**/
if(!function_exists('solatec_header_sticky_opts')){
	function solatec_header_sticky_opts($args = []){
		$args = wp_parse_args($args, [
			'default'       => false,
			'default_value' => '1',
			'subsection'    => true
		]);
		if($args['default']){
			$options = [
				'-1' => esc_html__('Default','solatec'),
                '1'  => esc_html__('Yes','solatec'),
                '0'  => esc_html__('No','solatec'),
			];
			$default_value = '-1';
		} else {
			$options = [
				'1'  => esc_html__('Yes','solatec'),
                '0'  => esc_html__('No','solatec'),
			];
			$default_value = '0';
		}
		return array(
		    'title'      => esc_html__('Header Sticky', 'solatec'),
		    'icon'       => 'el-icon-website',
		    'subsection' => $args['subsection'],
		    'fields'     => array(
		        array(
		            'id'       => 'sticky_on',
		            'title'    => esc_html__('Sticky Header', 'solatec'),
		            'subtitle' => esc_html__('Header will be sticked when applicable.', 'solatec'),
		            'type'     => 'button_set',
                    'options'  => $options,
                    'default'  => $default_value,
		        ),
		        array(
					'id'       => 'header_sticky_bg',
					'type'     => 'background',
					'title'    => esc_html__('Background', 'solatec'),
					'output'   => array('.cms-header.header-sticky'),
					'required' => array( 0 => 'sticky_on', 1 => 'equals', 2 => '1' ),
					'force_output' => true
		        ),
		    )
		);
	}
}

/**
 * Header Navigation 
**/
if(!function_exists('solatec_navigation_opts')){
	function solatec_navigation_opts($args=[]){
		$args = wp_parse_args($args, [
			'default'       => false,
			'default_value' => '1'
		]);
		if($args['default']){
			$menus = ['-1' => esc_html__('Theme Options','solatec')] + solatec_get_nav_menu();
			$default_menu  = '-1';
		} else {
			$menus = solatec_get_nav_menu();
			$default_menu  = '0';
		}
		$opts = array(
		    'title'      => esc_html__('Navigation', 'solatec'),
		    'icon'       => 'el el-lines',
		    'subsection' => true,
		    'fields'     => array(
		    	array(
					'title'       => esc_html__('Choose Menu', 'solatec'),
					'subtitle'    => esc_html__('Choose your menu', 'solatec'),
					'placeholder' => esc_html__('Choose your menu', 'solatec'),
					'id'          => 'primary_menu',
					'type'        => 'select',
					'options'     => $menus,
					'default'     => $default_menu,
					//'required'    => array( 0 => 'show_secondary_menu', 1 => 'equals', 2 => '1' ),
                ),
		        array(
					'title'  => esc_html__('Main Menu', 'solatec'),
					'type'   => 'section',
					'id'     => 'main_menu',
					'indent' => true
		        ),
		        array(
		            'id'      => 'main_menu_color',
		            'type'    => 'link_color',
		            'title'   => esc_html__('Color', 'solatec'),
		            'default' => array(
		                'regular' => '',
		                'hover'   => '',
		                'active'   => '',
		            ),
		        ),
		        array(
					'title'  => esc_html__('Ontop Menu', 'solatec'),
					'type'   => 'section',
					'id'     => 'ontop_menu',
					'indent' => true
		        ),
		        array(
		            'id'      => 'ontop_menu_color',
		            'type'    => 'link_color',
		            'title'   => esc_html__('Color', 'solatec'),
		            'default' => array(
		                'regular' => '',
		                'hover'   => '',
		                'active'   => '',
		            ),
		        ),
		        array(
					'title'  => esc_html__('Sticky Menu', 'solatec'),
					'type'   => 'section',
					'id'     => 'sticky_menu',
					'indent' => true
		        ),
		        array(
		            'id'      => 'sticky_menu_color',
		            'type'    => 'link_color',
		            'title'   => esc_html__('Color', 'solatec'),
		            'default' => array(
		                'regular' => '',
		                'hover'   => '',
		                'active'   => '',
		            ),
		        )
		    )
		);
		return $opts;
	}
}
/**
 * Header Secondary Menu 
**/
if(!function_exists('solatec_header_secondary_menu_opts')){
	function solatec_header_secondary_menu_opts($args = []){
		$args = wp_parse_args($args, [
			'default'       => false,
			'default_value' => '1',
			'subsection'    => true
		]);
		if($args['default']){
			$options = [
				'-1' => esc_html__('Default','solatec'),
                '1'  => esc_html__('Yes','solatec'),
                '0'  => esc_html__('No','solatec'),
			];
			$default_value = '-1';
			$menus = ['-1' => esc_html__('Theme Options','solatec')] + solatec_get_nav_menu();
			$default_menu  = '-1';
		} else {
			$options = [
				'1'  => esc_html__('Yes','solatec'),
                '0'  => esc_html__('No','solatec'),
			];
			$default_value = '0';
			$menus = solatec_get_nav_menu();
			$default_menu  = '';
		}
		// Return
		return array(
		    'title'      => esc_html__('Header Secondary Menu', 'solatec'),
		    'icon'       => 'el el-lines',
		    'subsection' => $args['subsection'],
		    'fields'     => array(
		        array(
                    'title'    => esc_html__('Show Secondary Menu', 'solatec'),
                    'subtitle' => esc_html__('Show/Hide Secondary Menu', 'solatec'),
                    'id'       => 'show_secondary_menu',
                    'type'     => 'button_set',
                    'options'  => $options,
                    'default'  => $default_value,
                ),
                array(
					'title'       => esc_html__('Secondary Menu Title', 'solatec'),
					'subtitle'    => esc_html__('Enter your secondary menu title', 'solatec'),
					'placeholder' => esc_html__('Leave blank to use default', 'solatec'),
					'id'          => 'secondary_menu_title',
					'type'        => 'text',
					'default'     => '',
					'required'    => array( 0 => 'show_secondary_menu', 1 => 'equals', 2 => '1' ),
                ),
                array(
					'title'       => esc_html__('Choose Secondary Menu', 'solatec'),
					'subtitle'    => esc_html__('Choose your menu', 'solatec'),
					'placeholder' => esc_html__('Choose your menu', 'solatec'),
					'id'          => 'secondary_menu',
					'type'        => 'select',
					'options'     => $menus,
					'default'     => $default_menu,
					'required'    => array( 0 => 'show_secondary_menu', 1 => 'equals', 2 => '1' ),
                ),

		    )
		);
	}
}

/**
 * Header Attribute
*/
if(!function_exists('solatec_header_atts_opts')){
	function solatec_header_atts_opts($args = []){
		$args = wp_parse_args($args, [
			'default'       => false,
			'default_value' => '1',
			'subsection'    => true
		]);
		if($args['default']){
			$options = [
				'-1' => esc_html__('Default','solatec'),
                '1'  => esc_html__('Yes','solatec'),
                '0'  => esc_html__('No','solatec'),
			];
			$default_value = '-1';

			$h_btn_link_type = [
				'-1' => esc_html__('Default','solatec'),
                'page'  => esc_html__('Page','solatec'),
                'custom'  => esc_html__('Custom','solatec'),
			];
			$h_btn_link_type_value = '-1';

			$h_btn_target = [
				'-1' => esc_html__('Default','solatec'),
                '_self'  => esc_html__('Self', 'solatec'),
		        '_blank'  => esc_html__('Blank', 'solatec')
			];
			$h_btn_target_value = '-1';

			$language_opts = [
				'-1'    => esc_html__('Default','solatec'),
				'0'     => esc_html__('Disable','solatec'),
				'all'   => esc_html__('All Screen', 'solatec'),
				'small d-xl-none' => esc_html__('Small Screen (=< 1200)','solatec')
			];
			$default_language_value = '-1';
		} else {
			$options = [
				'1'  => esc_html__('Yes','solatec'),
                '0'  => esc_html__('No','solatec'),
			];
			$default_value = '0';

			$h_btn_link_type = [
                'page'  => esc_html__('Page', 'solatec'),
		        'custom'  => esc_html__('Custom', 'solatec')
			];
			$h_btn_link_type_value = 'page';

			$h_btn_target = [
                '_self'  => esc_html__('Self', 'solatec'),
		        '_blank'  => esc_html__('Blank', 'solatec')
			];
			$h_btn_target_value = '_self';

			$language_opts = [
				'0'     => esc_html__('Disable','solatec'),
				'all'   => esc_html__('All Screen', 'solatec'),
				'small d-xl-none' => esc_html__('Small Screen (=< 1200)','solatec')
			];
			$default_language_value = '0';
		}
		// Return
		return array(
		    'title'      => esc_html__('Header Attribute', 'solatec'),
		    'icon'       => 'el-icon-website',
		    'subsection' => $args['subsection'],
		    'fields'     => array(
		        array(
                    'title'    => esc_html__('Show Search', 'solatec'),
                    'subtitle' => esc_html__('Show/Hide search icon', 'solatec'),
                    'id'       => 'search_on',
                    'type'     => 'button_set',
                    'options'  => $options,
                    'default'  => $default_value,
                ),
                solatec_woo_header_cart_opts([
                	'options' => $options,
                	'default' => $default_value	
                ]),
                solatec_header_language_switcher_opts([
                	'options' => $language_opts,
                	'default' => $default_language_value	
                ]),
                array(
					'title'  => esc_html__('Hidden Sidebar', 'solatec'),
					'type'   => 'section',
					'id'     => 'hidden_sidebar',
					'indent' => true
		        ),
		        array(
		            'id'       => 'hidden_sidebar_on',
		            'type'     => 'button_set',
		            'title'    => esc_html__('Show/Hide Hidden Sidebar', 'solatec'),
		            'desc'	   => esc_html__('When it is YES, you need add widget to Hidden Sidebar','solatec'),	
		            'options'  => $options,
                    'default'  => $default_value,
		        ),
		        array(
					'title'  => esc_html__('Button Navigation 01', 'solatec'),
					'type'   => 'section',
					'id'     => 'button_navigation_01',
					'indent' => true,
		        ),
		        array(
		            'id'       => 'h_btn_on',
		            'type'     => 'button_set',
		            'title'    => esc_html__('Show/Hide Button', 'solatec'),
		            'options'  => $options,
                    'default'  => $default_value,
		        ),
		        array(
					'id'           => 'h_btn_text',
					'type'         => 'text',
					'title'        => esc_html__('Button Text', 'solatec'),
					'default'      => '',
					'required'     => array( 0 => 'h_btn_on', 1 => 'equals', 2 => '1' ),
		        ),
		        array(
		            'id'       => 'h_btn_link_type',
		            'type'     => 'button_set',
		            'title'    => esc_html__('Button Link Type', 'solatec'),
		            'options'  => $h_btn_link_type,
					'default'      => $h_btn_link_type_value,
					'required'     => array( 0 => 'h_btn_on', 1 => 'equals', 2 => '1' ),
		        ),
		        array(
		            'id'    => 'h_btn_link',
		            'type'  => 'select',
		            'title' => esc_html__( 'Page Link', 'solatec' ), 
		            'data'  => 'page',
		            'args'  => array(
		                'post_type'      => 'page',
		                'posts_per_page' => -1,
		                'orderby'        => 'title',
		                'order'          => 'ASC',
		            ),
		            'required' => array( 0 => 'h_btn_link_type', 1 => 'equals', 2 => 'page' ),
		        ),
		        array(
		            'id' => 'h_btn_link_custom',
		            'type' => 'text',
		            'title' => esc_html__('Custom Link', 'solatec'),
		            'default' => '',
		            'required' => array( 0 => 'h_btn_link_type', 1 => 'equals', 2 => 'custom' ),
		        ),
		        array(
		            'id'       => 'h_btn_target',
		            'type'     => 'button_set',
		            'title'    => esc_html__('Button Target', 'solatec'),
		            'options'  => $h_btn_target,
		            'default'  => $h_btn_target_value,
		            'required' => array( 0 => 'h_btn_on', 1 => 'equals', 2 => '1' ),
		        ),
		        array(
					'title'  => esc_html__('Button Navigation 02', 'solatec'),
					'type'   => 'section',
					'id'     => 'button_navigation_02',
					'indent' => true,
		        ),
		        array(
		            'id'       => 'h_btn_on2',
		            'type'     => 'button_set',
		            'title'    => esc_html__('Show/Hide Button', 'solatec'),
		            'options'  => $options,
                    'default'  => $default_value,
		        ),
		        array(
					'id'           => 'h_btn_text2',
					'type'         => 'text',
					'title'        => esc_html__('Button Text', 'solatec'),
					'default'      => '',
					'required'     => array( 0 => 'h_btn_on2', 1 => 'equals', 2 => '1' ),
		        ),
		        array(
		            'id'       => 'h_btn_link_type2',
		            'type'     => 'button_set',
		            'title'    => esc_html__('Button Link Type', 'solatec'),
		            'options'  => $h_btn_link_type,
					'default'      => $h_btn_link_type_value,
					'required'     => array( 0 => 'h_btn_on2', 1 => 'equals', 2 => '1' ),
		        ),
		        array(
		            'id'    => 'h_btn_link2',
		            'type'  => 'select',
		            'title' => esc_html__( 'Page Link', 'solatec' ), 
		            'data'  => 'page',
		            'args'  => array(
		                'post_type'      => 'page',
		                'posts_per_page' => -1,
		                'orderby'        => 'title',
		                'order'          => 'ASC',
		            ),
		            'required' => array( 0 => 'h_btn_link_type2', 1 => 'equals', 2 => 'page' ),
		        ),
		        array(
		            'id' => 'h_btn_link_custom2',
		            'type' => 'text',
		            'title' => esc_html__('Custom Link', 'solatec'),
		            'default' => '',
		            'required' => array( 0 => 'h_btn_link_type2', 1 => 'equals', 2 => 'custom' ),
		        ),
		        array(
		            'id'       => 'h_btn_target2',
		            'type'     => 'button_set',
		            'title'    => esc_html__('Button Target', 'solatec'),
		            'options'  => $h_btn_target,
		            'default'  => $h_btn_target_value,
		            'required' => array( 0 => 'h_btn_on2', 1 => 'equals', 2 => '1' ),
		        ),
		        array(
					'title'  => esc_html__('Hotline', 'solatec'),
					'type'   => 'section',
					'id'     => 'button_navigation_hotline',
					'indent' => true,
		        ),
		        array(
		            'id'       => 'h_hotline_on',
		            'type'     => 'button_set',
		            'title'    => esc_html__('Show/Hide Hotline', 'solatec'),
		            'options'  => $options,
                    'default'  => $default_value,
		        ),
		        array(
					'id'           => 'h_hotline_text',
					'type'         => 'text',
					'title'        => esc_html__('Hotline Number', 'solatec'),
					'default'      => '',
					'required'     => array( 0 => 'h_hotline_on', 1 => 'equals', 2 => '1' ),
		        )
		    )
		);
	}
}
/**
 * Social list
**/
if(!function_exists('solatec_social_list_opts')){
	function solatec_social_list_opts($args=[]){
		$args = wp_parse_args($args,[
			'param_name' => 'social_list'
		]);
		$opts = array(
            'id'      => $args['param_name'],
            'type'    => 'sorter',
            'desc'    => 'Choose which social networks are displayed and edit where they link to.',
            'options' => array(
                'enabled'  => array(),
                'disabled' => array(
                	'facebook'      => 'Facebook',
                    'twitter'       => 'Twitter',
                    'linkedin'      => 'Linkedin',
                    'instagram'     => 'Instagram',
                	'google-plus'   => 'Google',
                    'tripadvisor'   => 'Tripadvisor',
                    'youtube'       => 'Youtube',
                    'vimeo'         => 'Vimeo',
                    'tumblr'        => 'Tumblr',
                    'pinterest'     => 'Pinterest',
                    'yelp'          => 'Yelp',
                    'skype'         => 'Skype',
                )
            ),
        );
        return $opts;
	}
}
/**
 * Page Title
***/
if(!function_exists('solatec_page_title_opts')){
	function solatec_page_title_opts($args = []){
		$args = wp_parse_args($args, [
			'default'        => false,
			'default_value'  => '1',
			'default_layout' => '',
			'subsection'     => false
		]);

		if($args['default']){
			$options = [
				'-1' => esc_html__('Default','solatec'),
                '1'  => esc_html__('Yes','solatec'),
                '0'  => esc_html__('No','solatec'),
			];
			// Default Layout 
			$ptitle_layout = !empty($args['default_layout']) ? $args['default_layout'] : '-1';
		} else {
			$options = [
				'1'  => esc_html__('Yes','solatec'),
                '0'  => esc_html__('No','solatec'),
			];
			// Default Layout 
			$ptitle_layout = !empty($args['default_layout']) ? $args['default_layout'] : solatec_configs('ptitle')['layout'];
		}
		// layout
		$layout_default = [
			'-1' => get_template_directory_uri() . '/assets/images/default-opt/default.jpg',
			//'0' => get_template_directory_uri() . '/assets/images/default-opt/none.jpg',
		];
		$layout_list = [
			'1' => get_template_directory_uri() . '/assets/images/ptitle-layout/p1.jpg',
			'2' => get_template_directory_uri() . '/assets/images/ptitle-layout/p2.jpg',
			'3' => get_template_directory_uri() . '/assets/images/ptitle-layout/p3.jpg',
			'4' => get_template_directory_uri() . '/assets/images/ptitle-layout/p4.jpg',
			'5' => get_template_directory_uri() . '/assets/images/ptitle-layout/p5.jpg',
			'6' => get_template_directory_uri() . '/assets/images/ptitle-layout/p6.jpg',
			'7' => get_template_directory_uri() . '/assets/images/ptitle-layout/p7.jpg',
			'8' => get_template_directory_uri() . '/assets/images/ptitle-layout/p8.jpg',
			'9' => get_template_directory_uri() . '/assets/images/ptitle-layout/p9.jpg',
			'10' => get_template_directory_uri() . '/assets/images/ptitle-layout/p10.jpg',
			'11' => get_template_directory_uri() . '/assets/images/ptitle-layout/p11.jpg',
			'12' => get_template_directory_uri() . '/assets/images/ptitle-layout/p12.jpg',
		];
		
		if($args['default']){
			$layout_opts = $layout_default +  $layout_list;
		} else {
			$layout_opts = $layout_list;
		}
		// Show/Hide
		if($args['default']){
			$sh_options = [
				'-1' => esc_html__('Default','solatec'),
                '1'  => esc_html__('Show','solatec'),
                '0'  => esc_html__('Hide','solatec'),
			];
		} else {
			$sh_options = [
				'1'  => esc_html__('Show','solatec'),
                '0'  => esc_html__('Hide','solatec'),
			];
		}
		
		return array(
			'title'      => esc_html__('Page Title', 'solatec'),
			'icon'       => 'el-icon-map-marker',
			'subsection' => $args['subsection'],
			'fields'     => array(
		        array(
		            'id'           => 'pagetitle',
		            'type'         => 'button_set',
		            'title'        => esc_html__( 'Page Title', 'solatec' ),
		            'subtitle'     => esc_html__('Show/Hide page title?', 'solatec'),
		            'options'      => $sh_options,
		            'default'      => $args['default_value'],
		        ),
		        array(
		            'id'       => 'ptitle_layout',
		            'type'     => 'image_select',
		            'title'    => esc_html__('Layout', 'solatec'),
		            'subtitle' => esc_html__('Select a layout for page title.', 'solatec'),
		            'options'  => $layout_opts,
		            'default'  => $ptitle_layout,
		            'required' => array( 0 => 'pagetitle', 1 => 'equals', 2 => '1' ),
		        ),
		        array(
					'id'                    => 'ptitle_bg',
					'type'                  => 'background',
					'title'                 => esc_html__('Background', 'solatec'),
					'subtitle'              => esc_html__('Page title background.', 'solatec'),
					'output'                => array('body #pagetitle'),
					'required'              => array( 0 => 'pagetitle', 1 => 'equals', 2 => '1' ),
		        ),
		        array(
					'id'           => 'ptitle_overlay_color',
					'type'         => 'color_rgba',
					'title'        => esc_html__('Overlay Background Color', 'solatec'),
					'required'     => array( 0 => 'pagetitle', 1 => 'equals', 2 => '1' ),
		        ),
		        array(
		            'id'       => 'ptitle_title_on',
		            'type'     => 'button_set',
		            'title'    => esc_html__('Show Title', 'solatec'),
		            'options'  => $sh_options,
		            'default'  => $args['default_value'],
		            'required' => array( 0 => 'pagetitle', 1 => 'equals', 2 => '1' ),
		        ),
		        solatec_page_title_custom_text_opts($args['default']),
		        array(
					'id'          => 'ptitle_color',
					'type'        => 'color_rgba',
					'title'       => esc_html__('Title Color', 'solatec'),
					'subtitle'    => esc_html__('Page title color.', 'solatec'),
					'required'    => array( 0 => 'ptitle_title_on', 1 => 'equals', 2 => '1' ),
		        ),
		        array(
		            'id'       => 'ptitle_breadcrumb_on',
		            'type'     => 'button_set',
		            'title'    => esc_html__('Show Breadcrumb', 'solatec'),
		            'options'  => $sh_options,
		            'default'  => $args['default_value'],
		            'required' => array( 0 => 'pagetitle', 1 => 'equals', 2 => '1' ),
		        ),
		        array(
		            'id'      => 'ptitle_breadcrumb_link_color',
		            'type'    => 'link_color',
		            'title'   => esc_html__('Breadcrumb Color', 'solatec'),
		            'default' => array(
		                'regular' => '',
		                'hover'   => '',
		                'active'  => '',
		            ),
		            'required' => array( 0 => 'ptitle_breadcrumb_on', 1 => 'equals', 2 => '1' ),
		        ),
		    )
		);
	}
}
if(!function_exists('solatec_page_title_custom_text_opts')){
	function solatec_page_title_custom_text_opts($show){
		if(!$show) return;
		return array(
			'id'           => 'custom_title',
			'type'         => 'textarea',
			'title'        => esc_html__( 'Custom Title', 'solatec' ),
			'subtitle'     => esc_html__( 'Use custom title for this page. The default title will be used on document title.', 'solatec' ),
			'required' 	   => array( 
				array(0 => 'ptitle_title_on', 1 => 'equals', 2 => '1' )
			)
		);
	}
}
/** 
 * Custom Post Slug
*/ 
if(!function_exists('solatec_custom_post_slugs_opts')){
	function solatec_custom_post_slugs_opts(){
		$opts = array(
		    'title'      => esc_html__('Custom Permarlink', 'solatec'),
		    'icon'       => 'el el-link',
		    'subsection' => true,
		    'fields'     => solatec_custom_post_type_slug()
		);
		return $opts;
	}
}
/**
 * Footer Options
**/
if(!function_exists('solatec_footer_opts')){
	function solatec_footer_opts($args=[]){
		$args = wp_parse_args($args, [
			'default'       => false,
			'default_value' => '1',
			'subsection'    => false
		]);
		if($args['default']){
			$footer_fixed_options = [
				'-1' => esc_html__('Default','solatec'),
                '1'  => esc_html__('Yes','solatec'),
                '0'  => esc_html__('No','solatec'),
			];
			$footer_layout_default = '-1';
			$footer_fixed_default_value = '-1';
		} else {
			$footer_fixed_options = [
				'1'  => esc_html__('Yes','solatec'),
                '0'  => esc_html__('No','solatec'),
			];
			$footer_layout_default = '1';
			$footer_fixed_default_value = '0';
		}
		
		// Return
		return array(
		    'title'      => esc_html__('Footer', 'solatec'),
		    'icon'       => 'el-icon-website',
		    'subsection' => $args['subsection'],
		    'fields'     => array(
		        array(
                    'id'          => 'footer_layout',
                    'type'        => 'image_select',
                    'title'       => esc_html__('Layout', 'solatec'),
                    'subtitle'    => esc_html__('Select a layout for upper footer area.', 'solatec'),
                    'desc'        => sprintf(esc_html__('%sClick Here%s to add your custom footer layout.','solatec'),'<a href="' . esc_url( admin_url( 'edit.php?post_type=cms-footer' ) ) . '" target="_blank">','</a>'),
                    'placeholder' => esc_html__('Default','solatec'),
                    'options'     => solatec_list_post_thumbnail('cms-footer', $args['default'], [
                    	'1' => get_template_directory_uri() . '/assets/images/footer-layout/default.png'
                    ]),
                    'default'     => $footer_layout_default
                ),
	            array(
                    'title'    => esc_html__('Footer Fixed', 'solatec'),
                    'subtitle' => esc_html__('Make footer fixed at bottom?', 'solatec'),
                    'id'       => 'footer_fixed',
                    'type'     => 'button_set',
                    'options'  => $footer_fixed_options,
                    'default'  => $footer_fixed_default_value,
                )
            )
		);
	}
}
if(!function_exists('solatec_footer_bottom_opts')){
	function solatec_footer_bottom_opts($args = []){
		return array(
		    'title'      => esc_html__('Footer Bottom', 'solatec'),
		    'icon'       => 'el el-circle-arrow-right',
		    'subsection' => true,
		    'fields'     => array(
		        array(
					'id'           =>'footer_copyright',
					'type'         => 'textarea',
					'title'        => esc_html__('Copyright', 'solatec'),
					'validate'     => 'html_custom',
					'default'      => '',
					'allowed_html' => array(
		                'a' => array(
		                    'href' => array(),
		                    'title' => array(),
		                    'class' => array(),
		                    'target' => array()
		                )
		            ),
		            'required' => [
				    	['footer_layout', 'equals', '1']
				    ]
		        ),
		        array(
		            'title'  => esc_html__('Social', 'solatec'),
		            'type'   => 'section',
		            'id'     => 'footer_social',
		            'indent' => true,
		            'required' => [
				    	['footer_layout', 'equals', '1']
				    ]
		        ),
		        solatec_social_list_opts(['param_name' => 'f_social_list']),
		    )
		);
	}
}
/**
 * Sidebar
*/
if(!function_exists('solatec_sidebar_opts')){
	function solatec_sidebar_opts($args = []){
		$args = wp_parse_args($args, [
			'name'          => 'sidebar_page_pos',
			'default'       => false,
			'default_value' => solatec_configs('blog')['archive_sidebar_pos'],
			'subsection'    => true,
			'fields_only'	=> false
		]);
		if($args['default']){
			$options = [
				'-1'    => esc_html__('Default','solatec'),
				'0'     => esc_html__('No Sidebar','solatec'),
				'left'  => esc_html__('Left','solatec'),
				'right' => esc_html__('Right','solatec'),
				'bottom' => esc_html__('Bottom','solatec'),
			];
			$default_value = '-1';
		} else {
			$options = [
				'0'     => esc_html__('No Sidebar','solatec'),
				'left'  => esc_html__('Left','solatec'),
				'right' => esc_html__('Right','solatec'),
				'bottom' => esc_html__('Bottom','solatec'),
			];
			$default_value = $args['default_value'];
		}
		// Return
		if($args['fields_only']){
			return array(
                'title'    => esc_html__('Sidebar Position', 'solatec'),
                'subtitle' => esc_html__('Choose position for sidebar', 'solatec'),
                'id'       => $args['name'],
                'type'     => 'button_set',
                'options'  => $options,
                'default'  => $default_value,
            );
		} else {
			return array(
			    'title'      => esc_html__('Sidebar Position', 'solatec'),
			    'icon'       => 'el-icon-website',
			    'subsection' => $args['subsection'],
			    'fields'     => array(
			        array(
	                    'title'    => esc_html__('Sidebar Position', 'solatec'),
	                    'subtitle' => esc_html__('Choose position for sidebar', 'solatec'),
	                    'id'       => $args['name'],
	                    'type'     => 'button_set',
	                    'options'  => $options,
	                    'default'  => $default_value,
	                )
	            )
			);
		}
	}
}

// Page layout 
if(!function_exists('solatec_page_layout_opts')){
	function solatec_page_layout_opts($args = []){
		$args = wp_parse_args($args, [
			'title' => esc_html__('Single Page', 'solatec'),
			'default'       => false,
			'default_value' => solatec_configs('blog')['archive_sidebar_pos'],
			'subsection'    => true,
			'fields_only'	=> false
		]);
		return array(
		    'title'      => $args['title'],
		    'icon'       => 'el-icon-file-edit',
		    'subsection' => true,
		    'fields'     => array(
		        solatec_sidebar_opts([
		            'name'          => 'page_sidebar_pos',
		            'fields_only'   =>  true,
		            'default_value' => solatec_configs('blog')['single_sidebar_pos']  
		        ]),
		        array(
		            'id'            => 'page_content_col',
		            'title'         => esc_html__('Content Columns', 'solatec'),
		            'subtitle'      => esc_html__('Choose content Columns', 'solatec'),
		            'type'          => 'slider',
		            'default'       => solatec_configs('blog')['single_content_col'],
		            'min'           => 1,
		            'step'          => 1,
		            'max'           => 11,
		            'display_value' => 'label',
		            'required'      => [ 
		                ['page_sidebar_pos', '!=', '0'],
		                ['page_sidebar_pos', '!=', 'bottom']
		            ],
		        )
		    )
		);
	}
}

if(!function_exists('solatec_woo_header_cart_opts')){
	function solatec_woo_header_cart_opts($args = []){
		if(!class_exists('WooCommerce')) return array();
		$args = wp_parse_args($args, [
			'options' => '',
			'default' => ''
		]);
		return array(
            'title'    => esc_html__('Show Cart', 'solatec'),
            'subtitle' => esc_html__('Show/Hide cart icon', 'solatec'),
            'id'       => 'cart_on',
            'type'     => 'button_set',
            'options'  => $args['options'],
            'default'  => $args['default'],
        );
	}
}

if(!function_exists('solatec_header_language_switcher_opts')){
	function solatec_header_language_switcher_opts($args = []){
		if(!class_exists('TRP_Translate_Press') ) return array();
		$args = wp_parse_args($args, [
			'options' => '',
			'default' => ''
		]);
		return array(
            'title'    => esc_html__('Show Language Switcher', 'solatec'),
            'subtitle' => esc_html__('Show/Hide Language Switcher', 'solatec'),
            'id'       => 'header_switch_language',
            'type'     => 'button_set',
            'options'  => $args['options'],
            'default'  => $args['default'],
        );
		
	}
}