<?php
if (!class_exists('ReduxFramework')) {
    return;
}
if (class_exists('ReduxFrameworkPlugin')) {
    remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
}

if(class_exists('Newsletter')) {
    $forms = array_filter( (array) get_option( 'newsletter_forms', array() ) );

    $newsletter_forms = array(
        'default' => esc_html__( 'Default Form', 'solatec' )
    );

    if ( $forms )
    {
        $index = 1;
        foreach ( $forms as $key => $form )
        {
            $newsletter_forms[$key] = sprintf( esc_html__( 'Form %s', 'solatec' ), $index );
            $index ++;
        }
    }
} else {
    $newsletter_forms = '';
}

$opt_name = solatec_get_opt_name();
$theme = wp_get_theme();
$text_domain = $theme->get('TextDomain');
if (is_child_theme()) {
    $text_domain = $theme->parent()->get('TextDomain');
}

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name'             => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name'         => $theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version'      => $theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type'            => class_exists('Elementor_Theme_Core') ? 'submenu' : '',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu'       => true,
    // Show the sections below the admin menu item or not
    'menu_title'           => esc_html__('Theme Options', 'solatec'),
    'page_title'           => esc_html__('Theme Options', 'solatec'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key'       => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography'     => false,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar'            => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon'       => 'dashicons-admin-generic',
    // Choose an icon for the admin bar menu
    'admin_bar_priority'   => 50,
    // Choose an priority for the admin bar menu
    'global_variable'      => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode'             => true,
    // Show the time the page took to load, etc
    'update_notice'        => true,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer'           => true,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field
    'show_options_object' => false,
    // OPTIONAL -> Give you extra features
    'page_priority'        => null,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent'          => class_exists('Elementor_Theme_Core') ? $text_domain : '',
    // For a full list of options, visit: //codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions'     => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon'            => '',
    // Specify a custom URL to an icon
    'last_tab'             => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon'            => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug'            => 'theme-options',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults'        => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show'         => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark'         => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export'   => false,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time'       => 60 * MINUTE_IN_SECONDS,
    'output'               => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag'           => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database'             => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn'              => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    // HINTS
    'hints'             => array(
        'icon'          => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color'    => 'lightgray',
        'icon_size'     => 'normal',
        'tip_style'     => array(
            'color'   => 'red',
            'shadow'  => true,
            'rounded' => false,
            'style'   => '',
        ),
        'tip_position'  => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect'    => array(
            'show' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'mouseover',
            ),
            'hide' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'click mouseleave',
            ),
        ),
    ),
    'templates_path'       => get_template_directory() . '/inc/templates/redux/'
);

Redux::SetArgs($opt_name, $args);

/*--------------------------------------------------------------
# General
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('General', 'solatec'),
    'icon'   => 'el-icon-home',
    'fields' => array()
));
/*--------------------------------------------------------------
# Colors
--------------------------------------------------------------*/
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Colors', 'solatec'),
    'icon'       => 'dashicons dashicons-dashboard',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'          => 'accent_color',
            'type'        => 'color',
            'title'       => esc_html__('Accent Color', 'solatec'),
            'transparent' => false,
            'default'     => ''
        ),
        array(
            'id'          => 'primary_color',
            'type'        => 'color',
            'title'       => esc_html__('Primary Color', 'solatec'),
            'transparent' => false,
            'default'     => ''
        ),
        array(
            'id'          => 'secondary_color',
            'type'        => 'color',
            'title'       => esc_html__('Secondary Color', 'solatec'),
            'transparent' => false,
            'default'     => ''
        ),
        array(
            'id'      => 'link_color',
            'type'    => 'link_color',
            'title'   => esc_html__('Link Colors', 'solatec'),
            'default' => array(
                'regular' => '',
                'hover'   => '',
                'active'  => ''
            ),
        )
    )
));

/*--------------------------------------------------------------
# Tools
--------------------------------------------------------------*/
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Tools', 'solatec'),
    'icon'       => 'el-icon-edit',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'show_page_loading',
            'type'     => 'switch',
            'title'    => esc_html__('Enable Page Loading', 'solatec'),
            'subtitle' => esc_html__('Enable page loading effect when you load site.', 'solatec'),
            'default'  => false
        ),
        array(
            'id'       => 'smoothscroll',
            'type'     => 'switch',
            'title'    => esc_html__('Smooth Scroll', 'solatec'),
            'default'  => false
        ),
        array(
            'id'       => 'back_totop_on',
            'type'     => 'switch',
            'title'    => esc_html__('Enable Back To Top', 'solatec'),
            'default'  => true
        ),
        array(
            'id'       => 'backtotop_icon',
            'type'     => 'cms_iconpicker',
            'title'    => esc_html__( 'Choose your Back To Top icon', 'solatec' ),
            'default'  => 'zmdi zmdi-long-arrow-up',
            'required' => [
                ['back_totop_on', 'equals', true]
            ]
        ),
        array(
            'id'       => 'dev_mode',
            'type'     => 'switch',
            'title'    => esc_html__('Dev Mode (not recommended)', 'solatec'),
            'description' => 'no minimize , generate css over time...',
            'default'  => false
        )
    )
));
/*--------------------------------------------------------------
# Typography
--------------------------------------------------------------*/
Redux::setSection($opt_name, array(
    'title'  => esc_html__('Typography', 'solatec'),
    'icon'   => 'el-icon-text-width',
    'fields' => array(
        array(
            'id'       => 'body_typo',
            'type'     => 'select',
            'title'    => esc_html__('Body Typography', 'solatec'),
            'options'  => array(
                'default' => esc_html__('Default', 'solatec'),
                'custom'  => esc_html__('Custom', 'solatec'),
            ),
            'default'  => 'default',
        ),
        array(
            'id'             => 'body_font_typo',
            'type'           => 'typography',
            'title'          => esc_html__('Body Google Font', 'solatec'),
            'subtitle'       => esc_html__('This will be the default font of your website.', 'solatec'),
            'letter-spacing' => true,
            'text-align'     => false,
            'units'          => 'px',
            'required'       => array( 0 => 'body_typo', 1 => 'equals', 2 => 'custom' ),
        ),
        array(
            'id'       => 'heading_font_typo',
            'type'     => 'select',
            'title'    => esc_html__('Heading Typography', 'solatec'),
            'options'  => array(
                'default' => esc_html__('Default', 'solatec'),
                'custom'  => esc_html__('Google Font', 'solatec'),
            ),
            'default'  => 'default',
        ),
        array(
            'id'             => 'h1_typo',
            'type'           => 'typography',
            'title'          => esc_html__('H1', 'solatec'),
            'subtitle'       => esc_html__('This will be the default font for all H1 tags of your website.', 'solatec'),
            'letter-spacing' => true,
            'text-align'     => false,
            'units'          => 'px',
            'required'       => array( 0 => 'heading_font_typo', 1 => 'equals', 2 => 'custom' ),
        ),
        array(
            'id'             => 'h2_typo',
            'type'           => 'typography',
            'title'          => esc_html__('H2', 'solatec'),
            'subtitle'       => esc_html__('This will be the default font for all H2 tags of your website.', 'solatec'),
            'letter-spacing' => true,
            'text-align'     => false,
            'units'          => 'px',
            'required'       => array( 0 => 'heading_font_typo', 1 => 'equals', 2 => 'custom' ),
        ),
        array(
            'id'             => 'h3_typo',
            'type'           => 'typography',
            'title'          => esc_html__('H3', 'solatec'),
            'subtitle'       => esc_html__('This will be the default font for all H3 tags of your website.', 'solatec'),
            'letter-spacing' => true,
            'text-align'     => false,
            'units'          => 'px',
            'required'       => array( 0 => 'heading_font_typo', 1 => 'equals', 2 => 'custom' ),
        ),
        array(
            'id'             => 'h4_typo',
            'type'           => 'typography',
            'title'          => esc_html__('H4', 'solatec'),
            'subtitle'       => esc_html__('This will be the default font for all H4 tags of your website.', 'solatec'),
            'letter-spacing' => true,
            'text-align'     => false,
            'units'          => 'px',
            'required'       => array( 0 => 'heading_font_typo', 1 => 'equals', 2 => 'custom' ),
        ),
        array(
            'id'             => 'h5_typo',
            'type'           => 'typography',
            'title'          => esc_html__('H5', 'solatec'),
            'subtitle'       => esc_html__('This will be the default font for all H5 tags of your website.', 'solatec'),
            'letter-spacing' => true,
            'text-align'     => false,
            'units'          => 'px',
            'required'       => array( 0 => 'heading_font_typo', 1 => 'equals', 2 => 'custom' ),
        ),
        array(
            'id'             => 'h6_typo',
            'type'           => 'typography',
            'title'          => esc_html__('H6', 'solatec'),
            'subtitle'       => esc_html__('This will be the default font for all H6 tags of your website.', 'solatec'),
            'letter-spacing' => true,
            'text-align'     => false,
            'units'          => 'px',
            'required'       => array( 0 => 'heading_font_typo', 1 => 'equals', 2 => 'custom' ),
        ),
        array(
            'id'       => 'sub_heading_default_font',
            'type'     => 'select',
            'title'    => esc_html__('Sub Heading Default Font', 'solatec'),
            'options'  => array(
                'default' => esc_html__('Default', 'solatec'),
                'custom'  => esc_html__('Google Font', 'solatec'),
            ),
            'default'  => 'default',
        ),
        array(
            'id'           => 'font_sub_heading',
            'type'         => 'typography',
            'title'        => esc_html__('Sub Heading', 'solatec'),
            'subtitle'     => esc_html__('This will be the default font for sub heading of your website.', 'solatec'),
            'text-align'   => false,
            'units'        => 'px',
            'required'     => array( 0 => 'sub_heading_default_font', 1 => 'equals', 2 => 'custom' ),
        ),
    )
));
$custom_font_selectors_1 = Redux::get_option($opt_name, 'custom_font_selectors_1');
$custom_font_selectors_1 = !empty($custom_font_selectors_1) ? explode(',', $custom_font_selectors_1) : array();
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Custom Fonts', 'solatec'),
    'icon'       => 'el el-fontsize',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'          => 'custom_font_1',
            'type'        => 'typography',
            'title'       => esc_html__('Custom Font', 'solatec'),
            'subtitle'    => esc_html__('This will be the font that applies to the class selector.', 'solatec'),
            'text-align'  => false,
            'output'      => $custom_font_selectors_1,
            'units'       => 'px',
        ),
        array(
            'id'       => 'custom_font_selectors_1',
            'type'     => 'textarea',
            'title'    => esc_html__('CSS Selectors', 'solatec'),
            'subtitle' => esc_html__('Add class selectors to apply above font.', 'solatec'),
            'validate' => 'no_html'
        )
    )
));
/**
 * Header Top
*/
Redux::setSection($opt_name, solatec_header_top_opts());
/*--------------------------------------------------------------
# Header
--------------------------------------------------------------*/
// Header layout
Redux::setSection($opt_name, solatec_header_opts());
// Logo
Redux::setSection($opt_name, solatec_header_logo_opts());
// Header OnTop (Transparent)
Redux::setSection($opt_name, solatec_header_ontop_opts());
// Header Sticky
Redux::setSection($opt_name, solatec_header_sticky_opts());
// Header Navigation
Redux::setSection($opt_name, solatec_navigation_opts());
// Secondary Menu
Redux::setSection($opt_name, solatec_header_secondary_menu_opts());
// Header Attribute:  search, cart,....
Redux::setSection($opt_name, solatec_header_atts_opts());
// Header Social
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Social Link', 'solatec'),
    'icon'       => 'el el-share',
    'subsection' => true,
    'fields'     => array(
        solatec_social_list_opts()
    )
));
/*--------------------------------------------------------------
# Page Title area
--------------------------------------------------------------*/

Redux::setSection($opt_name, solatec_page_title_opts());

/*--------------------------------------------------------------
# WordPress default content
--------------------------------------------------------------*/
Redux::setSection($opt_name, array(
        'title'  => esc_html__('Content', 'solatec'),
        'icon'   => 'el-icon-pencil',
        'fields' => array(
        array(
            'id'       => 'content_bg_color',
            'type'     => 'color_rgba',
            'title'    => esc_html__('Background Color', 'solatec'),
            'subtitle' => esc_html__('Content background color.', 'solatec'),
            'output'   => array('background-color' => '.cms-main')
        ),
        array(
            'id'             => 'content_padding',
            'type'           => 'spacing',
            'output'         => array('#cms-main'),
            'right'          => false,
            'left'           => false,
            'mode'           => 'padding',
            'units'          => array('px'),
            'units_extended' => 'false',
            'title'          => esc_html__('Content Padding', 'solatec'),
            'desc'           => esc_html__('Default: Top-90px, Bottom-90px', 'solatec'),
            'default'        => array(
                'padding-top'    => '',
                'padding-bottom' => '',
                'units'          => 'px',
            )
        ),
        array(
            'id'      => 'search_field_placeholder',
            'type'    => 'text',
            'title'   => esc_html__('Search Form - Text Placeholder', 'solatec'),
            'default' => '',
            'desc'           => esc_html__('Default: Search Keywords...', 'solatec'),
        ),
        array(
            'id'      => 'default_post_thumbnail',
            'type'    => 'button_set',
            'title'   => esc_html__('Use Placeholder Image for post have not featured image?', 'solatec'),
            'options' => array(
                '1'  => esc_html__('Yes', 'solatec'),
                '0' => esc_html__('No', 'solatec'),
            ),
            'default' => '0',
        ),
        array(
            'id'      => 'thumbnail_is_bg',
            'type'    => 'button_set',
            'title'   => esc_html__('Use Featured Image as Background', 'solatec'),
            'options' => array(
                '1'  => esc_html__('Yes', 'solatec'),
                '0' => esc_html__('No', 'solatec'),
            ),
            'default' => '0',
        ),
    )
));
// Single Page
Redux::setSection($opt_name, solatec_page_layout_opts());

// Archive
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Archive', 'solatec'),
    'icon'       => 'el-icon-list',
    'subsection' => true,
    'fields'     => array(
        solatec_sidebar_opts([
            'name'          => 'archive_sidebar_pos',
            'fields_only'   =>  true,
            'default_value' => solatec_configs('blog')['archive_sidebar_pos']  
        ]),
        array(
            'id'            => 'archive_content_col',
            'title'         => esc_html__('Content Width', 'solatec'),
            'subtitle'      => esc_html__('Choose content Columns width', 'solatec'),
            'type'          => 'slider',
            'default'       => solatec_configs('blog')['archive_content_col'],
            'min'           => 6,
            'step'          => 1,
            'max'           => 11,
            'display_value' => 'label',
            'required'      => [ 
                ['archive_sidebar_pos', '!=', '0'],
                ['archive_sidebar_pos', '!=', 'bottom']
            ],
        ),
        array(
            'id'       => 'archive_author_on',
            'title'    => esc_html__('Author', 'solatec'),
            'subtitle' => esc_html__('Show author name on each post.', 'solatec'),
            'type'     => 'switch',
            'default'  => false,
        ),
        array(
            'id'       => 'archive_date_on',
            'title'    => esc_html__('Date', 'solatec'),
            'subtitle' => esc_html__('Show date posted on each post.', 'solatec'),
            'type'     => 'switch',
            'default'  => true,
        ),
        array(
            'id'       => 'archive_categories_on',
            'title'    => esc_html__('Categories', 'solatec'),
            'subtitle' => esc_html__('Show category names on each post.', 'solatec'),
            'type'     => 'switch',
            'default'  => true,
        ),
        array(
            'id'       => 'archive_comments_on',
            'title'    => esc_html__('Comments', 'solatec'),
            'subtitle' => esc_html__('Show comments count on each post.', 'solatec'),
            'type'     => 'switch',
            'default'  => true,
        ),
    )
));
// Sinlge post
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Single Post', 'solatec'),
    'icon'       => 'el-icon-file-edit',
    'subsection' => true,
    'fields'     => array(
        solatec_sidebar_opts([
            'name'          => 'single_sidebar_pos',
            'fields_only'   =>  true,
            'default_value' => solatec_configs('blog')['single_sidebar_pos']  
        ]),
        array(
            'id'            => 'single_content_col',
            'title'         => esc_html__('Content Width', 'solatec'),
            'subtitle'      => esc_html__('Choose content Columns width', 'solatec'),
            'type'          => 'slider',
            'default'       => solatec_configs('blog')['single_content_col'],
            'min'           => 6,
            'step'          => 1,
            'max'           => 12,
            'display_value' => 'label',
            'required'      => [ 
                ['single_sidebar_pos', '!=', '0'],
                ['single_sidebar_pos', '!=', 'bottom']
            ],
        ),
        array(
            'id'       => 'post_author_on',
            'title'    => esc_html__('Author', 'solatec'),
            'subtitle' => esc_html__('Show author name on single post.', 'solatec'),
            'type'     => 'switch',
            'default'  => '0'
        ),
        array(
            'id'       => 'post_author_info_on',
            'title'    => esc_html__('Author Info', 'solatec'),
            'subtitle' => esc_html__('Show author info name on single post.', 'solatec'),
            'type'     => 'switch',
            'default'  => '0'
        ),
        array(
            'id'       => 'post_date_on',
            'title'    => esc_html__('Date', 'solatec'),
            'subtitle' => esc_html__('Show date on single post.', 'solatec'),
            'type'     => 'switch',
            'default'  => '1'
        ),
        array(
            'id'       => 'post_categories_on',
            'title'    => esc_html__('Categories', 'solatec'),
            'subtitle' => esc_html__('Show category names on single post.', 'solatec'),
            'type'     => 'switch',
            'default'  => '1'
        ),
        array(
            'id'       => 'post_tags_on',
            'title'    => esc_html__('Tags', 'solatec'),
            'subtitle' => esc_html__('Show tag names on single post.', 'solatec'),
            'type'     => 'switch',
            'default'  => '1'
        ),
        array(
            'id'       => 'post_comments_on',
            'title'    => esc_html__('Comments', 'solatec'),
            'subtitle' => esc_html__('Show comments count on single post.', 'solatec'),
            'type'     => 'switch',
            'default'  => '1'
        ),
        array(
            'id'       => 'post_social_share_on',
            'title'    => esc_html__('Social Share', 'solatec'),
            'subtitle' => esc_html__('Show social share on single post.', 'solatec'),
            'type'     => 'switch',
            'default'  => '0',
        ),
        array(
            'id'       => 'post_nav_link_on',
            'title'    => esc_html__('Post Navigation', 'solatec'),
            'subtitle' => esc_html__('Show next/preview Navigation.', 'solatec'),
            'type'     => 'switch',
            'default'  => '1',
        ),
        array(
            'id'       => 'post_comments_form_on',
            'title'    => esc_html__('Comments Form', 'solatec'),
            'subtitle' => esc_html__('Show comments form on single post.', 'solatec'),
            'type'     => 'switch',
            'default'  => '1'
        ),
        array(
            'id'       => 'post_comments_rating_on',
            'title'    => esc_html__('Comments Rating', 'solatec'),
            'subtitle' => esc_html__('Show comments rating field on single post.', 'solatec'),
            'type'     => 'switch',
            'default'  => '0',
            'required' => [
               'post_comments_form_on',
               'equals',
               '1' 
            ]
        ),
        array(
            'id'       => 'post_feature_image_on',
            'title'    => esc_html__('Feature Image', 'solatec'),
            'subtitle' => esc_html__('Show feature image on single post.', 'solatec'),
            'type'     => 'switch',
            'default'  => '1'
        ),
        array(
            'id'       => 'post_related_on',
            'title'    => esc_html__('Related Post', 'solatec'),
            'subtitle' => esc_html__('Show related on single post.', 'solatec'),
            'type'     => 'switch',
            'default'  => '0'
        ),
    )
));
//Redux::setSection($opt_name, solatec_sidebar_opts());
/* 404 Page /--------------------------------------------------------- */
Redux::setSection($opt_name, array(
    'title'      => esc_html__('404 Page', 'solatec'),
    'icon'       => 'el-cog-alt el',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'heading_404_page',
            'type'     => 'text',
            'title'    => esc_html__('Heading', 'solatec'),
            'subtitle' => esc_html__('Enter your text', 'solatec'),
            'desc'     => esc_html__('Leave blank to use default text', 'solatec'),
            'default'  => '',
        ),
        array(
            'id'       => 'subheading_404_page',
            'type'     => 'text',
            'title'    => esc_html__('SubHeading', 'solatec'),
            'subtitle' => esc_html__('Enter your text', 'solatec'),
            'desc'     => esc_html__('Leave blank to use default text', 'solatec'),
            'default'  => '',
        ),
        array(
            'id'       => 'content_404_page',
            'type'     => 'textarea',
            'title'    => esc_html__('Content', 'solatec'),
            'subtitle' => esc_html__('Enter your text', 'solatec'),
            'desc'     => esc_html__('Leave blank to use default text', 'solatec'),
            'default' => '',
        ),
        array(
            'id'       => 'btn_text_404_page',
            'type'     => 'text',
            'title'    => esc_html__('Button Text', 'solatec'),
            'subtitle' => esc_html__('Enter your text', 'solatec'),
            'default'  => '',
            'desc'     => esc_html__('Leave blank to use default text', 'solatec')
        ),
        array(
            'id'               => 'bg_404_page',
            'type'             => 'background',
            'title'            => esc_html__('Background', 'solatec'),
            'subtitle'         => esc_html__('Choose your Background', 'solatec'),
            'desc'             => esc_html__('Leave blank to use default background', 'solatec'),
            'background-color' => false,
            'output'           => 'body.error404 .cms-main'
        ),
        array(
            'id'               => 'post_types',
            'type'             => 'select',
            'data'             => 'post_types', 
            'title'            => esc_html__('post type list', 'solatec')
        ),
    ),
));
/**
 * Custom Slug
*/
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Custom Permarlink', 'solatec'),
    'icon'       => 'el el-link',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'service_slug',
            'title'    => esc_html__( 'Service Slug', 'solatec' ),
            'subtitle' => esc_html__('Enter slug for service archive','solatec'),
            'type'     => 'text'
        ),
        array(
            'id'       => 'project_slug',
            'title'    => esc_html__( 'Project Slug', 'solatec' ),
            'subtitle' => esc_html__('Enter slug for project archive','solatec'),
            'type'     => 'text'
        )
    )
));
/*--------------------------------------------------------------
# Shop
--------------------------------------------------------------*/
if(class_exists('Woocommerce')) {
    Redux::setSection($opt_name, array(
        'title'  => esc_html__('Shop', 'solatec'),
        'icon'   => 'el el-shopping-cart',
        'fields' => array(
            solatec_sidebar_opts([
                'name'          => 'product_page_sidebar_pos',
                'fields_only'   =>  true,
                'default_value' => solatec_configs('blog')['single_sidebar_pos']  
            ]),
            array(
                'id'            => 'product_page_content_col',
                'title'         => esc_html__('Content Width', 'solatec'),
                'subtitle'      => esc_html__('Choose content Columns width', 'solatec'),
                'type'          => 'slider',
                'default'       => solatec_configs('blog')['archive_content_col'],
                'min'           => 6,
                'step'          => 1,
                'max'           => 11,
                'display_value' => 'label',
                'required'      => [ 
                    ['product_page_sidebar_pos', '!=', '0'],
                    ['product_page_sidebar_pos', '!=', 'bottom']
                ],
            ),
            array(
                'title'         => esc_html__('Products displayed per row', 'solatec'),
                'id'            => 'products_columns',
                'type'          => 'slider',
                'subtitle'      => esc_html__('Number product to show per row', 'solatec'),
                'default'       => 3,
                'min'           => 2,
                'step'          => 1,
                'max'           => 6,
                'display_value' => 'text'
            ),
            array(
                'title'         => esc_html__('Products displayed per page', 'solatec'),
                'id'            => 'product_per_page',
                'type'          => 'slider',
                'subtitle'      => esc_html__('Number product to show', 'solatec'),
                'default'       => 9,
                'min'           => 3,
                'step'          => 1,
                'max'           => 50,
                'display_value' => 'text'
            ),
        )
    ));
    Redux::setSection($opt_name, array(
        'title'      => esc_html__('Single Product', 'solatec'),
        'icon'       => 'el el-shopping-cart',
        'subsection' => true,
        'fields'     => array(
            solatec_sidebar_opts([
                'name'          => 'product_single_sidebar_pos',
                'fields_only'   =>  true,
                'default_value' => solatec_configs('blog')['single_sidebar_pos']  
            ]),
            array(
                'id'            => 'product_single_content_col',
                'title'         => esc_html__('Content Width', 'solatec'),
                'subtitle'      => esc_html__('Choose content Columns width', 'solatec'),
                'type'          => 'slider',
                'default'       => solatec_configs('blog')['archive_content_col'],
                'min'           => 6,
                'step'          => 1,
                'max'           => 11,
                'display_value' => 'label',
                'required'      => [ 
                    ['product_page_sidebar_pos', '!=', '0'],
                    ['product_page_sidebar_pos', '!=', 'bottom']
                ],
            ),
            array(
                'id'       => 'product_social_share_on',
                'title'    => esc_html__('Social Share', 'solatec'),
                'subtitle' => esc_html__('Show social share on single product.', 'solatec'),
                'type'     => 'switch',
                'default'  => '1',
            ),
        )
    ));
}

/*--------------------------------------------------------------
# Footer
--------------------------------------------------------------*/
Redux::setSection($opt_name, solatec_footer_opts());
//Redux::setSection($opt_name, solatec_footer_bottom_opts());

/* API Key /--------------------------------------------------------- */
Redux::setSection($opt_name, array(
    'title'  => esc_html__('API Key', 'solatec'),
    'icon'   => 'el el-key',
    'fields' => array(
        array(
            'id'      => 'gm_api_key',
            'type'    => 'text',
            'title'   => esc_html__('Google Maps', 'solatec'),
            'default' => 'AIzaSyC08_qdlXXCWiFNVj02d-L2BDK5qr6ZnfM',
            'desc'    => esc_html__('Register a Google Maps Api key then put it in here.', 'solatec')
        ),
    ),
));

/* Socials 
--------------------------------------------------------- */
Redux::setSection($opt_name, array(
    'title'  => esc_html__('Social Links', 'solatec'),
    'icon'   => 'el el-share',
    'fields' => array(
        array(
            'id'       => 'social_facebook_icon',
            'type'     => 'cms_iconpicker',
            'title'    => esc_html__('Facebook Icon', 'solatec'),
        ),
        array(
            'id'      => 'social_facebook_url',
            'type'    => 'text',
            'title'   => esc_html__('Facebook URL', 'solatec'),
            'default' => '#',
        ),
         array(
            'id'       => 'social_twitter_icon',
            'type'     => 'cms_iconpicker',
            'title'    => esc_html__('Twitter Icon', 'solatec'),
        ),
        array(
            'id'      => 'social_twitter_url',
            'type'    => 'text',
            'title'   => esc_html__('Twitter URL', 'solatec'),
            'default' => '#',
        ),
         array(
            'id'       => 'social_linkedin_icon',
            'type'     => 'cms_iconpicker',
            'title'    => esc_html__('LinkedIn Icon', 'solatec'),
        ),
        array(
            'id'      => 'social_linkedin_url',
            'type'    => 'text',
            'title'   => esc_html__('Inkedin URL', 'solatec'),
            'default' => '#',
        ),
        array(
            'id'       => 'social_instagram_icon',
            'type'     => 'cms_iconpicker',
            'title'    => esc_html__('Instagram Icon', 'solatec'),
        ),
        array(
            'id'      => 'social_instagram_url',
            'type'    => 'text',
            'title'   => esc_html__('Instagram URL', 'solatec'),
            'default' => '#',
        ),
        array(
            'id'       => 'social_gplus_icon',
            'type'     => 'cms_iconpicker',
            'title'    => esc_html__('Google Icon', 'solatec'),
        ),
        array(
            'id'      => 'social_gplus_url',
            'type'    => 'text',
            'title'   => esc_html__('Google URL', 'solatec'),
            'default' => '#',
        ),
        array(
            'id'       => 'social_skype_icon',
            'type'     => 'cms_iconpicker',
            'title'    => esc_html__('Skype Icon', 'solatec'),
        ),
        array(
            'id'      => 'social_skype_url',
            'type'    => 'text',
            'title'   => esc_html__('Skype URL', 'solatec'),
            'default' => '#',
        ),
        array(
            'id'       => 'social_pinterest_icon',
            'type'     => 'cms_iconpicker',
            'title'    => esc_html__('Pinterest Icon', 'solatec'),
        ),
        array(
            'id'      => 'social_pinterest_url',
            'type'    => 'text',
            'title'   => esc_html__('Pinterest URL', 'solatec'),
            'default' => '#',
        ),
        array(
            'id'       => 'social_vimeo_icon',
            'type'     => 'cms_iconpicker',
            'title'    => esc_html__('Vimeo Icon', 'solatec'),
        ),
        array(
            'id'      => 'social_vimeo_url',
            'type'    => 'text',
            'title'   => esc_html__('Vimeo URL', 'solatec'),
            'default' => '#',
        ),
        array(
            'id'       => 'social_youtube_icon',
            'type'     => 'cms_iconpicker',
            'title'    => esc_html__('Youtube Icon', 'solatec'),
        ),
        array(
            'id'      => 'social_youtube_url',
            'type'    => 'text',
            'title'   => esc_html__('Youtube URL', 'solatec'),
            'default' => '#',
        ),
        array(
            'id'       => 'social_yelp_icon',
            'type'     => 'cms_iconpicker',
            'title'    => esc_html__('Yelp Icon', 'solatec'),
        ),
        array(
            'id'      => 'social_yelp_url',
            'type'    => 'text',
            'title'   => esc_html__('Yelp URL', 'solatec'),
            'default' => '#',
        ),
        array(
            'id'       => 'social_tumblr_icon',
            'type'     => 'cms_iconpicker',
            'title'    => esc_html__('Tumblr Icon', 'solatec'),
        ),
        array(
            'id'      => 'social_tumblr_url',
            'type'    => 'text',
            'title'   => esc_html__('Tumblr URL', 'solatec'),
            'default' => '#',
        ),
        array(
            'id'       => 'social_tripadvisor_icon',
            'type'     => 'cms_iconpicker',
            'title'    => esc_html__('Tripadvisor Icon', 'solatec'),
        ),
        array(
            'id'      => 'social_tripadvisor_url',
            'type'    => 'text',
            'title'   => esc_html__('Tripadvisor URL', 'solatec'),
            'default' => '#',
        ),
    ),
));

// Social list for Social Widget 
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Widget Social', 'solatec'),
    'icon'       => 'el el-share',
    'subsection' => true,
    'fields'     => array(
        solatec_social_list_opts(['param_name' => 'wg_social'])
    )
));