<?php
defined( 'ABSPATH' ) or exit( -1 );
/**
 * CMS Quick Contact
 *
 * @package Solatec
 * @version 1.0
 */
if(!function_exists('etc_register_wp_widget')) return;

function register_quickcontact_widget() {
    etc_register_wp_widget('CMS_Quick_Contact_Widget');
}
add_action('widgets_init', 'register_quickcontact_widget');

class CMS_Quick_Contact_Widget extends WP_Widget {
    function __construct() {
        parent::__construct(
            'cms_quickcontact_widget', // Base ID
            esc_html__('* CMS Quick Contact', 'solatec'), // Name
            array('description' => esc_html__('CMS Quick Contact Widget', 'solatec')) // Args
        );
    }
    function widget($args, $instance) {
        $instance = wp_parse_args( (array) $instance, array(
            'title'          => '',
            'layout'         => '1',
            'background_img' => '',
            'icon_img'       => '',
            'description'    => '',
            'description2'   => '',
            'button_text'    => '',
            'button_link'    => '',
            'button_text2'   => '',
            'button_link2'   => '',
        ) );
        extract($args);

        $title              = empty( $instance['title'] ) ? '' : $instance['title'];
        $title              = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $background_img_id  = isset($instance['background_img']) ? $instance['background_img'] : '';
        $background_img_url = wp_get_attachment_image_url($background_img_id, '');
        
        $icon_img_id        = isset($instance['icon_img']) ? (!empty($instance['icon_img']) ? $instance['icon_img'] : '') : '';
        $icon_img_url       = wp_get_attachment_image_url($icon_img_id, '');
        
        $description        = isset($instance['description']) ? $instance['description'] : '';
        $description2       = isset($instance['description2']) ? $instance['description2'] : '';
        $button_text        = isset($instance['button_text']) ? $instance['button_text'] : '';
        $button_link        = isset($instance['button_link']) ? $instance['button_link'] : '';
        $button_text2       = isset($instance['button_text2']) ? $instance['button_text2'] : '';
        $button_link2       = isset($instance['button_link2']) ? $instance['button_link2'] : '';
        
        printf('%s', $before_widget);
            if(!empty($icon_img_url)) {
        ?>
            <div class="cms-wg-icon">
                <img class="rtl-flip" src="<?php echo esc_url($icon_img_url); ?>" alt="<?php echo esc_attr__('widget icon', 'solatec')?>" />
            </div>
        <?php
            }
        if (!empty($title))  printf('%s %s %s', $before_title , $title , $after_title);

            /*solatec_render_socials_list([
                'name'   => 'wg_social', 
                'before' => '<div class="cms-quickcontact cms-quickcontact-layout-'.$instance['layout'].'">',
                'after'  => '</div>' 
            ]);*/
            if (!empty($description)): ?>
                <div class="cms-contact-text">
                    <?php echo wpautop($description); ?>
                </div>
            <?php endif; 
            if (!empty($button_link)) : ?>
                <div class="cms-contact-button">
                    <a href="<?php echo esc_url($button_link);?>" target="_blank"><span aria-hidden="true" class="fas fa-phone-alt"></span><?php echo esc_html($button_text);?></a>
                </div>
            <?php endif;
            if (!empty($description2)): ?>
                <div class="cms-contact-text2 text-body">
                    <?php echo wpautop($description2); ?>
                </div>
            <?php endif;
            if (!empty($button_link2)) : ?>
                <div class="cms-contact-button2">
                    <a href="<?php echo esc_url($button_link2);?>" target="_blank"><?php echo esc_html($button_text2);?></a>
                </div>
            <?php endif;
        printf('%s', $after_widget);
    }

    function update( $new_instance, $old_instance ) {
        $instance                   = $old_instance;
        $instance['title']          = strip_tags($new_instance['title']);
        $instance['layout']         = $new_instance['layout'];
        $instance['background_img'] = $new_instance['background_img'];
        $instance['icon_img']       = $new_instance['icon_img'];
        $instance['description']    = strip_tags($new_instance['description']);
        $instance['description2']   = strip_tags($new_instance['description2']);
        $instance['button_text']    = strip_tags($new_instance['button_text']);
        $instance['button_link']    = strip_tags($new_instance['button_link']);
        $instance['button_text2']   = strip_tags($new_instance['button_text2']);
        $instance['button_link2']   = strip_tags($new_instance['button_link2']);
        return $instance;
    }

    function form( $instance ) {
        $title          = isset($instance['title']) ? esc_attr($instance['title']) : '';
        $layout         = isset($instance['layout']) ? esc_attr($instance['layout']) : '1';
        $background_img = isset($instance['background_img']) ? $instance['background_img'] : '';
        $icon_img       = isset($instance['icon_img']) ? $instance['icon_img'] : '';
        $description    = isset($instance['description']) ? $instance['description'] : '';
        $description2   = isset($instance['description2']) ? $instance['description2'] : '';
        $button_text    = isset($instance['button_text']) ? $instance['button_text'] : '';
        $button_link    = isset($instance['button_link']) ? $instance['button_link'] : '';
        $button_text2   = isset($instance['button_text2']) ? $instance['button_text2'] : '';
        $button_link2   = isset($instance['button_link2']) ? $instance['button_link2'] : '';
    ?>
        <p>
            <label for="<?php echo esc_url($this->get_field_id('title')); ?>"><?php esc_html_e( 'Title:', 'solatec' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_url($this->get_field_id('layout')); ?>"><?php esc_html_e( 'Layout', 'solatec' ); ?></label>
            <select class="widefat" id="<?php echo esc_attr( $this->get_field_id('layout') ); ?>" name="<?php echo esc_attr( $this->get_field_name('layout') ); ?>">
                <option value="1"<?php if( $layout == '1' ){ echo 'selected="selected"';} ?>><?php esc_html_e('Layout 1', 'solatec'); ?></option>
                <option value="2"<?php if( $layout == '2' ){ echo 'selected="selected"';} ?>><?php esc_html_e('Layout 2', 'solatec'); ?></option>
            </select>
        </p>
        <div class="cms-image-wrap">
            <label for="<?php echo esc_url($this->get_field_id('background_img')); ?>"><?php esc_html_e('Background Image', 'solatec'); ?></label>
            <input type="hidden" class="widefat hide-image-url"
                   id="<?php echo esc_attr($this->get_field_id('background_img')); ?>"
                   name="<?php echo esc_attr($this->get_field_name('background_img')); ?>"
                   value="<?php echo esc_attr($background_img) ?>"/>
            <div class="cms-show-image">
                <?php
                if ($background_img != "") {
                    ?>
                    <img src="<?php echo wp_get_attachment_image_url($background_img) ?>">
                    <?php
                }
                ?>
            </div>
            <?php
            if ($background_img != "") {
                ?>
                <a href="#" class="cms-select-image" style="display: none;"><?php esc_html_e('Select Image', 'solatec'); ?></a>
                <a href="#" class="cms-remove-image"><?php esc_html_e('Remove Image', 'solatec'); ?></a>
                <?php
            } else {
                ?>
                <a href="#" class="cms-select-image"><?php esc_html_e('Select Image', 'solatec'); ?></a>
                <a href="#" class="cms-remove-image" style="display: none;"><?php esc_html_e('Remove Image', 'solatec'); ?></a>
                <?php
            }
            ?>
        </div>
        <div class="cms-image-wrap">
            <label for="<?php echo esc_url($this->get_field_id('icon_img')); ?>"><?php esc_html_e('Icon', 'solatec'); ?></label>
            <input type="hidden" class="widefat hide-image-url"
                   id="<?php echo esc_attr($this->get_field_id('icon_img')); ?>"
                   name="<?php echo esc_attr($this->get_field_name('icon_img')); ?>"
                   value="<?php echo esc_attr($icon_img) ?>"/>
            <div class="cms-show-image">
                <?php
                if ($icon_img != "") {
                    ?>
                    <img src="<?php echo wp_get_attachment_image_url($icon_img) ?>">
                    <?php
                }
                ?>
            </div>
            <?php
            if ($icon_img != "") {
                ?>
                <a href="#" class="cms-select-image" style="display: none;"><?php esc_html_e('Select Icon', 'solatec'); ?></a>
                <a href="#" class="cms-remove-image"><?php esc_html_e('Remove Icon', 'solatec'); ?></a>
                <?php
            } else {
                ?>
                <a href="#" class="cms-select-image"><?php esc_html_e('Select Icon', 'solatec'); ?></a>
                <a href="#" class="cms-remove-image" style="display: none;"><?php esc_html_e('Remove Icon', 'solatec'); ?></a>
                <?php
            }
            ?>
        </div>
        <p>
            <label for="<?php echo esc_url($this->get_field_id('description')); ?>"><?php esc_html_e('Description', 'solatec'); ?></label>
            <textarea class="widefat" rows="8" cols="20" id="<?php echo esc_attr($this->get_field_id('description')); ?>" name="<?php echo esc_attr($this->get_field_name('description')); ?>"><?php echo wp_kses_post($description); ?></textarea>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('button_text')); ?>"><?php esc_html_e( 'Button Text', 'solatec' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('button_text') ); ?>" name="<?php echo esc_attr( $this->get_field_name('button_text') ); ?>" type="text" value="<?php echo esc_attr( $button_text ); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('button_link')); ?>"><?php esc_html_e( 'Button Link', 'solatec' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('button_link') ); ?>" name="<?php echo esc_attr( $this->get_field_name('button_link') ); ?>" type="text" value="<?php echo esc_attr( $button_link ); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_url($this->get_field_id('description2')); ?>"><?php esc_html_e('Description 2', 'solatec'); ?></label>
            <textarea class="widefat" rows="8" cols="20" id="<?php echo esc_attr($this->get_field_id('description2')); ?>" name="<?php echo esc_attr($this->get_field_name('description2')); ?>"><?php echo wp_kses_post($description2); ?></textarea>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('button_text2')); ?>"><?php esc_html_e( 'Button Text2', 'solatec' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('button_text2') ); ?>" name="<?php echo esc_attr( $this->get_field_name('button_text2') ); ?>" type="text" value="<?php echo esc_attr( $button_text2 ); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('button_link2')); ?>"><?php esc_html_e( 'Button Link2', 'solatec' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('button_link2') ); ?>" name="<?php echo esc_attr( $this->get_field_name('button_link2') ); ?>" type="text" value="<?php echo esc_attr( $button_link2 ); ?>" />
        </p>
    <?php
    }
}