<?php
defined( 'ABSPATH' ) or exit( -1 );
/**
 * CMS Socials widgets
 *
 * @package Solatec
 * @version 1.0
 */
if(!function_exists('etc_register_wp_widget')) return;

function register_social_widget() {
    etc_register_wp_widget('CMS_Social_Widget');
}
add_action('widgets_init', 'register_social_widget');

class CMS_Social_Widget extends WP_Widget {
    function __construct() {
        parent::__construct(
            'cs_social_widget', // Base ID
            esc_html__('* CMS Social', 'solatec'), // Name
            array('description' => esc_html__('Social Widget', 'solatec'),) // Args
        );
    }
    function widget($args, $instance) {
        $instance = wp_parse_args( (array) $instance, array(
            'title'   => '',
            'layout'  => '1',
        ) );
        extract($args);

        $title = empty( $instance['title'] ) ? '' : $instance['title'];
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        
        printf('%s', $before_widget);

        if (!empty($title))  printf('%s %s %s', $before_title , $title , $after_title);

            solatec_render_socials_list([
                'name'   => 'wg_social', 
                'before' => '<div class="cms-socials cms-social-layout-'.$instance['layout'].'">',
                'after'  => '</div>' 
            ]);

        printf('%s', $after_widget);
    }

    function update( $new_instance, $old_instance ) {
         $instance = $old_instance;
         $instance['title']  = strip_tags($new_instance['title']);
         $instance['layout'] = $new_instance['layout'];
         return $instance;
    }

    function form( $instance ) {
         $title  = isset($instance['title']) ? esc_attr($instance['title']) : '';
         $layout = isset($instance['layout']) ? esc_attr($instance['layout']) : '1';
    ?>
        <p class="description">
            <?php esc_html_e('To use this widget, please choose social you want in theme options', 'solatec'); ?>
        </p>
        <p>
            <label for="<?php echo esc_url($this->get_field_id('title')); ?>"><?php esc_html_e( 'Title:', 'solatec' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_url($this->get_field_id('layout')); ?>"><?php esc_html_e( 'Layout', 'solatec' ); ?></label>
            <select class="widefat" id="<?php echo esc_attr( $this->get_field_id('layout') ); ?>" name="<?php echo esc_attr( $this->get_field_name('layout') ); ?>">
                <option value="1"<?php if( $layout == '1' ){ echo 'selected="selected"';} ?>><?php esc_html_e('Default', 'solatec'); ?></option>
                <option value="2"<?php if( $layout == '2' ){ echo 'selected="selected"';} ?>><?php esc_html_e('Layout 2', 'solatec'); ?></option>
            </select>
        </p>
    <?php
    }
}