<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
// Register Contact Form 7 Widget
if (!function_exists('solatec_widget_cms_ctf7_register_controls')) {
    add_action('etc_widget_cms_ctf7_register_controls', 'solatec_widget_cms_ctf7_register_controls', 10, 1);
    function solatec_widget_cms_ctf7_register_controls($widget)
    {
        $cf7 = get_posts('post_type="wpcf7_contact_form"&numberposts=-1');
        $contact_forms = array();
        if ($cf7) {
            foreach ($cf7 as $cform) {
                $contact_forms[$cform->ID] = $cform->post_title;
            }
        } else {
            $contact_forms[0] = esc_html__('No contact forms found', 'solatec');
        }
        // Layout Section Start
        $widget->start_controls_section('layout_section', [
            'label' => esc_html__('Layout', 'solatec'),
            'tab' => Controls_Manager::TAB_LAYOUT
        ]);
            solatec_elementor_row_align($widget, [
                'condition' => [
                    'layout' => ['1']
                ]
            ]);
            solatec_elementor_text_align($widget, [
                'condition' => [
                    'layout' => ['1']
                ]
            ]);
            $widget->add_control('layout', [
                'label'   => esc_html__('Templates', 'solatec'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'solatec' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_ctf7/layout/layout1.png'
                    ],
                    '2' => [
                        'label' => esc_html__( 'Layout 2', 'solatec' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_ctf7/layout/layout1.png'
                    ],
                    '3' => [
                        'label' => esc_html__( 'Layout 3', 'solatec' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_ctf7/layout/layout3.png'
                    ]
                ],
                'prefix_class' => 'cms-cf7-layout-',
            ]);
        $widget->end_controls_section();
        // Source Section
        $widget->start_controls_section(
            'source_section',
            [
                'label'    => esc_html__('Source Settings', 'solatec'),
                'tab'      => Controls_Manager::TAB_CONTENT,
            ]
        );
            $widget->add_control(
                'form_title',
                [
                    'label'       => esc_html__( 'Form Title', 'solatec' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Enter Form title', 'solatec' ),
                    'label_block' => true,
                ]
            );
            $widget->add_control(
                'form_desc',
                [
                    'label'       => esc_html__( 'Form Description', 'solatec' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Enter your text', 'solatec' ),
                    'label_block' => true,
                ]
            );
            $widget->add_control(
                'ctf7_id',
                [
                    'label'   => esc_html__('Select Form', 'solatec'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => $contact_forms,
                ]
            );
        $widget->end_controls_section();
        // Banner settings
        $widget->start_controls_section(
            'image_section',
            [
                'label'    => esc_html__('Banner Settings', 'solatec'),
                'tab'      => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['2']
                ]
            ]
        );
            $widget->add_control(
                'form_banner',
                [
                    'label'       => esc_html__( 'Choose your banner', 'solatec' ),
                    'type'        => Controls_Manager::MEDIA,
                    'label_block' => true
                ]
            );
            $widget->add_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'         => 'thumbnail_size',
                    'control_type' => 'group',
                    'default'      => 'full',
                    'condition'   => [
                        'form_banner!' => ''
                    ]
                ]
            );
        $widget->end_controls_section();
        // Icon
        $widget->start_controls_section(
            'icon_section',
            [
                'label'    => esc_html__('Icon Settings', 'solatec'),
                'tab'      => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['2']
                ]
            ]
        );
            $widget->add_control(
                'selected_icon',
                [
                    'label'            => esc_html__( 'Icon', 'solatec' ),
                    'type'             => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'default'          => [
                        'value'   => 'far fa-paper-plane',
                        'library' => 'fa-regular',
                    ]
                ]
            );
            $widget->add_control(
                'icon_size',
                [
                    'type'  => Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'min' => 20,
                            'max' => 200,
                        ]
                    ],
                    'size_units' => ['px'],
                    'default' => [
                        'unit' => 'px',
                        'size' => 50,
                    ]
                ]
            );
        $widget->end_controls_section();
    }
}